/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.lokalize.FileSearch.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "filesearchadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class FileSearchAdaptor
 */

FileSearchAdaptor::FileSearchAdaptor(FileSearchTab *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

FileSearchAdaptor::~FileSearchAdaptor()
{
    // destructor
}

void FileSearchAdaptor::addFilesToSearch(const QStringList &in0)
{
    // handle method call org.kde.Lokalize.FileSearch.addFilesToSearch
    parent()->addFilesToSearch(in0);
}

bool FileSearchAdaptor::findGuiText(const QString &text)
{
    // handle method call org.kde.Lokalize.FileSearch.findGuiText
    return parent()->findGuiText(text);
}

bool FileSearchAdaptor::findGuiTextPackage(const QString &text, const QString &package)
{
    // handle method call org.kde.Lokalize.FileSearch.findGuiTextPackage
    return parent()->findGuiTextPackage(text, package);
}

void FileSearchAdaptor::performSearch()
{
    // handle method call org.kde.Lokalize.FileSearch.performSearch
    parent()->performSearch();
}

void FileSearchAdaptor::setSourceQuery(const QString &in0)
{
    // handle method call org.kde.Lokalize.FileSearch.setSourceQuery
    parent()->setSourceQuery(in0);
}

void FileSearchAdaptor::setTargetQuery(const QString &in0)
{
    // handle method call org.kde.Lokalize.FileSearch.setTargetQuery
    parent()->setTargetQuery(in0);
}


#include "moc_filesearchadaptor.cpp"
