/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.lokalize.MainWindow.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef MAINWINDOWADAPTOR_H
#define MAINWINDOWADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "lokalizemainwindow.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.Lokalize.MainWindow
 */
class MainWindowAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.Lokalize.MainWindow")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.Lokalize.MainWindow\">\n"
"    <signal name=\"editorAdded\"/>\n"
"    <signal name=\"editorActivated\"/>\n"
"    <method name=\"openFileInEditor\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"path\"/>\n"
"    </method>\n"
"    <method name=\"openFileInEditorAt\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"path\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"source\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"ctxt\"/>\n"
"    </method>\n"
"    <method name=\"showTranslationMemory\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"showProjectOverview\"/>\n"
"    <method name=\"openProject\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"path\"/>\n"
"    </method>\n"
"    <method name=\"currentProject\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"editorIndexForFile\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"path\"/>\n"
"    </method>\n"
"    <method name=\"pid\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"dbusName\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"busyCursor\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"busy\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    MainWindowAdaptor(LokalizeMainWindow *parent);
    ~MainWindowAdaptor() override;

    inline LokalizeMainWindow *parent() const
    { return static_cast<LokalizeMainWindow *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void busyCursor(bool busy);
    QString currentProject();
    QString dbusName();
    int editorIndexForFile(const QString &path);
    int openFileInEditor(const QString &path);
    int openFileInEditorAt(const QString &path, const QString &source, const QString &ctxt);
    void openProject(const QString &path);
    int pid();
    void showProjectOverview();
    int showTranslationMemory();
Q_SIGNALS: // SIGNALS
    void editorActivated();
    void editorAdded();
};

#endif
