/********************************************************************************
** Form generated from reading UI file 'prefs_project_local.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFS_PROJECT_LOCAL_H
#define UI_PREFS_PROJECT_LOCAL_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_prefs_project_local
{
public:
    QVBoxLayout *vboxLayout;
    QFormLayout *formLayout;
    QLabel *l0;
    QComboBox *kcfg_Role;

    void setupUi(QWidget *prefs_project_local)
    {
        if (prefs_project_local->objectName().isEmpty())
            prefs_project_local->setObjectName("prefs_project_local");
        prefs_project_local->resize(611, 439);
        vboxLayout = new QVBoxLayout(prefs_project_local);
        vboxLayout->setObjectName("vboxLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        l0 = new QLabel(prefs_project_local);
        l0->setObjectName("l0");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, l0);

        kcfg_Role = new QComboBox(prefs_project_local);
        kcfg_Role->addItem(QString());
        kcfg_Role->addItem(QString());
        kcfg_Role->addItem(QString());
        kcfg_Role->setObjectName("kcfg_Role");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_Role);


        vboxLayout->addLayout(formLayout);


        retranslateUi(prefs_project_local);

        QMetaObject::connectSlotsByName(prefs_project_local);
    } // setupUi

    void retranslateUi(QWidget *prefs_project_local)
    {
        l0->setText(tr2i18n("Role:", nullptr));
        kcfg_Role->setItemText(0, tr2i18n("Translator", nullptr));
        kcfg_Role->setItemText(1, tr2i18n("Reviewer", nullptr));
        kcfg_Role->setItemText(2, tr2i18n("Approver", nullptr));

        (void)prefs_project_local;
    } // retranslateUi

};

namespace Ui {
    class prefs_project_local: public Ui_prefs_project_local {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PREFS_PROJECT_LOCAL_H

