/****************************************************************************
** Meta object code from reading C++ file 'lokalizetabpagebase.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../lokalize-26.08.0/src/lokalizetabpagebase.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'lokalizetabpagebase.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21LokalizeSubwindowBaseE_t {};
} // unnamed namespace

template <> constexpr inline auto LokalizeSubwindowBase::qt_create_metaobjectdata<qt_meta_tag_ZN21LokalizeSubwindowBaseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LokalizeSubwindowBase"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LokalizeSubwindowBase, qt_meta_tag_ZN21LokalizeSubwindowBaseE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LokalizeSubwindowBase::staticMetaObject = { {
    QMetaObject::SuperData::link<KMainWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21LokalizeSubwindowBaseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21LokalizeSubwindowBaseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21LokalizeSubwindowBaseE_t>.metaTypes,
    nullptr
} };

void LokalizeSubwindowBase::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LokalizeSubwindowBase *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *LokalizeSubwindowBase::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LokalizeSubwindowBase::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21LokalizeSubwindowBaseE_t>.strings))
        return static_cast<void*>(this);
    return KMainWindow::qt_metacast(_clname);
}

int LokalizeSubwindowBase::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KMainWindow::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN19LokalizeTabPageBaseE_t {};
} // unnamed namespace

template <> constexpr inline auto LokalizeTabPageBase::qt_create_metaobjectdata<qt_meta_tag_ZN19LokalizeTabPageBaseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LokalizeTabPageBase",
        "signalUpdatedTabLabelAndIconAvailable",
        "",
        "LokalizeTabPageBase*",
        "signalStatusBarCurrent",
        "signalStatusBarTotal",
        "signalStatusBarFuzzyNotReady",
        "signalStatusBarUntranslated",
        "signalStatusBarTranslationStatus"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'signalUpdatedTabLabelAndIconAvailable'
        QtMocHelpers::SignalData<void(LokalizeTabPageBase *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'signalStatusBarCurrent'
        QtMocHelpers::SignalData<void(const int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'signalStatusBarTotal'
        QtMocHelpers::SignalData<void(const int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'signalStatusBarFuzzyNotReady'
        QtMocHelpers::SignalData<void(const int, const int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'signalStatusBarUntranslated'
        QtMocHelpers::SignalData<void(const int, const int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'signalStatusBarTranslationStatus'
        QtMocHelpers::SignalData<void(const QString)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LokalizeTabPageBase, qt_meta_tag_ZN19LokalizeTabPageBaseE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LokalizeTabPageBase::staticMetaObject = { {
    QMetaObject::SuperData::link<LokalizeSubwindowBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19LokalizeTabPageBaseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19LokalizeTabPageBaseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19LokalizeTabPageBaseE_t>.metaTypes,
    nullptr
} };

void LokalizeTabPageBase::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LokalizeTabPageBase *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->signalUpdatedTabLabelAndIconAvailable((*reinterpret_cast<std::add_pointer_t<LokalizeTabPageBase*>>(_a[1]))); break;
        case 1: _t->signalStatusBarCurrent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->signalStatusBarTotal((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->signalStatusBarFuzzyNotReady((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 4: _t->signalStatusBarUntranslated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 5: _t->signalStatusBarTranslationStatus((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< LokalizeTabPageBase* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (LokalizeTabPageBase::*)(LokalizeTabPageBase * )>(_a, &LokalizeTabPageBase::signalUpdatedTabLabelAndIconAvailable, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (LokalizeTabPageBase::*)(const int )>(_a, &LokalizeTabPageBase::signalStatusBarCurrent, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (LokalizeTabPageBase::*)(const int )>(_a, &LokalizeTabPageBase::signalStatusBarTotal, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (LokalizeTabPageBase::*)(const int , const int )>(_a, &LokalizeTabPageBase::signalStatusBarFuzzyNotReady, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (LokalizeTabPageBase::*)(const int , const int )>(_a, &LokalizeTabPageBase::signalStatusBarUntranslated, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (LokalizeTabPageBase::*)(const QString )>(_a, &LokalizeTabPageBase::signalStatusBarTranslationStatus, 5))
            return;
    }
}

const QMetaObject *LokalizeTabPageBase::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LokalizeTabPageBase::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19LokalizeTabPageBaseE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KXMLGUIClient"))
        return static_cast< KXMLGUIClient*>(this);
    return LokalizeSubwindowBase::qt_metacast(_clname);
}

int LokalizeTabPageBase::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = LokalizeSubwindowBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void LokalizeTabPageBase::signalUpdatedTabLabelAndIconAvailable(LokalizeTabPageBase * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void LokalizeTabPageBase::signalStatusBarCurrent(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void LokalizeTabPageBase::signalStatusBarTotal(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void LokalizeTabPageBase::signalStatusBarFuzzyNotReady(const int _t1, const int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void LokalizeTabPageBase::signalStatusBarUntranslated(const int _t1, const int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void LokalizeTabPageBase::signalStatusBarTranslationStatus(const QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN32LokalizeTabPageBaseNoQMainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto LokalizeTabPageBaseNoQMainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN32LokalizeTabPageBaseNoQMainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LokalizeTabPageBaseNoQMainWindow",
        "signalUpdatedTabLabelAndIconAvailable",
        "",
        "LokalizeTabPageBaseNoQMainWindow*",
        "signalStatusBarCurrent",
        "signalStatusBarTotal",
        "signalStatusBarFuzzyNotReady",
        "signalStatusBarUntranslated",
        "signalStatusBarTranslationStatus"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'signalUpdatedTabLabelAndIconAvailable'
        QtMocHelpers::SignalData<void(LokalizeTabPageBaseNoQMainWindow *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'signalStatusBarCurrent'
        QtMocHelpers::SignalData<void(const int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'signalStatusBarTotal'
        QtMocHelpers::SignalData<void(const int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'signalStatusBarFuzzyNotReady'
        QtMocHelpers::SignalData<void(const int, const int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'signalStatusBarUntranslated'
        QtMocHelpers::SignalData<void(const int, const int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'signalStatusBarTranslationStatus'
        QtMocHelpers::SignalData<void(const QString)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LokalizeTabPageBaseNoQMainWindow, qt_meta_tag_ZN32LokalizeTabPageBaseNoQMainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LokalizeTabPageBaseNoQMainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32LokalizeTabPageBaseNoQMainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32LokalizeTabPageBaseNoQMainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN32LokalizeTabPageBaseNoQMainWindowE_t>.metaTypes,
    nullptr
} };

void LokalizeTabPageBaseNoQMainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LokalizeTabPageBaseNoQMainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->signalUpdatedTabLabelAndIconAvailable((*reinterpret_cast<std::add_pointer_t<LokalizeTabPageBaseNoQMainWindow*>>(_a[1]))); break;
        case 1: _t->signalStatusBarCurrent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->signalStatusBarTotal((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->signalStatusBarFuzzyNotReady((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 4: _t->signalStatusBarUntranslated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 5: _t->signalStatusBarTranslationStatus((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< LokalizeTabPageBaseNoQMainWindow* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (LokalizeTabPageBaseNoQMainWindow::*)(LokalizeTabPageBaseNoQMainWindow * )>(_a, &LokalizeTabPageBaseNoQMainWindow::signalUpdatedTabLabelAndIconAvailable, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (LokalizeTabPageBaseNoQMainWindow::*)(const int )>(_a, &LokalizeTabPageBaseNoQMainWindow::signalStatusBarCurrent, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (LokalizeTabPageBaseNoQMainWindow::*)(const int )>(_a, &LokalizeTabPageBaseNoQMainWindow::signalStatusBarTotal, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (LokalizeTabPageBaseNoQMainWindow::*)(const int , const int )>(_a, &LokalizeTabPageBaseNoQMainWindow::signalStatusBarFuzzyNotReady, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (LokalizeTabPageBaseNoQMainWindow::*)(const int , const int )>(_a, &LokalizeTabPageBaseNoQMainWindow::signalStatusBarUntranslated, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (LokalizeTabPageBaseNoQMainWindow::*)(const QString )>(_a, &LokalizeTabPageBaseNoQMainWindow::signalStatusBarTranslationStatus, 5))
            return;
    }
}

const QMetaObject *LokalizeTabPageBaseNoQMainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LokalizeTabPageBaseNoQMainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32LokalizeTabPageBaseNoQMainWindowE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KXMLGUIClient"))
        return static_cast< KXMLGUIClient*>(this);
    return QWidget::qt_metacast(_clname);
}

int LokalizeTabPageBaseNoQMainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void LokalizeTabPageBaseNoQMainWindow::signalUpdatedTabLabelAndIconAvailable(LokalizeTabPageBaseNoQMainWindow * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void LokalizeTabPageBaseNoQMainWindow::signalStatusBarCurrent(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void LokalizeTabPageBaseNoQMainWindow::signalStatusBarTotal(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void LokalizeTabPageBaseNoQMainWindow::signalStatusBarFuzzyNotReady(const int _t1, const int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void LokalizeTabPageBaseNoQMainWindow::signalStatusBarUntranslated(const int _t1, const int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void LokalizeTabPageBaseNoQMainWindow::signalStatusBarTranslationStatus(const QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
