/********************************************************************************
** Form generated from reading UI file 'massreplaceoptions.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MASSREPLACEOPTIONS_H
#define UI_MASSREPLACEOPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_MassReplaceOptions
{
public:
    QGridLayout *gridLayout;
    QLabel *label;
    QLabel *label_2;
    QPushButton *doPreview;
    QLineEdit *replaceText;
    QLineEdit *searchText;
    QPushButton *doReplace;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout;
    QCheckBox *useRegExps;
    QCheckBox *matchCase;
    QSpacerItem *horizontalSpacer;

    void setupUi(QWidget *MassReplaceOptions)
    {
        if (MassReplaceOptions->objectName().isEmpty())
            MassReplaceOptions->setObjectName("MassReplaceOptions");
        MassReplaceOptions->resize(281, 278);
        gridLayout = new QGridLayout(MassReplaceOptions);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(MassReplaceOptions);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        label_2 = new QLabel(MassReplaceOptions);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        doPreview = new QPushButton(MassReplaceOptions);
        doPreview->setObjectName("doPreview");
        doPreview->setCheckable(true);

        gridLayout->addWidget(doPreview, 0, 2, 1, 1);

        replaceText = new QLineEdit(MassReplaceOptions);
        replaceText->setObjectName("replaceText");

        gridLayout->addWidget(replaceText, 1, 1, 1, 1);

        searchText = new QLineEdit(MassReplaceOptions);
        searchText->setObjectName("searchText");

        gridLayout->addWidget(searchText, 0, 1, 1, 1);

        doReplace = new QPushButton(MassReplaceOptions);
        doReplace->setObjectName("doReplace");
        doReplace->setEnabled(false);

        gridLayout->addWidget(doReplace, 1, 2, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 3, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        useRegExps = new QCheckBox(MassReplaceOptions);
        useRegExps->setObjectName("useRegExps");

        horizontalLayout->addWidget(useRegExps);

        matchCase = new QCheckBox(MassReplaceOptions);
        matchCase->setObjectName("matchCase");

        horizontalLayout->addWidget(matchCase);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        gridLayout->addLayout(horizontalLayout, 2, 0, 1, 3);

#if QT_CONFIG(shortcut)
        label->setBuddy(searchText);
        label_2->setBuddy(replaceText);
#endif // QT_CONFIG(shortcut)

        retranslateUi(MassReplaceOptions);

        QMetaObject::connectSlotsByName(MassReplaceOptions);
    } // setupUi

    void retranslateUi(QWidget *MassReplaceOptions)
    {
        label->setText(tr2i18n("Replace:", nullptr));
        label_2->setText(tr2i18n("With:", nullptr));
        doPreview->setText(tr2i18n("Preview", nullptr));
        doReplace->setText(tr2i18n("Mass Replace", nullptr));
        useRegExps->setText(tr2i18n("Regular expressions", nullptr));
        matchCase->setText(tr2i18n("Match case", nullptr));
        (void)MassReplaceOptions;
    } // retranslateUi

};

namespace Ui {
    class MassReplaceOptions: public Ui_MassReplaceOptions {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MASSREPLACEOPTIONS_H

