/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.lokalize.Editor.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "editoradaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class EditorAdaptor
 */

EditorAdaptor::EditorAdaptor(EditorTab *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

EditorAdaptor::~EditorAdaptor()
{
    // destructor
}

void EditorAdaptor::addAlternateTranslation(int entry, const QString &translation)
{
    // handle method call org.kde.Lokalize.Editor.addAlternateTranslation
    parent()->addAlternateTranslation(entry, translation);
}

void EditorAdaptor::addEntryNote(int entry, const QString &note)
{
    // handle method call org.kde.Lokalize.Editor.addEntryNote
    parent()->addEntryNote(entry, note);
}

void EditorAdaptor::addTemporaryAlternateTranslation(int entry, const QString &translation)
{
    // handle method call org.kde.Lokalize.Editor.addTemporaryAlternateTranslation
    parent()->addTemporaryAlternateTranslation(entry, translation);
}

void EditorAdaptor::addTemporaryEntryNote(int entry, const QString &note)
{
    // handle method call org.kde.Lokalize.Editor.addTemporaryEntryNote
    parent()->addTemporaryEntryNote(entry, note);
}

void EditorAdaptor::attachAlternateTranslationFile(const QString &path)
{
    // handle method call org.kde.Lokalize.Editor.attachAlternateTranslationFile
    parent()->attachAlternateTranslationFile(path);
}

void EditorAdaptor::close()
{
    // handle method call org.kde.Lokalize.Editor.close
    parent()->close();
}

int EditorAdaptor::currentEntry()
{
    // handle method call org.kde.Lokalize.Editor.currentEntry
    return parent()->currentEntry();
}

QString EditorAdaptor::currentEntryId()
{
    // handle method call org.kde.Lokalize.Editor.currentEntryId
    return parent()->currentEntryId();
}

QString EditorAdaptor::currentFile()
{
    // handle method call org.kde.Lokalize.Editor.currentFile
    return parent()->currentFile();
}

QByteArray EditorAdaptor::currentFileContents()
{
    // handle method call org.kde.Lokalize.Editor.currentFileContents
    return parent()->currentFileContents();
}

int EditorAdaptor::currentForm()
{
    // handle method call org.kde.Lokalize.Editor.currentForm
    return parent()->currentForm();
}

int EditorAdaptor::entryCount()
{
    // handle method call org.kde.Lokalize.Editor.entryCount
    return parent()->entryCount();
}

int EditorAdaptor::entryPluralFormCount(int entry)
{
    // handle method call org.kde.Lokalize.Editor.entryPluralFormCount
    return parent()->entryPluralFormCount(entry);
}

bool EditorAdaptor::entryReady(int entry)
{
    // handle method call org.kde.Lokalize.Editor.entryReady
    return parent()->entryReady(entry);
}

QString EditorAdaptor::entrySource(int entry, int form)
{
    // handle method call org.kde.Lokalize.Editor.entrySource
    return parent()->entrySource(entry, form);
}

QString EditorAdaptor::entryTarget(int entry, int form)
{
    // handle method call org.kde.Lokalize.Editor.entryTarget
    return parent()->entryTarget(entry, form);
}

bool EditorAdaptor::findEntryBySourceContext(const QString &source, const QString &ctxt)
{
    // handle method call org.kde.Lokalize.Editor.findEntryBySourceContext
    return parent()->findEntryBySourceContext(source, ctxt);
}

void EditorAdaptor::gotoEntry(int entry)
{
    // handle method call org.kde.Lokalize.Editor.gotoEntry
    parent()->gotoEntry(entry);
}

void EditorAdaptor::gotoEntryForm(int entry, int form)
{
    // handle method call org.kde.Lokalize.Editor.gotoEntryForm
    parent()->gotoEntryForm(entry, form);
}

void EditorAdaptor::gotoEntryFormOffset(int entry, int form, int offset)
{
    // handle method call org.kde.Lokalize.Editor.gotoEntryFormOffset
    parent()->gotoEntryFormOffset(entry, form, offset);
}

void EditorAdaptor::gotoEntryFormOffsetSelection(int entry, int form, int offset, int selection)
{
    // handle method call org.kde.Lokalize.Editor.gotoEntryFormOffsetSelection
    parent()->gotoEntryFormOffsetSelection(entry, form, offset, selection);
}

void EditorAdaptor::gotoFirst()
{
    // handle method call org.kde.Lokalize.Editor.gotoFirst
    parent()->gotoFirst();
}

void EditorAdaptor::gotoFirstUnfiltered()
{
    // handle method call org.kde.Lokalize.Editor.gotoFirstUnfiltered
    parent()->gotoFirstUnfiltered();
}

void EditorAdaptor::gotoLast()
{
    // handle method call org.kde.Lokalize.Editor.gotoLast
    parent()->gotoLast();
}

void EditorAdaptor::gotoLastUnfiltered()
{
    // handle method call org.kde.Lokalize.Editor.gotoLastUnfiltered
    parent()->gotoLastUnfiltered();
}

void EditorAdaptor::gotoNext()
{
    // handle method call org.kde.Lokalize.Editor.gotoNext
    parent()->gotoNext();
}

void EditorAdaptor::gotoNextUnfiltered()
{
    // handle method call org.kde.Lokalize.Editor.gotoNextUnfiltered
    parent()->gotoNextUnfiltered();
}

void EditorAdaptor::gotoPrev()
{
    // handle method call org.kde.Lokalize.Editor.gotoPrev
    parent()->gotoPrev();
}

void EditorAdaptor::gotoPrevUnfiltered()
{
    // handle method call org.kde.Lokalize.Editor.gotoPrevUnfiltered
    parent()->gotoPrevUnfiltered();
}

bool EditorAdaptor::isValid()
{
    // handle method call org.kde.Lokalize.Editor.isValid
    return parent()->isValid();
}

void EditorAdaptor::openSyncSource(const QString &path)
{
    // handle method call org.kde.Lokalize.Editor.openSyncSource
    parent()->openSyncSource(path);
}

void EditorAdaptor::reloadFile()
{
    // handle method call org.kde.Lokalize.Editor.reloadFile
    parent()->reloadFile();
}

bool EditorAdaptor::saveFile()
{
    // handle method call org.kde.Lokalize.Editor.saveFile
    return parent()->saveFile();
}

bool EditorAdaptor::saveFileAs()
{
    // handle method call org.kde.Lokalize.Editor.saveFileAs
    return parent()->saveFileAs();
}

QString EditorAdaptor::selectionInSource()
{
    // handle method call org.kde.Lokalize.Editor.selectionInSource
    return parent()->selectionInSource();
}

QString EditorAdaptor::selectionInTarget()
{
    // handle method call org.kde.Lokalize.Editor.selectionInTarget
    return parent()->selectionInTarget();
}

void EditorAdaptor::setEntriesFilteredOut(bool filteredOut)
{
    // handle method call org.kde.Lokalize.Editor.setEntriesFilteredOut
    parent()->setEntriesFilteredOut(filteredOut);
}

void EditorAdaptor::setEntryFilteredOut(int entry, bool filteredOut)
{
    // handle method call org.kde.Lokalize.Editor.setEntryFilteredOut
    parent()->setEntryFilteredOut(entry, filteredOut);
}

void EditorAdaptor::setEntryTarget(int entry, int form, const QString &content)
{
    // handle method call org.kde.Lokalize.Editor.setEntryTarget
    parent()->setEntryTarget(entry, form, content);
}

void EditorAdaptor::setSrcFileOpenRequestAccepted(bool a)
{
    // handle method call org.kde.Lokalize.Editor.setSrcFileOpenRequestAccepted
    parent()->setSrcFileOpenRequestAccepted(a);
}

QString EditorAdaptor::sourceLangCode()
{
    // handle method call org.kde.Lokalize.Editor.sourceLangCode
    return parent()->sourceLangCode();
}

QString EditorAdaptor::targetLangCode()
{
    // handle method call org.kde.Lokalize.Editor.targetLangCode
    return parent()->targetLangCode();
}


#include "moc_editoradaptor.cpp"
