/****************************************************************************
** Meta object code from reading C++ file 'tmview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../lokalize-26.08.0/src/tm/tmview.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tmview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2TM6TMViewE_t {};
} // unnamed namespace

template <> constexpr inline auto TM::TMView::qt_create_metaobjectdata<qt_meta_tag_ZN2TM6TMViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TM::TMView",
        "refreshRequested",
        "",
        "textInsertRequested",
        "fileOpenRequested",
        "filePath",
        "str",
        "ctxt",
        "setAsActive",
        "slotNewEntryDisplayed",
        "DocPosition",
        "pos",
        "slotSuggestionsCame",
        "SelectJob*",
        "slotUseSuggestion",
        "slotRemoveSuggestion",
        "slotFileLoaded",
        "url",
        "displayFromCache",
        "slotBatchTranslate",
        "slotBatchTranslateFuzzy",
        "slotBatchSelectDone",
        "slotCacheSuggestions",
        "initLater",
        "contextMenu",
        "QPoint",
        "removeEntry",
        "TMEntry",
        "e"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'refreshRequested'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textInsertRequested'
        QtMocHelpers::SignalData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'fileOpenRequested'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &, const bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 6 }, { QMetaType::QString, 7 }, { QMetaType::Bool, 8 },
        }}),
        // Slot 'slotNewEntryDisplayed'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNewEntryDisplayed'
        QtMocHelpers::SlotData<void(const DocPosition &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'slotSuggestionsCame'
        QtMocHelpers::SlotData<void(SelectJob *)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
        // Slot 'slotUseSuggestion'
        QtMocHelpers::SlotData<void(int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotRemoveSuggestion'
        QtMocHelpers::SlotData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotFileLoaded'
        QtMocHelpers::SlotData<void(const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'displayFromCache'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotBatchTranslate'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotBatchTranslateFuzzy'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotBatchSelectDone'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCacheSuggestions'
        QtMocHelpers::SlotData<void(SelectJob *)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
        // Slot 'initLater'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'contextMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 25, 11 },
        }}),
        // Slot 'removeEntry'
        QtMocHelpers::SlotData<void(const TMEntry &)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TMView, qt_meta_tag_ZN2TM6TMViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TM::TMView::staticMetaObject = { {
    QMetaObject::SuperData::link<QDockWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2TM6TMViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2TM6TMViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2TM6TMViewE_t>.metaTypes,
    nullptr
} };

void TM::TMView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TMView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->refreshRequested(); break;
        case 1: _t->textInsertRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->fileOpenRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 3: _t->slotNewEntryDisplayed(); break;
        case 4: _t->slotNewEntryDisplayed((*reinterpret_cast<std::add_pointer_t<DocPosition>>(_a[1]))); break;
        case 5: _t->slotSuggestionsCame((*reinterpret_cast<std::add_pointer_t<SelectJob*>>(_a[1]))); break;
        case 6: _t->slotUseSuggestion((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->slotRemoveSuggestion((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->slotFileLoaded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->displayFromCache(); break;
        case 10: _t->slotBatchTranslate(); break;
        case 11: _t->slotBatchTranslateFuzzy(); break;
        case 12: _t->slotBatchSelectDone(); break;
        case 13: _t->slotCacheSuggestions((*reinterpret_cast<std::add_pointer_t<SelectJob*>>(_a[1]))); break;
        case 14: _t->initLater(); break;
        case 15: _t->contextMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 16: _t->removeEntry((*reinterpret_cast<std::add_pointer_t<TMEntry>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DocPosition >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TMView::*)()>(_a, &TMView::refreshRequested, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TMView::*)(const QString & )>(_a, &TMView::textInsertRequested, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TMView::*)(const QString & , const QString & , const QString & , const bool )>(_a, &TMView::fileOpenRequested, 2))
            return;
    }
}

const QMetaObject *TM::TMView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TM::TMView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2TM6TMViewE_t>.strings))
        return static_cast<void*>(this);
    return QDockWidget::qt_metacast(_clname);
}

int TM::TMView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDockWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void TM::TMView::refreshRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TM::TMView::textInsertRequested(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void TM::TMView::fileOpenRequested(const QString & _t1, const QString & _t2, const QString & _t3, const bool _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3, _t4);
}
namespace {
struct qt_meta_tag_ZN2TM29DoubleClickToInsertTextQLabelE_t {};
} // unnamed namespace

template <> constexpr inline auto TM::DoubleClickToInsertTextQLabel::qt_create_metaobjectdata<qt_meta_tag_ZN2TM29DoubleClickToInsertTextQLabelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TM::DoubleClickToInsertTextQLabel",
        "textInsertRequested",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'textInsertRequested'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DoubleClickToInsertTextQLabel, qt_meta_tag_ZN2TM29DoubleClickToInsertTextQLabelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TM::DoubleClickToInsertTextQLabel::staticMetaObject = { {
    QMetaObject::SuperData::link<QLabel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2TM29DoubleClickToInsertTextQLabelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2TM29DoubleClickToInsertTextQLabelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2TM29DoubleClickToInsertTextQLabelE_t>.metaTypes,
    nullptr
} };

void TM::DoubleClickToInsertTextQLabel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DoubleClickToInsertTextQLabel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->textInsertRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DoubleClickToInsertTextQLabel::*)(const QString & )>(_a, &DoubleClickToInsertTextQLabel::textInsertRequested, 0))
            return;
    }
}

const QMetaObject *TM::DoubleClickToInsertTextQLabel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TM::DoubleClickToInsertTextQLabel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2TM29DoubleClickToInsertTextQLabelE_t>.strings))
        return static_cast<void*>(this);
    return QLabel::qt_metacast(_clname);
}

int TM::DoubleClickToInsertTextQLabel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QLabel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void TM::DoubleClickToInsertTextQLabel::textInsertRequested(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
