/****************************************************************************
** Meta object code from reading C++ file 'mainwindowadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "mainwindowadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindowadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17MainWindowAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto MainWindowAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN17MainWindowAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MainWindowAdaptor",
        "D-Bus Interface",
        "org.kde.Lokalize.MainWindow",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.Lokalize.MainWindow\">\n    <signal na"
        "me=\"editorAdded\"/>\n    <signal name=\"editorActivated\"/>\n    "
        "<method name=\"openFileInEditor\">\n      <arg direction=\"out\" t"
        "ype=\"i\"/>\n      <arg direction=\"in\" type=\"s\" name=\"path\"/"
        ">\n    </method>\n    <method name=\"openFileInEditorAt\">\n      "
        "<arg direction=\"out\" type=\"i\"/>\n      <arg direction=\"in\" t"
        "ype=\"s\" name=\"path\"/>\n      <arg direction=\"in\" type=\"s\" "
        "name=\"source\"/>\n      <arg direction=\"in\" type=\"s\" name=\"c"
        "txt\"/>\n    </method>\n    <method name=\"showTranslationMemory\""
        ">\n      <arg direction=\"out\" type=\"i\"/>\n    </method>\n    <"
        "method name=\"showProjectOverview\"/>\n    <method name=\"openProj"
        "ect\">\n      <arg direction=\"in\" type=\"s\" name=\"path\"/>\n  "
        "  </method>\n    <method name=\"currentProject\">\n      <arg dire"
        "ction=\"out\" type=\"s\"/>\n    </method>\n    <method name=\"edit"
        "orIndexForFile\">\n      <arg direction=\"out\" type=\"i\"/>\n    "
        "  <arg direction=\"in\" type=\"s\" name=\"path\"/>\n    </method>\n"
        "    <method name=\"pid\">\n      <arg direction=\"out\" type=\"i\""
        "/>\n    </method>\n    <method name=\"dbusName\">\n      <arg dire"
        "ction=\"out\" type=\"s\"/>\n    </method>\n    <method name=\"busy"
        "Cursor\">\n      <arg direction=\"in\" type=\"b\" name=\"busy\"/>\n"
        "    </method>\n  </interface>\n",
        "editorActivated",
        "",
        "editorAdded",
        "busyCursor",
        "busy",
        "currentProject",
        "dbusName",
        "editorIndexForFile",
        "path",
        "openFileInEditor",
        "openFileInEditorAt",
        "source",
        "ctxt",
        "openProject",
        "pid",
        "showProjectOverview",
        "showTranslationMemory"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'editorActivated'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'editorAdded'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'busyCursor'
        QtMocHelpers::SlotData<void(bool)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Slot 'currentProject'
        QtMocHelpers::SlotData<QString()>(10, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'dbusName'
        QtMocHelpers::SlotData<QString()>(11, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'editorIndexForFile'
        QtMocHelpers::SlotData<int(const QString &)>(12, 6, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'openFileInEditor'
        QtMocHelpers::SlotData<int(const QString &)>(14, 6, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'openFileInEditorAt'
        QtMocHelpers::SlotData<int(const QString &, const QString &, const QString &)>(15, 6, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 13 }, { QMetaType::QString, 16 }, { QMetaType::QString, 17 },
        }}),
        // Slot 'openProject'
        QtMocHelpers::SlotData<void(const QString &)>(18, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'pid'
        QtMocHelpers::SlotData<int()>(19, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'showProjectOverview'
        QtMocHelpers::SlotData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showTranslationMemory'
        QtMocHelpers::SlotData<int()>(21, 6, QMC::AccessPublic, QMetaType::Int),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<MainWindowAdaptor, qt_meta_tag_ZN17MainWindowAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject MainWindowAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17MainWindowAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17MainWindowAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17MainWindowAdaptorE_t>.metaTypes,
    nullptr
} };

void MainWindowAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWindowAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->editorActivated(); break;
        case 1: _t->editorAdded(); break;
        case 2: _t->busyCursor((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: { QString _r = _t->currentProject();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { QString _r = _t->dbusName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { int _r = _t->editorIndexForFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 6: { int _r = _t->openFileInEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 7: { int _r = _t->openFileInEditorAt((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->openProject((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: { int _r = _t->pid();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->showProjectOverview(); break;
        case 11: { int _r = _t->showTranslationMemory();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MainWindowAdaptor::*)()>(_a, &MainWindowAdaptor::editorActivated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindowAdaptor::*)()>(_a, &MainWindowAdaptor::editorAdded, 1))
            return;
    }
}

const QMetaObject *MainWindowAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainWindowAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17MainWindowAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int MainWindowAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void MainWindowAdaptor::editorActivated()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MainWindowAdaptor::editorAdded()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
