/********************************************************************************
** Form generated from reading UI file 'prefs_pology.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFS_POLOGY_H
#define UI_PREFS_POLOGY_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_prefs_pology
{
public:
    QVBoxLayout *vboxLayout;
    QFormLayout *formLayout;
    QCheckBox *kcfg_PologyEnabled;
    QLabel *textLabel3_0;
    QPlainTextEdit *kcfg_PologyCommandEntry;
    QLabel *textLabel4_0;
    QPlainTextEdit *kcfg_PologyCommandFile;

    void setupUi(QWidget *prefs_pology)
    {
        if (prefs_pology->objectName().isEmpty())
            prefs_pology->setObjectName("prefs_pology");
        prefs_pology->resize(611, 439);
        vboxLayout = new QVBoxLayout(prefs_pology);
        vboxLayout->setObjectName("vboxLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        kcfg_PologyEnabled = new QCheckBox(prefs_pology);
        kcfg_PologyEnabled->setObjectName("kcfg_PologyEnabled");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, kcfg_PologyEnabled);

        textLabel3_0 = new QLabel(prefs_pology);
        textLabel3_0->setObjectName("textLabel3_0");
        textLabel3_0->setWordWrap(true);

        formLayout->setWidget(1, QFormLayout::ItemRole::SpanningRole, textLabel3_0);

        kcfg_PologyCommandEntry = new QPlainTextEdit(prefs_pology);
        kcfg_PologyCommandEntry->setObjectName("kcfg_PologyCommandEntry");
        kcfg_PologyCommandEntry->setMaximumSize(QSize(611, 100));

        formLayout->setWidget(2, QFormLayout::ItemRole::SpanningRole, kcfg_PologyCommandEntry);

        textLabel4_0 = new QLabel(prefs_pology);
        textLabel4_0->setObjectName("textLabel4_0");
        textLabel4_0->setWordWrap(true);

        formLayout->setWidget(3, QFormLayout::ItemRole::SpanningRole, textLabel4_0);

        kcfg_PologyCommandFile = new QPlainTextEdit(prefs_pology);
        kcfg_PologyCommandFile->setObjectName("kcfg_PologyCommandFile");
        kcfg_PologyCommandFile->setMaximumSize(QSize(611, 100));

        formLayout->setWidget(4, QFormLayout::ItemRole::SpanningRole, kcfg_PologyCommandFile);


        vboxLayout->addLayout(formLayout);


        retranslateUi(prefs_pology);

        QMetaObject::connectSlotsByName(prefs_pology);
    } // setupUi

    void retranslateUi(QWidget *prefs_pology)
    {
        kcfg_PologyEnabled->setText(tr2i18n("Enable Pology verification", nullptr));
        textLabel3_0->setText(tr2i18n("The Pology command to run in order to check a single entry. Use the following placeholders in order to set-up the commands: %u is the entry number, %f is the file name. For instance: posieve -u %u check-rules %f", "@label:textbox"));
#if QT_CONFIG(tooltip)
        kcfg_PologyCommandEntry->setToolTip(tr2i18n("The Pology command to run in order to check a single entry.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_PologyCommandEntry->setWhatsThis(tr2i18n("Please enter here the Pology command to be run in order to check a single entry", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel4_0->setText(tr2i18n("The Pology command to run in order to check a whole file. This command should include \"-s lokalize\", placeholder %f is the file name. For instance: posieve -s lokalize check-rules %f", "@label:textbox"));
#if QT_CONFIG(tooltip)
        kcfg_PologyCommandFile->setToolTip(tr2i18n("The Pology command to run in order to check a whole file.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_PologyCommandFile->setWhatsThis(tr2i18n("Please enter here the Pology command to be run in order to check a whole file", nullptr));
#endif // QT_CONFIG(whatsthis)
        (void)prefs_pology;
    } // retranslateUi

};

namespace Ui {
    class prefs_pology: public Ui_prefs_pology {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PREFS_POLOGY_H

