/****************************************************************************
** Meta object code from reading C++ file 'lokalizemainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../lokalize-26.08.0/src/lokalizemainwindow.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'lokalizemainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18LokalizeMainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto LokalizeMainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN18LokalizeMainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LokalizeMainWindow",
        "D-Bus Interface",
        "org.kde.Lokalize.MainWindow",
        "editorAdded",
        "",
        "editorActivated",
        "initLater",
        "projectLoaded",
        "projectSettingsChanged",
        "openProject",
        "QUrl",
        "url",
        "showTabs",
        "showWelcome",
        "queryCloseAllTabs",
        "queryCloseTabByPageWidget",
        "QWidget*",
        "widget",
        "queryCloseTabAtIndex",
        "index",
        "queryAndCloseTabAtIndex",
        "queryAndCloseCurrentTab",
        "queryAndCloseAllEditorTabs",
        "saveAllEditorTabs",
        "revertAllEditorTabs",
        "closeTabByPageWidget",
        "closeTabAtIndex",
        "closeCurrentTab",
        "openFileInEditor",
        "path",
        "openFileInEditorAt",
        "source",
        "ctxt",
        "lookupInTranslationMemory",
        "DocPosition::Part",
        "part",
        "text",
        "target",
        "showTranslationMemory",
        "showProjectOverview",
        "projectOverview",
        "queryAndCloseProject",
        "closeProject",
        "currentProject",
        "activeEditor",
        "editorForFile",
        "editorIndexForFile",
        "pid",
        "dbusName",
        "busyCursor",
        "busy",
        "fileOpen_",
        "EditorTab*",
        "setAsActive",
        "fileOpen",
        "entry",
        "mergeFile",
        "silent",
        "DocPosition",
        "docPos",
        "selection",
        "showTM",
        "TM::TMTab*",
        "showFileSearch",
        "FileSearchTab*",
        "activate",
        "showGlossary",
        "GlossaryNS::GlossaryTab*",
        "selectGlossaryEntry",
        "showFileSearchAction",
        "fileSearchNext",
        "addFilesToSearch",
        "activateTabAtIndex",
        "i",
        "activateTabByPageWidget",
        "w",
        "activateTabToLeftOfCurrent",
        "activateTabToRightOfCurrent",
        "activatePreviousTab",
        "setActiveGuiClient",
        "KXMLGUIClient*",
        "newClient",
        "updateTabDetailsByPageWidget",
        "LokalizeTabPageBase*",
        "pageWidget",
        "updateTabIconByPageWidget",
        "LokalizeTabPageBaseNoQMainWindow*",
        "widgetTextCapture"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'editorAdded'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Signal 'editorActivated'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'initLater'
        QtMocHelpers::SlotData<void()>(6, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'projectLoaded'
        QtMocHelpers::SlotData<void()>(7, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'projectSettingsChanged'
        QtMocHelpers::SlotData<void()>(8, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openProject'
        QtMocHelpers::SlotData<void(const QUrl &)>(9, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'openProject'
        QtMocHelpers::SlotData<void()>(9, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showTabs'
        QtMocHelpers::SlotData<void()>(12, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showWelcome'
        QtMocHelpers::SlotData<void()>(13, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'queryCloseAllTabs'
        QtMocHelpers::SlotData<bool()>(14, 4, QMC::AccessPrivate, QMetaType::Bool),
        // Slot 'queryCloseTabByPageWidget'
        QtMocHelpers::SlotData<bool(QWidget *)>(15, 4, QMC::AccessPrivate, QMetaType::Bool, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'queryCloseTabAtIndex'
        QtMocHelpers::SlotData<bool(int)>(18, 4, QMC::AccessPrivate, QMetaType::Bool, {{
            { QMetaType::Int, 19 },
        }}),
        // Slot 'queryAndCloseTabAtIndex'
        QtMocHelpers::SlotData<void(int)>(20, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Slot 'queryAndCloseCurrentTab'
        QtMocHelpers::SlotData<void()>(21, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'queryAndCloseAllEditorTabs'
        QtMocHelpers::SlotData<void()>(22, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveAllEditorTabs'
        QtMocHelpers::SlotData<void()>(23, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'revertAllEditorTabs'
        QtMocHelpers::SlotData<void()>(24, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'closeTabByPageWidget'
        QtMocHelpers::SlotData<void(QWidget *)>(25, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'closeTabAtIndex'
        QtMocHelpers::SlotData<void(int)>(26, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Slot 'closeCurrentTab'
        QtMocHelpers::SlotData<void()>(27, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openFileInEditor'
        QtMocHelpers::SlotData<int(const QString &)>(28, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int, {{
            { QMetaType::QString, 29 },
        }}),
        // Slot 'openFileInEditorAt'
        QtMocHelpers::SlotData<int(const QString &, const QString &, const QString &)>(30, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int, {{
            { QMetaType::QString, 29 }, { QMetaType::QString, 31 }, { QMetaType::QString, 32 },
        }}),
        // Slot 'lookupInTranslationMemory'
        QtMocHelpers::SlotData<int(DocPosition::Part, const QString &)>(33, 4, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 34, 35 }, { QMetaType::QString, 36 },
        }}),
        // Slot 'lookupInTranslationMemory'
        QtMocHelpers::SlotData<int(const QString &, const QString &)>(33, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int, {{
            { QMetaType::QString, 31 }, { QMetaType::QString, 37 },
        }}),
        // Slot 'showTranslationMemory'
        QtMocHelpers::SlotData<int()>(38, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'showProjectOverview'
        QtMocHelpers::SlotData<void()>(39, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'projectOverview'
        QtMocHelpers::SlotData<QObject *()>(40, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QObjectStar),
        // Slot 'queryAndCloseProject'
        QtMocHelpers::SlotData<bool()>(41, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'closeProject'
        QtMocHelpers::SlotData<void()>(42, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'openProject'
        QtMocHelpers::SlotData<void(QString)>(9, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 29 },
        }}),
        // Slot 'currentProject'
        QtMocHelpers::SlotData<QString()>(43, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'activeEditor'
        QtMocHelpers::SlotData<QObject *()>(44, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QObjectStar),
        // Slot 'editorForFile'
        QtMocHelpers::SlotData<QObject *(const QString &)>(45, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QObjectStar, {{
            { QMetaType::QString, 29 },
        }}),
        // Slot 'editorIndexForFile'
        QtMocHelpers::SlotData<int(const QString &)>(46, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int, {{
            { QMetaType::QString, 29 },
        }}),
        // Slot 'pid'
        QtMocHelpers::SlotData<int()>(47, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Slot 'dbusName'
        QtMocHelpers::SlotData<QString()>(48, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'busyCursor'
        QtMocHelpers::SlotData<void(bool)>(49, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 50 },
        }}),
        // Slot 'fileOpen_'
        QtMocHelpers::SlotData<EditorTab *(QString, const bool)>(51, 4, QMC::AccessPublic, 0x80000000 | 52, {{
            { QMetaType::QString, 11 }, { QMetaType::Bool, 53 },
        }}),
        // Slot 'fileOpen'
        QtMocHelpers::SlotData<EditorTab *(QString, int, bool, const QString &, bool)>(54, 4, QMC::AccessPublic, 0x80000000 | 52, {{
            { QMetaType::QString, 11 }, { QMetaType::Int, 55 }, { QMetaType::Bool, 53 }, { QMetaType::QString, 56 },
            { QMetaType::Bool, 57 },
        }}),
        // Slot 'fileOpen'
        QtMocHelpers::SlotData<EditorTab *(QString, int, bool, const QString &)>(54, 4, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 52, {{
            { QMetaType::QString, 11 }, { QMetaType::Int, 55 }, { QMetaType::Bool, 53 }, { QMetaType::QString, 56 },
        }}),
        // Slot 'fileOpen'
        QtMocHelpers::SlotData<EditorTab *(QString, int, bool)>(54, 4, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 52, {{
            { QMetaType::QString, 11 }, { QMetaType::Int, 55 }, { QMetaType::Bool, 53 },
        }}),
        // Slot 'fileOpen'
        QtMocHelpers::SlotData<EditorTab *(QString, int)>(54, 4, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 52, {{
            { QMetaType::QString, 11 }, { QMetaType::Int, 55 },
        }}),
        // Slot 'fileOpen'
        QtMocHelpers::SlotData<EditorTab *(QString)>(54, 4, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 52, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'fileOpen'
        QtMocHelpers::SlotData<EditorTab *()>(54, 4, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 52),
        // Slot 'fileOpen'
        QtMocHelpers::SlotData<EditorTab *(const QString &, const QString &, const QString &, const bool)>(54, 4, QMC::AccessPublic, 0x80000000 | 52, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 31 }, { QMetaType::QString, 32 }, { QMetaType::Bool, 53 },
        }}),
        // Slot 'fileOpen'
        QtMocHelpers::SlotData<EditorTab *(const QString &, DocPosition, int, const bool)>(54, 4, QMC::AccessPublic, 0x80000000 | 52, {{
            { QMetaType::QString, 11 }, { 0x80000000 | 58, 59 }, { QMetaType::Int, 60 }, { QMetaType::Bool, 53 },
        }}),
        // Slot 'fileOpen'
        QtMocHelpers::SlotData<EditorTab *(const QUrl &)>(54, 4, QMC::AccessPublic, 0x80000000 | 52, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'showTM'
        QtMocHelpers::SlotData<TM::TMTab *()>(61, 4, QMC::AccessPublic, 0x80000000 | 62),
        // Slot 'showFileSearch'
        QtMocHelpers::SlotData<FileSearchTab *(bool)>(63, 4, QMC::AccessPublic, 0x80000000 | 64, {{
            { QMetaType::Bool, 65 },
        }}),
        // Slot 'showFileSearch'
        QtMocHelpers::SlotData<FileSearchTab *()>(63, 4, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 64),
        // Slot 'showGlossary'
        QtMocHelpers::SlotData<GlossaryNS::GlossaryTab *()>(66, 4, QMC::AccessPublic, 0x80000000 | 67),
        // Slot 'selectGlossaryEntry'
        QtMocHelpers::SlotData<void(const QByteArray &)>(68, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 4 },
        }}),
        // Slot 'showFileSearchAction'
        QtMocHelpers::SlotData<void()>(69, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'fileSearchNext'
        QtMocHelpers::SlotData<void()>(70, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addFilesToSearch'
        QtMocHelpers::SlotData<void(const QStringList &)>(71, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 4 },
        }}),
        // Slot 'activateTabAtIndex'
        QtMocHelpers::SlotData<void(int)>(72, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 73 },
        }}),
        // Slot 'activateTabByPageWidget'
        QtMocHelpers::SlotData<void(QWidget *)>(74, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 75 },
        }}),
        // Slot 'activateTabToLeftOfCurrent'
        QtMocHelpers::SlotData<void()>(76, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'activateTabToRightOfCurrent'
        QtMocHelpers::SlotData<void()>(77, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'activatePreviousTab'
        QtMocHelpers::SlotData<void()>(78, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setActiveGuiClient'
        QtMocHelpers::SlotData<void(KXMLGUIClient *)>(79, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 80, 81 },
        }}),
        // Slot 'updateTabDetailsByPageWidget'
        QtMocHelpers::SlotData<void(LokalizeTabPageBase *)>(82, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 83, 84 },
        }}),
        // Slot 'updateTabIconByPageWidget'
        QtMocHelpers::SlotData<void(LokalizeTabPageBaseNoQMainWindow *)>(85, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 86, 84 },
        }}),
        // Slot 'widgetTextCapture'
        QtMocHelpers::SlotData<void()>(87, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<LokalizeMainWindow, qt_meta_tag_ZN18LokalizeMainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject LokalizeMainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<KXmlGuiWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18LokalizeMainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18LokalizeMainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18LokalizeMainWindowE_t>.metaTypes,
    nullptr
} };

void LokalizeMainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LokalizeMainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->editorAdded(); break;
        case 1: _t->editorActivated(); break;
        case 2: _t->initLater(); break;
        case 3: _t->projectLoaded(); break;
        case 4: _t->projectSettingsChanged(); break;
        case 5: _t->openProject((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 6: _t->openProject(); break;
        case 7: _t->showTabs(); break;
        case 8: _t->showWelcome(); break;
        case 9: { bool _r = _t->queryCloseAllTabs();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->queryCloseTabByPageWidget((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->queryCloseTabAtIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->queryAndCloseTabAtIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->queryAndCloseCurrentTab(); break;
        case 14: _t->queryAndCloseAllEditorTabs(); break;
        case 15: _t->saveAllEditorTabs(); break;
        case 16: _t->revertAllEditorTabs(); break;
        case 17: _t->closeTabByPageWidget((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1]))); break;
        case 18: _t->closeTabAtIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->closeCurrentTab(); break;
        case 20: { int _r = _t->openFileInEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 21: { int _r = _t->openFileInEditorAt((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 22: { int _r = _t->lookupInTranslationMemory((*reinterpret_cast<std::add_pointer_t<DocPosition::Part>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 23: { int _r = _t->lookupInTranslationMemory((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 24: { int _r = _t->showTranslationMemory();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 25: _t->showProjectOverview(); break;
        case 26: { QObject* _r = _t->projectOverview();
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = std::move(_r); }  break;
        case 27: { bool _r = _t->queryAndCloseProject();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 28: _t->closeProject(); break;
        case 29: _t->openProject((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 30: { QString _r = _t->currentProject();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 31: { QObject* _r = _t->activeEditor();
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = std::move(_r); }  break;
        case 32: { QObject* _r = _t->editorForFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = std::move(_r); }  break;
        case 33: { int _r = _t->editorIndexForFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 34: { int _r = _t->pid();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 35: { QString _r = _t->dbusName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 36: _t->busyCursor((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 37: { EditorTab* _r = _t->fileOpen_((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<EditorTab**>(_a[0]) = std::move(_r); }  break;
        case 38: { EditorTab* _r = _t->fileOpen((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])));
            if (_a[0]) *reinterpret_cast<EditorTab**>(_a[0]) = std::move(_r); }  break;
        case 39: { EditorTab* _r = _t->fileOpen((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<EditorTab**>(_a[0]) = std::move(_r); }  break;
        case 40: { EditorTab* _r = _t->fileOpen((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<EditorTab**>(_a[0]) = std::move(_r); }  break;
        case 41: { EditorTab* _r = _t->fileOpen((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<EditorTab**>(_a[0]) = std::move(_r); }  break;
        case 42: { EditorTab* _r = _t->fileOpen((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<EditorTab**>(_a[0]) = std::move(_r); }  break;
        case 43: { EditorTab* _r = _t->fileOpen();
            if (_a[0]) *reinterpret_cast<EditorTab**>(_a[0]) = std::move(_r); }  break;
        case 44: { EditorTab* _r = _t->fileOpen((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])));
            if (_a[0]) *reinterpret_cast<EditorTab**>(_a[0]) = std::move(_r); }  break;
        case 45: { EditorTab* _r = _t->fileOpen((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<DocPosition>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])));
            if (_a[0]) *reinterpret_cast<EditorTab**>(_a[0]) = std::move(_r); }  break;
        case 46: { EditorTab* _r = _t->fileOpen((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<EditorTab**>(_a[0]) = std::move(_r); }  break;
        case 47: { TM::TMTab* _r = _t->showTM();
            if (_a[0]) *reinterpret_cast<TM::TMTab**>(_a[0]) = std::move(_r); }  break;
        case 48: { FileSearchTab* _r = _t->showFileSearch((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<FileSearchTab**>(_a[0]) = std::move(_r); }  break;
        case 49: { FileSearchTab* _r = _t->showFileSearch();
            if (_a[0]) *reinterpret_cast<FileSearchTab**>(_a[0]) = std::move(_r); }  break;
        case 50: { GlossaryNS::GlossaryTab* _r = _t->showGlossary();
            if (_a[0]) *reinterpret_cast<GlossaryNS::GlossaryTab**>(_a[0]) = std::move(_r); }  break;
        case 51: _t->selectGlossaryEntry((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 52: _t->showFileSearchAction(); break;
        case 53: _t->fileSearchNext(); break;
        case 54: _t->addFilesToSearch((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 55: _t->activateTabAtIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 56: _t->activateTabByPageWidget((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1]))); break;
        case 57: _t->activateTabToLeftOfCurrent(); break;
        case 58: _t->activateTabToRightOfCurrent(); break;
        case 59: _t->activatePreviousTab(); break;
        case 60: _t->setActiveGuiClient((*reinterpret_cast<std::add_pointer_t<KXMLGUIClient*>>(_a[1]))); break;
        case 61: _t->updateTabDetailsByPageWidget((*reinterpret_cast<std::add_pointer_t<LokalizeTabPageBase*>>(_a[1]))); break;
        case 62: _t->updateTabIconByPageWidget((*reinterpret_cast<std::add_pointer_t<LokalizeTabPageBaseNoQMainWindow*>>(_a[1]))); break;
        case 63: _t->widgetTextCapture(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 45:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DocPosition >(); break;
            }
            break;
        case 56:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 61:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< LokalizeTabPageBase* >(); break;
            }
            break;
        case 62:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< LokalizeTabPageBaseNoQMainWindow* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (LokalizeMainWindow::*)()>(_a, &LokalizeMainWindow::editorAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (LokalizeMainWindow::*)()>(_a, &LokalizeMainWindow::editorActivated, 1))
            return;
    }
}

const QMetaObject *LokalizeMainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LokalizeMainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18LokalizeMainWindowE_t>.strings))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int LokalizeMainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 64)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 64;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 64)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 64;
    }
    return _id;
}

// SIGNAL 0
void LokalizeMainWindow::editorAdded()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void LokalizeMainWindow::editorActivated()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
namespace {
struct qt_meta_tag_ZN17DelayedFileOpenerE_t {};
} // unnamed namespace

template <> constexpr inline auto DelayedFileOpener::qt_create_metaobjectdata<qt_meta_tag_ZN17DelayedFileOpenerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DelayedFileOpener",
        "doOpen",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'doOpen'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DelayedFileOpener, qt_meta_tag_ZN17DelayedFileOpenerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DelayedFileOpener::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DelayedFileOpenerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DelayedFileOpenerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17DelayedFileOpenerE_t>.metaTypes,
    nullptr
} };

void DelayedFileOpener::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DelayedFileOpener *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->doOpen(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *DelayedFileOpener::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DelayedFileOpener::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DelayedFileOpenerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DelayedFileOpener::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
