/****************************************************************************
** Meta object code from reading C++ file 'editoradaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "editoradaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'editoradaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13EditorAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto EditorAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN13EditorAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EditorAdaptor",
        "D-Bus Interface",
        "org.kde.Lokalize.Editor",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.Lokalize.Editor\">\n    <signal name=\""
        "srcFileOpenRequested\">\n      <arg direction=\"out\" type=\"s\" n"
        "ame=\"srcPath\"/>\n      <arg direction=\"out\" type=\"i\" name=\""
        "line\"/>\n    </signal>\n    <signal name=\"fileClosed\">\n      <"
        "arg direction=\"out\" type=\"s\" name=\"path\"/>\n    </signal>\n "
        "   <signal name=\"fileSaved\">\n      <arg direction=\"out\" type="
        "\"s\" name=\"path\"/>\n    </signal>\n    <signal name=\"fileAbout"
        "ToBeClosed\"/>\n    <signal name=\"fileOpened\"/>\n    <signal nam"
        "e=\"entryDisplayed\"/>\n    <method name=\"gotoEntry\">\n      <ar"
        "g direction=\"in\" type=\"i\" name=\"entry\"/>\n    </method>\n   "
        " <method name=\"gotoEntryForm\">\n      <arg direction=\"in\" type"
        "=\"i\" name=\"entry\"/>\n      <arg direction=\"in\" type=\"i\" na"
        "me=\"form\"/>\n    </method>\n    <method name=\"gotoEntryFormOffs"
        "et\">\n      <arg direction=\"in\" type=\"i\" name=\"entry\"/>\n  "
        "    <arg direction=\"in\" type=\"i\" name=\"form\"/>\n      <arg d"
        "irection=\"in\" type=\"i\" name=\"offset\"/>\n    </method>\n    <"
        "method name=\"gotoEntryFormOffsetSelection\">\n      <arg directio"
        "n=\"in\" type=\"i\" name=\"entry\"/>\n      <arg direction=\"in\" "
        "type=\"i\" name=\"form\"/>\n      <arg direction=\"in\" type=\"i\""
        " name=\"offset\"/>\n      <arg direction=\"in\" type=\"i\" name=\""
        "selection\"/>\n    </method>\n    <method name=\"currentEntryId\">"
        "\n      <arg direction=\"out\" type=\"s\"/>\n    </method>\n    <m"
        "ethod name=\"currentEntry\">\n      <arg direction=\"out\" type=\""
        "i\"/>\n    </method>\n    <method name=\"currentForm\">\n      <ar"
        "g direction=\"out\" type=\"i\"/>\n    </method>\n    <method name="
        "\"selectionInTarget\">\n      <arg direction=\"out\" type=\"s\"/>\n"
        "    </method>\n    <method name=\"selectionInSource\">\n      <arg"
        " direction=\"out\" type=\"s\"/>\n    </method>\n    <method name=\""
        "setEntryFilteredOut\">\n      <arg direction=\"in\" type=\"i\" nam"
        "e=\"entry\"/>\n      <arg direction=\"in\" type=\"b\" name=\"filte"
        "redOut\"/>\n    </method>\n    <method name=\"setEntriesFilteredOu"
        "t\">\n      <arg direction=\"in\" type=\"b\" name=\"filteredOut\"/"
        ">\n    </method>\n    <method name=\"entryCount\">\n      <arg dir"
        "ection=\"out\" type=\"i\"/>\n    </method>\n    <method name=\"ent"
        "rySource\">\n      <arg direction=\"out\" type=\"s\"/>\n      <arg"
        " direction=\"in\" type=\"i\" name=\"entry\"/>\n      <arg directio"
        "n=\"in\" type=\"i\" name=\"form\"/>\n    </method>\n    <method na"
        "me=\"entryTarget\">\n      <arg direction=\"out\" type=\"s\"/>\n  "
        "    <arg direction=\"in\" type=\"i\" name=\"entry\"/>\n      <arg "
        "direction=\"in\" type=\"i\" name=\"form\"/>\n    </method>\n    <m"
        "ethod name=\"setEntryTarget\">\n      <arg direction=\"in\" type=\""
        "i\" name=\"entry\"/>\n      <arg direction=\"in\" type=\"i\" name="
        "\"form\"/>\n      <arg direction=\"in\" type=\"s\" name=\"content\""
        "/>\n    </method>\n    <method name=\"entryPluralFormCount\">\n   "
        "   <arg direction=\"out\" type=\"i\"/>\n      <arg direction=\"in\""
        " type=\"i\" name=\"entry\"/>\n    </method>\n    <method name=\"en"
        "tryReady\">\n      <arg direction=\"out\" type=\"b\"/>\n      <arg"
        " direction=\"in\" type=\"i\" name=\"entry\"/>\n    </method>\n    "
        "<method name=\"addEntryNote\">\n      <arg direction=\"in\" type=\""
        "i\" name=\"entry\"/>\n      <arg direction=\"in\" type=\"s\" name="
        "\"note\"/>\n    </method>\n    <method name=\"addTemporaryEntryNot"
        "e\">\n      <arg direction=\"in\" type=\"i\" name=\"entry\"/>\n   "
        "   <arg direction=\"in\" type=\"s\" name=\"note\"/>\n    </method>"
        "\n    <method name=\"addAlternateTranslation\">\n      <arg direct"
        "ion=\"in\" type=\"i\" name=\"entry\"/>\n      <arg direction=\"in\""
        " type=\"s\" name=\"translation\"/>\n    </method>\n    <method nam"
        "e=\"addTemporaryAlternateTranslation\">\n      <arg direction=\"in"
        "\" type=\"i\" name=\"entry\"/>\n      <arg direction=\"in\" type=\""
        "s\" name=\"translation\"/>\n    </method>\n    <method name=\"curr"
        "entFile\">\n      <arg direction=\"out\" type=\"s\"/>\n    </metho"
        "d>\n    <method name=\"currentFileContents\">\n      <arg directio"
        "n=\"out\" type=\"ay\"/>\n    </method>\n    <method name=\"sourceL"
        "angCode\">\n      <arg direction=\"out\" type=\"s\"/>\n    </metho"
        "d>\n    <method name=\"targetLangCode\">\n      <arg direction=\"o"
        "ut\" type=\"s\"/>\n    </method>\n    <method name=\"attachAlterna"
        "teTranslationFile\">\n      <arg direction=\"in\" type=\"s\" name="
        "\"path\"/>\n    </method>\n    <method name=\"openSyncSource\">\n "
        "     <arg direction=\"in\" type=\"s\" name=\"path\"/>\n    </metho"
        "d>\n    <method name=\"reloadFile\"/>\n    <method name=\"saveFile"
        "\">\n      <arg direction=\"out\" type=\"b\"/>\n    </method>\n   "
        " <method name=\"saveFileAs\">\n      <arg direction=\"out\" type=\""
        "b\"/>\n    </method>\n    <method name=\"close\"/>\n    <method na"
        "me=\"gotoNextUnfiltered\"/>\n    <method name=\"gotoPrevUnfiltered"
        "\"/>\n    <method name=\"gotoFirstUnfiltered\"/>\n    <method name"
        "=\"gotoLastUnfiltered\"/>\n    <method name=\"gotoNext\"/>\n    <m"
        "ethod name=\"gotoPrev\"/>\n    <method name=\"gotoFirst\"/>\n    <"
        "method name=\"gotoLast\"/>\n    <method name=\"findEntryBySourceCo"
        "ntext\">\n      <arg direction=\"out\" type=\"b\"/>\n      <arg di"
        "rection=\"in\" type=\"s\" name=\"source\"/>\n      <arg direction="
        "\"in\" type=\"s\" name=\"ctxt\"/>\n    </method>\n    <method name"
        "=\"isValid\">\n      <arg direction=\"out\" type=\"b\"/>\n    </me"
        "thod>\n    <method name=\"setSrcFileOpenRequestAccepted\">\n      "
        "<arg direction=\"in\" type=\"b\" name=\"a\"/>\n    </method>\n  </"
        "interface>\n",
        "entryDisplayed",
        "",
        "fileAboutToBeClosed",
        "fileClosed",
        "path",
        "fileOpened",
        "fileSaved",
        "srcFileOpenRequested",
        "srcPath",
        "line",
        "addAlternateTranslation",
        "entry",
        "translation",
        "addEntryNote",
        "note",
        "addTemporaryAlternateTranslation",
        "addTemporaryEntryNote",
        "attachAlternateTranslationFile",
        "close",
        "currentEntry",
        "currentEntryId",
        "currentFile",
        "currentFileContents",
        "currentForm",
        "entryCount",
        "entryPluralFormCount",
        "entryReady",
        "entrySource",
        "form",
        "entryTarget",
        "findEntryBySourceContext",
        "source",
        "ctxt",
        "gotoEntry",
        "gotoEntryForm",
        "gotoEntryFormOffset",
        "offset",
        "gotoEntryFormOffsetSelection",
        "selection",
        "gotoFirst",
        "gotoFirstUnfiltered",
        "gotoLast",
        "gotoLastUnfiltered",
        "gotoNext",
        "gotoNextUnfiltered",
        "gotoPrev",
        "gotoPrevUnfiltered",
        "isValid",
        "openSyncSource",
        "reloadFile",
        "saveFile",
        "saveFileAs",
        "selectionInSource",
        "selectionInTarget",
        "setEntriesFilteredOut",
        "filteredOut",
        "setEntryFilteredOut",
        "setEntryTarget",
        "content",
        "setSrcFileOpenRequestAccepted",
        "a",
        "sourceLangCode",
        "targetLangCode"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'entryDisplayed'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fileAboutToBeClosed'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fileClosed'
        QtMocHelpers::SignalData<void(const QString &)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'fileOpened'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fileSaved'
        QtMocHelpers::SignalData<void(const QString &)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'srcFileOpenRequested'
        QtMocHelpers::SignalData<void(const QString &, int)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 }, { QMetaType::Int, 14 },
        }}),
        // Slot 'addAlternateTranslation'
        QtMocHelpers::SlotData<void(int, const QString &)>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 }, { QMetaType::QString, 17 },
        }}),
        // Slot 'addEntryNote'
        QtMocHelpers::SlotData<void(int, const QString &)>(18, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 }, { QMetaType::QString, 19 },
        }}),
        // Slot 'addTemporaryAlternateTranslation'
        QtMocHelpers::SlotData<void(int, const QString &)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 }, { QMetaType::QString, 17 },
        }}),
        // Slot 'addTemporaryEntryNote'
        QtMocHelpers::SlotData<void(int, const QString &)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 }, { QMetaType::QString, 19 },
        }}),
        // Slot 'attachAlternateTranslationFile'
        QtMocHelpers::SlotData<void(const QString &)>(22, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'close'
        QtMocHelpers::SlotData<void()>(23, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'currentEntry'
        QtMocHelpers::SlotData<int()>(24, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'currentEntryId'
        QtMocHelpers::SlotData<QString()>(25, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'currentFile'
        QtMocHelpers::SlotData<QString()>(26, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'currentFileContents'
        QtMocHelpers::SlotData<QByteArray()>(27, 6, QMC::AccessPublic, QMetaType::QByteArray),
        // Slot 'currentForm'
        QtMocHelpers::SlotData<int()>(28, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'entryCount'
        QtMocHelpers::SlotData<int()>(29, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'entryPluralFormCount'
        QtMocHelpers::SlotData<int(int)>(30, 6, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'entryReady'
        QtMocHelpers::SlotData<bool(int)>(31, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'entrySource'
        QtMocHelpers::SlotData<QString(int, int)>(32, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 16 }, { QMetaType::Int, 33 },
        }}),
        // Slot 'entryTarget'
        QtMocHelpers::SlotData<QString(int, int)>(34, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 16 }, { QMetaType::Int, 33 },
        }}),
        // Slot 'findEntryBySourceContext'
        QtMocHelpers::SlotData<bool(const QString &, const QString &)>(35, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 36 }, { QMetaType::QString, 37 },
        }}),
        // Slot 'gotoEntry'
        QtMocHelpers::SlotData<void(int)>(38, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'gotoEntryForm'
        QtMocHelpers::SlotData<void(int, int)>(39, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 }, { QMetaType::Int, 33 },
        }}),
        // Slot 'gotoEntryFormOffset'
        QtMocHelpers::SlotData<void(int, int, int)>(40, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 }, { QMetaType::Int, 33 }, { QMetaType::Int, 41 },
        }}),
        // Slot 'gotoEntryFormOffsetSelection'
        QtMocHelpers::SlotData<void(int, int, int, int)>(42, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 }, { QMetaType::Int, 33 }, { QMetaType::Int, 41 }, { QMetaType::Int, 43 },
        }}),
        // Slot 'gotoFirst'
        QtMocHelpers::SlotData<void()>(44, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'gotoFirstUnfiltered'
        QtMocHelpers::SlotData<void()>(45, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'gotoLast'
        QtMocHelpers::SlotData<void()>(46, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'gotoLastUnfiltered'
        QtMocHelpers::SlotData<void()>(47, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'gotoNext'
        QtMocHelpers::SlotData<void()>(48, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'gotoNextUnfiltered'
        QtMocHelpers::SlotData<void()>(49, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'gotoPrev'
        QtMocHelpers::SlotData<void()>(50, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'gotoPrevUnfiltered'
        QtMocHelpers::SlotData<void()>(51, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'isValid'
        QtMocHelpers::SlotData<bool()>(52, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'openSyncSource'
        QtMocHelpers::SlotData<void(const QString &)>(53, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'reloadFile'
        QtMocHelpers::SlotData<void()>(54, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveFile'
        QtMocHelpers::SlotData<bool()>(55, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'saveFileAs'
        QtMocHelpers::SlotData<bool()>(56, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'selectionInSource'
        QtMocHelpers::SlotData<QString()>(57, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'selectionInTarget'
        QtMocHelpers::SlotData<QString()>(58, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'setEntriesFilteredOut'
        QtMocHelpers::SlotData<void(bool)>(59, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 60 },
        }}),
        // Slot 'setEntryFilteredOut'
        QtMocHelpers::SlotData<void(int, bool)>(61, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 }, { QMetaType::Bool, 60 },
        }}),
        // Slot 'setEntryTarget'
        QtMocHelpers::SlotData<void(int, int, const QString &)>(62, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 }, { QMetaType::Int, 33 }, { QMetaType::QString, 63 },
        }}),
        // Slot 'setSrcFileOpenRequestAccepted'
        QtMocHelpers::SlotData<void(bool)>(64, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 65 },
        }}),
        // Slot 'sourceLangCode'
        QtMocHelpers::SlotData<QString()>(66, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'targetLangCode'
        QtMocHelpers::SlotData<QString()>(67, 6, QMC::AccessPublic, QMetaType::QString),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<EditorAdaptor, qt_meta_tag_ZN13EditorAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject EditorAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13EditorAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13EditorAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13EditorAdaptorE_t>.metaTypes,
    nullptr
} };

void EditorAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EditorAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->entryDisplayed(); break;
        case 1: _t->fileAboutToBeClosed(); break;
        case 2: _t->fileClosed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->fileOpened(); break;
        case 4: _t->fileSaved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->srcFileOpenRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 6: _t->addAlternateTranslation((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 7: _t->addEntryNote((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 8: _t->addTemporaryAlternateTranslation((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 9: _t->addTemporaryEntryNote((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 10: _t->attachAlternateTranslationFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->close(); break;
        case 12: { int _r = _t->currentEntry();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 13: { QString _r = _t->currentEntryId();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 14: { QString _r = _t->currentFile();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 15: { QByteArray _r = _t->currentFileContents();
            if (_a[0]) *reinterpret_cast<QByteArray*>(_a[0]) = std::move(_r); }  break;
        case 16: { int _r = _t->currentForm();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 17: { int _r = _t->entryCount();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 18: { int _r = _t->entryPluralFormCount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 19: { bool _r = _t->entryReady((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 20: { QString _r = _t->entrySource((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 21: { QString _r = _t->entryTarget((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 22: { bool _r = _t->findEntryBySourceContext((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 23: _t->gotoEntry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 24: _t->gotoEntryForm((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 25: _t->gotoEntryFormOffset((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 26: _t->gotoEntryFormOffsetSelection((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 27: _t->gotoFirst(); break;
        case 28: _t->gotoFirstUnfiltered(); break;
        case 29: _t->gotoLast(); break;
        case 30: _t->gotoLastUnfiltered(); break;
        case 31: _t->gotoNext(); break;
        case 32: _t->gotoNextUnfiltered(); break;
        case 33: _t->gotoPrev(); break;
        case 34: _t->gotoPrevUnfiltered(); break;
        case 35: { bool _r = _t->isValid();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 36: _t->openSyncSource((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 37: _t->reloadFile(); break;
        case 38: { bool _r = _t->saveFile();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 39: { bool _r = _t->saveFileAs();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 40: { QString _r = _t->selectionInSource();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 41: { QString _r = _t->selectionInTarget();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 42: _t->setEntriesFilteredOut((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 43: _t->setEntryFilteredOut((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 44: _t->setEntryTarget((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 45: _t->setSrcFileOpenRequestAccepted((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 46: { QString _r = _t->sourceLangCode();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 47: { QString _r = _t->targetLangCode();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (EditorAdaptor::*)()>(_a, &EditorAdaptor::entryDisplayed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditorAdaptor::*)()>(_a, &EditorAdaptor::fileAboutToBeClosed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditorAdaptor::*)(const QString & )>(_a, &EditorAdaptor::fileClosed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditorAdaptor::*)()>(_a, &EditorAdaptor::fileOpened, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditorAdaptor::*)(const QString & )>(_a, &EditorAdaptor::fileSaved, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditorAdaptor::*)(const QString & , int )>(_a, &EditorAdaptor::srcFileOpenRequested, 5))
            return;
    }
}

const QMetaObject *EditorAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EditorAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13EditorAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int EditorAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 48)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 48;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 48)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 48;
    }
    return _id;
}

// SIGNAL 0
void EditorAdaptor::entryDisplayed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void EditorAdaptor::fileAboutToBeClosed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void EditorAdaptor::fileClosed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void EditorAdaptor::fileOpened()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void EditorAdaptor::fileSaved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void EditorAdaptor::srcFileOpenRequested(const QString & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}
QT_WARNING_POP
