/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.lokalize.MainWindow.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "mainwindowadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class MainWindowAdaptor
 */

MainWindowAdaptor::MainWindowAdaptor(LokalizeMainWindow *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

MainWindowAdaptor::~MainWindowAdaptor()
{
    // destructor
}

void MainWindowAdaptor::busyCursor(bool busy)
{
    // handle method call org.kde.Lokalize.MainWindow.busyCursor
    parent()->busyCursor(busy);
}

QString MainWindowAdaptor::currentProject()
{
    // handle method call org.kde.Lokalize.MainWindow.currentProject
    return parent()->currentProject();
}

QString MainWindowAdaptor::dbusName()
{
    // handle method call org.kde.Lokalize.MainWindow.dbusName
    return parent()->dbusName();
}

int MainWindowAdaptor::editorIndexForFile(const QString &path)
{
    // handle method call org.kde.Lokalize.MainWindow.editorIndexForFile
    return parent()->editorIndexForFile(path);
}

int MainWindowAdaptor::openFileInEditor(const QString &path)
{
    // handle method call org.kde.Lokalize.MainWindow.openFileInEditor
    return parent()->openFileInEditor(path);
}

int MainWindowAdaptor::openFileInEditorAt(const QString &path, const QString &source, const QString &ctxt)
{
    // handle method call org.kde.Lokalize.MainWindow.openFileInEditorAt
    return parent()->openFileInEditorAt(path, source, ctxt);
}

void MainWindowAdaptor::openProject(const QString &path)
{
    // handle method call org.kde.Lokalize.MainWindow.openProject
    parent()->openProject(path);
}

int MainWindowAdaptor::pid()
{
    // handle method call org.kde.Lokalize.MainWindow.pid
    return parent()->pid();
}

void MainWindowAdaptor::showProjectOverview()
{
    // handle method call org.kde.Lokalize.MainWindow.showProjectOverview
    parent()->showProjectOverview();
}

int MainWindowAdaptor::showTranslationMemory()
{
    // handle method call org.kde.Lokalize.MainWindow.showTranslationMemory
    return parent()->showTranslationMemory();
}


#include "moc_mainwindowadaptor.cpp"
