/********************************************************************************
** Form generated from reading UI file 'widgettextcaptureconfig.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WIDGETTEXTCAPTURECONFIG_H
#define UI_WIDGETTEXTCAPTURECONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_WidgetTextCapture
{
public:
    QVBoxLayout *verticalLayout_2;
    QLabel *label;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QRadioButton *none;
    QRadioButton *search;
    QRadioButton *clipboard;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *WidgetTextCapture)
    {
        if (WidgetTextCapture->objectName().isEmpty())
            WidgetTextCapture->setObjectName("WidgetTextCapture");
        WidgetTextCapture->resize(588, 363);
        verticalLayout_2 = new QVBoxLayout(WidgetTextCapture);
        verticalLayout_2->setObjectName("verticalLayout_2");
        label = new QLabel(WidgetTextCapture);
        label->setObjectName("label");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);
        label->setWordWrap(true);

        verticalLayout_2->addWidget(label);

        groupBox = new QGroupBox(WidgetTextCapture);
        groupBox->setObjectName("groupBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy1);
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName("verticalLayout");
        none = new QRadioButton(groupBox);
        none->setObjectName("none");
        none->setChecked(true);

        verticalLayout->addWidget(none);

        search = new QRadioButton(groupBox);
        search->setObjectName("search");

        verticalLayout->addWidget(search);

        clipboard = new QRadioButton(groupBox);
        clipboard->setObjectName("clipboard");

        verticalLayout->addWidget(clipboard);


        verticalLayout_2->addWidget(groupBox);

        verticalSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(WidgetTextCapture);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_2->addWidget(buttonBox);


        retranslateUi(WidgetTextCapture);

        QMetaObject::connectSlotsByName(WidgetTextCapture);
    } // setupUi

    void retranslateUi(QWidget *WidgetTextCapture)
    {
        label->setText(tr2i18n("<html>\n"
"<p align=\"justify\">To facilitate KDE translation, Lokalize can capture text from applications' user interfaces and search for translation files containing the text.</p>\n"
"<p align=\"justify\">When enabled, the capture can be initiated by middle mouse clicking on any non-editable GUI element (widget). After that, switch to the Lokalize window and choose the entry with this text. Even if several files contain the same string, the right one will be chosen in most cases.</p>\n"
"<p align=\"justify\">Remember that you need to have an up-to-date actual translation memory with all translation files indexed for this feature to work.</p></html>", nullptr));
        groupBox->setTitle(tr2i18n("Middle Mouse Button Click Reaction", nullptr));
        none->setText(tr2i18n("None", nullptr));
        search->setText(tr2i18n("Search GUI element text in translation memory", nullptr));
        clipboard->setText(tr2i18n("Copy GUI element text to clipboard", nullptr));
        (void)WidgetTextCapture;
    } // retranslateUi

};

namespace Ui {
    class WidgetTextCapture: public Ui_WidgetTextCapture {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WIDGETTEXTCAPTURECONFIG_H

