/********************************************************************************
** Form generated from reading UI file 'findextension.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FINDEXTENSION_H
#define UI_FINDEXTENSION_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_findExtension
{
public:
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *m_skipTags;
    QCheckBox *m_ignoreAccelMarks;
    QVBoxLayout *verticalLayout;
    QCheckBox *m_notes;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *findExtension)
    {
        if (findExtension->objectName().isEmpty())
            findExtension->setObjectName("findExtension");
        findExtension->resize(300, 60);
        horizontalLayout = new QHBoxLayout(findExtension);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 4, 4, 0);
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        m_skipTags = new QCheckBox(findExtension);
        m_skipTags->setObjectName("m_skipTags");

        verticalLayout_2->addWidget(m_skipTags);

        m_ignoreAccelMarks = new QCheckBox(findExtension);
        m_ignoreAccelMarks->setObjectName("m_ignoreAccelMarks");

        verticalLayout_2->addWidget(m_ignoreAccelMarks);


        horizontalLayout->addLayout(verticalLayout_2);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        m_notes = new QCheckBox(findExtension);
        m_notes->setObjectName("m_notes");

        verticalLayout->addWidget(m_notes);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        horizontalLayout->addLayout(verticalLayout);


        retranslateUi(findExtension);

        QMetaObject::connectSlotsByName(findExtension);
    } // setupUi

    void retranslateUi(QWidget *findExtension)
    {
#if QT_CONFIG(whatsthis)
        m_skipTags->setWhatsThis(tr2i18n("Skip tags", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_skipTags->setText(tr2i18n("Skip markup", "@option:check"));
#if QT_CONFIG(whatsthis)
        m_ignoreAccelMarks->setWhatsThis(tr2i18n("Ignore accelerator marks", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_ignoreAccelMarks->setText(tr2i18n("Ignore accelerator marks", "@option:check"));
        m_notes->setText(tr2i18n("Include notes", nullptr));
        (void)findExtension;
    } // retranslateUi

};

namespace Ui {
    class findExtension: public Ui_findExtension {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FINDEXTENSION_H

