/********************************************************************************
** Form generated from reading UI file 'prefs_project_advanced.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFS_PROJECT_ADVANCED_H
#define UI_PREFS_PROJECT_ADVANCED_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"
#include "prefs.h"

QT_BEGIN_NAMESPACE

class Ui_project_advanced
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *groupBox;
    QFormLayout *formLayout;
    QLabel *l0;
    QLineEdit *kcfg_Accel;
    QLabel *l1;
    QLineEdit *kcfg_Markup;
    QLabel *l2;
    QSpinBox *kcfg_WordWrap;
    QGroupBox *groupBox_2;
    QFormLayout *formLayout_2;
    QLabel *l3;
    KUrlRequester *potBaseDir;
    QLabel *l4;
    KUrlRequester *branchDir;
    QLabel *l5;
    KUrlRequester *potBranchDir;
    QLabel *l6;
    KUrlRequester *altDir;
    RelPathSaver *kcfg_PotBaseDir;
    RelPathSaver *kcfg_BranchDir;
    RelPathSaver *kcfg_PotBranchDir;
    RelPathSaver *kcfg_AltDir;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *project_advanced)
    {
        if (project_advanced->objectName().isEmpty())
            project_advanced->setObjectName("project_advanced");
        project_advanced->resize(611, 430);
        vboxLayout = new QVBoxLayout(project_advanced);
        vboxLayout->setObjectName("vboxLayout");
        groupBox = new QGroupBox(project_advanced);
        groupBox->setObjectName("groupBox");
        formLayout = new QFormLayout(groupBox);
        formLayout->setObjectName("formLayout");
        l0 = new QLabel(groupBox);
        l0->setObjectName("l0");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, l0);

        kcfg_Accel = new QLineEdit(groupBox);
        kcfg_Accel->setObjectName("kcfg_Accel");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_Accel);

        l1 = new QLabel(groupBox);
        l1->setObjectName("l1");
        l1->setWordWrap(false);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, l1);

        kcfg_Markup = new QLineEdit(groupBox);
        kcfg_Markup->setObjectName("kcfg_Markup");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_Markup);

        l2 = new QLabel(groupBox);
        l2->setObjectName("l2");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, l2);

        kcfg_WordWrap = new QSpinBox(groupBox);
        kcfg_WordWrap->setObjectName("kcfg_WordWrap");
        kcfg_WordWrap->setMinimum(-1);
        kcfg_WordWrap->setMaximum(32767);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_WordWrap);


        vboxLayout->addWidget(groupBox);

        groupBox_2 = new QGroupBox(project_advanced);
        groupBox_2->setObjectName("groupBox_2");
        formLayout_2 = new QFormLayout(groupBox_2);
        formLayout_2->setObjectName("formLayout_2");
        formLayout_2->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        l3 = new QLabel(groupBox_2);
        l3->setObjectName("l3");
        l3->setWordWrap(false);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, l3);

        potBaseDir = new KUrlRequester(groupBox_2);
        potBaseDir->setObjectName("potBaseDir");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(potBaseDir->sizePolicy().hasHeightForWidth());
        potBaseDir->setSizePolicy(sizePolicy);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, potBaseDir);

        l4 = new QLabel(groupBox_2);
        l4->setObjectName("l4");
        l4->setWordWrap(false);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, l4);

        branchDir = new KUrlRequester(groupBox_2);
        branchDir->setObjectName("branchDir");
        sizePolicy.setHeightForWidth(branchDir->sizePolicy().hasHeightForWidth());
        branchDir->setSizePolicy(sizePolicy);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, branchDir);

        l5 = new QLabel(groupBox_2);
        l5->setObjectName("l5");
        l5->setWordWrap(false);

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, l5);

        potBranchDir = new KUrlRequester(groupBox_2);
        potBranchDir->setObjectName("potBranchDir");
        sizePolicy.setHeightForWidth(potBranchDir->sizePolicy().hasHeightForWidth());
        potBranchDir->setSizePolicy(sizePolicy);

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, potBranchDir);

        l6 = new QLabel(groupBox_2);
        l6->setObjectName("l6");
        l6->setWordWrap(false);

        formLayout_2->setWidget(3, QFormLayout::ItemRole::LabelRole, l6);

        altDir = new KUrlRequester(groupBox_2);
        altDir->setObjectName("altDir");
        sizePolicy.setHeightForWidth(altDir->sizePolicy().hasHeightForWidth());
        altDir->setSizePolicy(sizePolicy);

        formLayout_2->setWidget(3, QFormLayout::ItemRole::FieldRole, altDir);


        vboxLayout->addWidget(groupBox_2);

        kcfg_PotBaseDir = new RelPathSaver(project_advanced);
        kcfg_PotBaseDir->setObjectName("kcfg_PotBaseDir");

        vboxLayout->addWidget(kcfg_PotBaseDir);

        kcfg_BranchDir = new RelPathSaver(project_advanced);
        kcfg_BranchDir->setObjectName("kcfg_BranchDir");

        vboxLayout->addWidget(kcfg_BranchDir);

        kcfg_PotBranchDir = new RelPathSaver(project_advanced);
        kcfg_PotBranchDir->setObjectName("kcfg_PotBranchDir");

        vboxLayout->addWidget(kcfg_PotBranchDir);

        kcfg_AltDir = new RelPathSaver(project_advanced);
        kcfg_AltDir->setObjectName("kcfg_AltDir");

        vboxLayout->addWidget(kcfg_AltDir);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        l0->setBuddy(kcfg_Accel);
        l1->setBuddy(kcfg_Markup);
        l2->setBuddy(kcfg_WordWrap);
        l3->setBuddy(potBaseDir);
        l4->setBuddy(branchDir);
        l5->setBuddy(branchDir);
        l6->setBuddy(altDir);
#endif // QT_CONFIG(shortcut)

        retranslateUi(project_advanced);

        QMetaObject::connectSlotsByName(project_advanced);
    } // setupUi

    void retranslateUi(QWidget *project_advanced)
    {
        groupBox->setTitle(tr2i18n("Syntax", nullptr));
        l0->setText(tr2i18n("Accelerator:", "@label:textbox"));
#if QT_CONFIG(tooltip)
        kcfg_Accel->setToolTip(tr2i18n("Usually '&', but may also be '_' for GTK apps.", nullptr));
#endif // QT_CONFIG(tooltip)
        l1->setText(tr2i18n("Markup:", "@label:textbox"));
#if QT_CONFIG(tooltip)
        kcfg_Markup->setToolTip(tr2i18n("Regular expression of markup. It is used for translation memory matching and for 'Insert tag' feature.\n"
"\n"
"A default value (suitable for XML-based texts) is:\n"
"(<[^>]+>)+|(&[A-Za-z_:][A-Za-z0-9_\\.:-]*;)+\n"
"\n"
"It is only used for gettext PO files, as XLIFF format has its own way of specifying where markup is.", nullptr));
#endif // QT_CONFIG(tooltip)
        l2->setText(tr2i18n("Word wrap:", "@label:textbox"));
#if QT_CONFIG(tooltip)
        kcfg_WordWrap->setToolTip(tr2i18n("Width used for the automatic msgfmt-like word wrap. Use the value '0' to disable the word wrap. Use -1 when translating for KDE PO Summit. 1 to 3 doesn't change anything.", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBox_2->setTitle(tr2i18n("Paths", nullptr));
        l3->setText(tr2i18n("Template files folder:", "@label:textbox"));
#if QT_CONFIG(tooltip)
        potBaseDir->setToolTip(tr2i18n("Usually your translation project will be a subproject of a project\n"
"for translating same texts into multiple languages.\n"
"\n"
"Set this to path of a folder containing empty translation files\n"
"(i.e. files without translation into any language)\n"
"shared among all subprojects.", nullptr));
#endif // QT_CONFIG(tooltip)
        l4->setText(tr2i18n("Branch folder:", "@label:textbox"));
#if QT_CONFIG(tooltip)
        branchDir->setToolTip(tr2i18n("This setting is for Sync Mode.\n"
"\n"
"Sync Mode may be used to make changes to translation\n"
"for two branches simultaneously.\n"
"\n"
"Set this to path that corresponds to root folder of the branch project,\n"
"and Secondary Sync view will automatically open files from branch.\n"
"Then, each time you make changes in files of your main branch,\n"
"they will automatically be replicated to the branch\n"
"(of course, if it contains the same English string).\n"
"\n"
"See documentation for more details.", "this message contains text from documentation, so use its translation when you're translating docs"));
#endif // QT_CONFIG(tooltip)
        l5->setText(tr2i18n("Branch template files folder:", "@label:textbox"));
#if QT_CONFIG(tooltip)
        potBranchDir->setToolTip(tr2i18n("This setting is for Sync Mode.\n"
"\n"
"Sync Mode may be used to make changes to translation\n"
"for two branches simultaneously.\n"
"\n"
"Set this to path that corresponds to root folder of the branch project templates folder,\n"
"and Secondary Sync view will automatically create files from branch.", "this message contains text from documentation, so use its translation when you're translating docs"));
#endif // QT_CONFIG(tooltip)
        l6->setText(tr2i18n("Alternate translations folder:", "@label:textbox"));
#if QT_CONFIG(tooltip)
        altDir->setToolTip(tr2i18n("Set this to path of a folder with structure similar to Root Folder.\n"
"\n"
"On each translation file open, a corresponding file in Alternate translations directory will be looked up and,\n"
"if it is found, it will be used for Alternate Translations view.\n"
"\n"
"You will likely want to use translations of another target language (i.e. another subproject), which is close to yours.\n"
"Also, you can use other subproject's translations either immediately, or have them pretranslated to your language by machine.\n"
"\n"
"See documentation for more details.", "this message contains text from documentation, so use its translation when you're translating docs"));
#endif // QT_CONFIG(tooltip)
        (void)project_advanced;
    } // retranslateUi

};

namespace Ui {
    class project_advanced: public Ui_project_advanced {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PREFS_PROJECT_ADVANCED_H

