/********************************************************************************
** Form generated from reading UI file 'dbparams.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DBPARAMS_H
#define UI_DBPARAMS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_DBParams
{
public:
    QGridLayout *gridLayout;
    QLineEdit *name;
    QGroupBox *connectionBox;
    QFormLayout *formLayout_2;
    QLabel *label_10;
    QLineEdit *dbName;
    QLabel *label_7;
    QComboBox *dbHost;
    QLabel *label_8;
    QLineEdit *dbUser;
    QLabel *label_9;
    QLineEdit *dbPasswd;
    QComboBox *dbType;
    QLabel *label;
    QLabel *label_6;
    QGroupBox *contentBox;
    QFormLayout *formLayout;
    QLabel *label_4;
    KComboBox *sourceLang;
    QLabel *label_5;
    KComboBox *targetLang;
    QLineEdit *markup;
    QLabel *label_2;
    QLineEdit *accel;
    QLabel *label_3;
    QDialogButtonBox *buttonBox;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *DBParams)
    {
        if (DBParams->objectName().isEmpty())
            DBParams->setObjectName("DBParams");
        DBParams->resize(770, 503);
        gridLayout = new QGridLayout(DBParams);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setSizeConstraint(QLayout::SetMinimumSize);
        name = new QLineEdit(DBParams);
        name->setObjectName("name");

        gridLayout->addWidget(name, 0, 1, 1, 1);

        connectionBox = new QGroupBox(DBParams);
        connectionBox->setObjectName("connectionBox");
        formLayout_2 = new QFormLayout(connectionBox);
        formLayout_2->setObjectName("formLayout_2");
        formLayout_2->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        label_10 = new QLabel(connectionBox);
        label_10->setObjectName("label_10");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, label_10);

        dbName = new QLineEdit(connectionBox);
        dbName->setObjectName("dbName");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, dbName);

        label_7 = new QLabel(connectionBox);
        label_7->setObjectName("label_7");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, label_7);

        dbHost = new QComboBox(connectionBox);
        dbHost->setObjectName("dbHost");
        dbHost->setEditable(true);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, dbHost);

        label_8 = new QLabel(connectionBox);
        label_8->setObjectName("label_8");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, label_8);

        dbUser = new QLineEdit(connectionBox);
        dbUser->setObjectName("dbUser");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, dbUser);

        label_9 = new QLabel(connectionBox);
        label_9->setObjectName("label_9");

        formLayout_2->setWidget(3, QFormLayout::ItemRole::LabelRole, label_9);

        dbPasswd = new QLineEdit(connectionBox);
        dbPasswd->setObjectName("dbPasswd");
        dbPasswd->setEchoMode(QLineEdit::Password);

        formLayout_2->setWidget(3, QFormLayout::ItemRole::FieldRole, dbPasswd);


        gridLayout->addWidget(connectionBox, 6, 0, 1, 2);

        dbType = new QComboBox(DBParams);
        dbType->addItem(QString());
        dbType->setObjectName("dbType");

        gridLayout->addWidget(dbType, 1, 1, 1, 1);

        label = new QLabel(DBParams);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        label_6 = new QLabel(DBParams);
        label_6->setObjectName("label_6");

        gridLayout->addWidget(label_6, 1, 0, 1, 1);

        contentBox = new QGroupBox(DBParams);
        contentBox->setObjectName("contentBox");
        formLayout = new QFormLayout(contentBox);
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        label_4 = new QLabel(contentBox);
        label_4->setObjectName("label_4");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_4);

        sourceLang = new KComboBox(contentBox);
        sourceLang->setObjectName("sourceLang");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, sourceLang);

        label_5 = new QLabel(contentBox);
        label_5->setObjectName("label_5");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_5);

        targetLang = new KComboBox(contentBox);
        targetLang->setObjectName("targetLang");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, targetLang);

        markup = new QLineEdit(contentBox);
        markup->setObjectName("markup");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, markup);

        label_2 = new QLabel(contentBox);
        label_2->setObjectName("label_2");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_2);

        accel = new QLineEdit(contentBox);
        accel->setObjectName("accel");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, accel);

        label_3 = new QLabel(contentBox);
        label_3->setObjectName("label_3");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_3);


        gridLayout->addWidget(contentBox, 7, 0, 1, 2);

        buttonBox = new QDialogButtonBox(DBParams);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 9, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 8, 1, 1, 1);

#if QT_CONFIG(shortcut)
        label_10->setBuddy(dbName);
        label_7->setBuddy(dbHost);
        label_8->setBuddy(dbUser);
        label_9->setBuddy(dbPasswd);
        label->setBuddy(name);
        label_6->setBuddy(dbType);
        label_4->setBuddy(sourceLang);
        label_5->setBuddy(targetLang);
        label_2->setBuddy(markup);
        label_3->setBuddy(accel);
#endif // QT_CONFIG(shortcut)

        retranslateUi(DBParams);

        QMetaObject::connectSlotsByName(DBParams);
    } // setupUi

    void retranslateUi(QWidget *DBParams)
    {
        connectionBox->setTitle(tr2i18n("Connection", nullptr));
        label_10->setText(tr2i18n("Database name:", nullptr));
        label_7->setText(tr2i18n("Host:", nullptr));
        label_8->setText(tr2i18n("User:", nullptr));
        label_9->setText(tr2i18n("Password:", nullptr));
        dbType->setItemText(0, tr2i18n("Local", nullptr));

        label->setText(tr2i18n("Name:", nullptr));
        label_6->setText(tr2i18n("Database type:", nullptr));
        contentBox->setTitle(tr2i18n("Content", nullptr));
        label_4->setText(tr2i18n("Source language:", nullptr));
        label_5->setText(tr2i18n("Target language:", nullptr));
        label_2->setText(tr2i18n("Markup regex:", nullptr));
        label_3->setText(tr2i18n("Accelerator:", nullptr));
        (void)DBParams;
    } // retranslateUi

};

namespace Ui {
    class DBParams: public Ui_DBParams {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DBPARAMS_H

