/****************************************************************************
** Meta object code from reading C++ file 'projecttab.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../lokalize-26.08.0/src/project/projecttab.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'projecttab.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10ProjectTabE_t {};
} // unnamed namespace

template <> constexpr inline auto ProjectTab::qt_create_metaobjectdata<qt_meta_tag_ZN10ProjectTabE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ProjectTab",
        "D-Bus Interface",
        "org.kde.Lokalize.ProjectOverview",
        "projectOpenRequested",
        "",
        "fileOpenRequested",
        "setAsActive",
        "searchRequested",
        "replaceRequested",
        "spellcheckRequested",
        "setCurrentItem",
        "url",
        "currentItem",
        "selectedItems",
        "currentItemIsTranslationFile",
        "setFilterRegExp",
        "setFocus",
        "scanFilesToTM",
        "pologyOnFiles",
        "addComment",
        "searchInFiles",
        "templ",
        "searchInFilesInclTempl",
        "openFile",
        "findInFiles",
        "replaceInFiles",
        "spellcheckFiles",
        "gotoPrevFuzzyUntr",
        "gotoNextFuzzyUntr",
        "gotoPrevFuzzy",
        "gotoNextFuzzy",
        "gotoPrevUntranslated",
        "gotoNextUntranslated",
        "gotoPrevTemplateOnly",
        "gotoNextTemplateOnly",
        "gotoPrevTransOnly",
        "gotoNextTransOnly",
        "updateStatusBar",
        "fuzzy",
        "translated",
        "untranslated",
        "done",
        "pologyHasFinished",
        "exitCode",
        "QProcess::ExitStatus",
        "exitStatus"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'projectOpenRequested'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fileOpenRequested'
        QtMocHelpers::SignalData<void(const QString &, const bool)>(5, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 }, { QMetaType::Bool, 6 },
        }}),
        // Signal 'searchRequested'
        QtMocHelpers::SignalData<void(const QStringList &)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 4 },
        }}),
        // Signal 'replaceRequested'
        QtMocHelpers::SignalData<void(const QStringList &)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 4 },
        }}),
        // Signal 'spellcheckRequested'
        QtMocHelpers::SignalData<void(const QStringList &)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 4 },
        }}),
        // Slot 'setCurrentItem'
        QtMocHelpers::SlotData<void(const QString &)>(10, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'currentItem'
        QtMocHelpers::SlotData<QString() const>(12, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'selectedItems'
        QtMocHelpers::SlotData<QStringList() const>(13, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList),
        // Slot 'currentItemIsTranslationFile'
        QtMocHelpers::SlotData<bool() const>(14, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'setFilterRegExp'
        QtMocHelpers::SlotData<void()>(15, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setFocus'
        QtMocHelpers::SlotData<void()>(16, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'scanFilesToTM'
        QtMocHelpers::SlotData<void()>(17, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'pologyOnFiles'
        QtMocHelpers::SlotData<void()>(18, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addComment'
        QtMocHelpers::SlotData<void()>(19, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'searchInFiles'
        QtMocHelpers::SlotData<void(bool)>(20, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
        // Slot 'searchInFiles'
        QtMocHelpers::SlotData<void()>(20, 4, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'searchInFilesInclTempl'
        QtMocHelpers::SlotData<void()>(22, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openFile'
        QtMocHelpers::SlotData<void()>(23, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'findInFiles'
        QtMocHelpers::SlotData<void()>(24, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'replaceInFiles'
        QtMocHelpers::SlotData<void()>(25, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'spellcheckFiles'
        QtMocHelpers::SlotData<void()>(26, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'gotoPrevFuzzyUntr'
        QtMocHelpers::SlotData<void()>(27, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'gotoNextFuzzyUntr'
        QtMocHelpers::SlotData<void()>(28, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'gotoPrevFuzzy'
        QtMocHelpers::SlotData<void()>(29, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'gotoNextFuzzy'
        QtMocHelpers::SlotData<void()>(30, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'gotoPrevUntranslated'
        QtMocHelpers::SlotData<void()>(31, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'gotoNextUntranslated'
        QtMocHelpers::SlotData<void()>(32, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'gotoPrevTemplateOnly'
        QtMocHelpers::SlotData<void()>(33, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'gotoNextTemplateOnly'
        QtMocHelpers::SlotData<void()>(34, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'gotoPrevTransOnly'
        QtMocHelpers::SlotData<void()>(35, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'gotoNextTransOnly'
        QtMocHelpers::SlotData<void()>(36, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateStatusBar'
        QtMocHelpers::SlotData<void(int, int, int, bool)>(37, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 38 }, { QMetaType::Int, 39 }, { QMetaType::Int, 40 }, { QMetaType::Bool, 41 },
        }}),
        // Slot 'updateStatusBar'
        QtMocHelpers::SlotData<void(int, int, int)>(37, 4, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 38 }, { QMetaType::Int, 39 }, { QMetaType::Int, 40 },
        }}),
        // Slot 'updateStatusBar'
        QtMocHelpers::SlotData<void(int, int)>(37, 4, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 38 }, { QMetaType::Int, 39 },
        }}),
        // Slot 'updateStatusBar'
        QtMocHelpers::SlotData<void(int)>(37, 4, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 38 },
        }}),
        // Slot 'updateStatusBar'
        QtMocHelpers::SlotData<void()>(37, 4, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'pologyHasFinished'
        QtMocHelpers::SlotData<void(int, QProcess::ExitStatus)>(42, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 43 }, { 0x80000000 | 44, 45 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ProjectTab, qt_meta_tag_ZN10ProjectTabE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ProjectTab::staticMetaObject = { {
    QMetaObject::SuperData::link<LokalizeTabPageBaseNoQMainWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ProjectTabE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ProjectTabE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10ProjectTabE_t>.metaTypes,
    nullptr
} };

void ProjectTab::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProjectTab *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->projectOpenRequested(); break;
        case 1: _t->fileOpenRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 2: _t->searchRequested((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 3: _t->replaceRequested((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 4: _t->spellcheckRequested((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 5: _t->setCurrentItem((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: { QString _r = _t->currentItem();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 7: { QStringList _r = _t->selectedItems();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->currentItemIsTranslationFile();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->setFilterRegExp(); break;
        case 10: _t->setFocus(); break;
        case 11: _t->scanFilesToTM(); break;
        case 12: _t->pologyOnFiles(); break;
        case 13: _t->addComment(); break;
        case 14: _t->searchInFiles((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->searchInFiles(); break;
        case 16: _t->searchInFilesInclTempl(); break;
        case 17: _t->openFile(); break;
        case 18: _t->findInFiles(); break;
        case 19: _t->replaceInFiles(); break;
        case 20: _t->spellcheckFiles(); break;
        case 21: _t->gotoPrevFuzzyUntr(); break;
        case 22: _t->gotoNextFuzzyUntr(); break;
        case 23: _t->gotoPrevFuzzy(); break;
        case 24: _t->gotoNextFuzzy(); break;
        case 25: _t->gotoPrevUntranslated(); break;
        case 26: _t->gotoNextUntranslated(); break;
        case 27: _t->gotoPrevTemplateOnly(); break;
        case 28: _t->gotoNextTemplateOnly(); break;
        case 29: _t->gotoPrevTransOnly(); break;
        case 30: _t->gotoNextTransOnly(); break;
        case 31: _t->updateStatusBar((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 32: _t->updateStatusBar((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 33: _t->updateStatusBar((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 34: _t->updateStatusBar((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 35: _t->updateStatusBar(); break;
        case 36: _t->pologyHasFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QProcess::ExitStatus>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ProjectTab::*)()>(_a, &ProjectTab::projectOpenRequested, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProjectTab::*)(const QString & , const bool )>(_a, &ProjectTab::fileOpenRequested, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProjectTab::*)(const QStringList & )>(_a, &ProjectTab::searchRequested, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProjectTab::*)(const QStringList & )>(_a, &ProjectTab::replaceRequested, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProjectTab::*)(const QStringList & )>(_a, &ProjectTab::spellcheckRequested, 4))
            return;
    }
}

const QMetaObject *ProjectTab::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ProjectTab::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ProjectTabE_t>.strings))
        return static_cast<void*>(this);
    return LokalizeTabPageBaseNoQMainWindow::qt_metacast(_clname);
}

int ProjectTab::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = LokalizeTabPageBaseNoQMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 37)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 37;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 37)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 37;
    }
    return _id;
}

// SIGNAL 0
void ProjectTab::projectOpenRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ProjectTab::fileOpenRequested(const QString & _t1, const bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void ProjectTab::searchRequested(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ProjectTab::replaceRequested(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ProjectTab::spellcheckRequested(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
