// This file is generated by kconfig_compiler_kf6 from projectlocal.kcfg.
// All changes you do to this file will be lost.

#include "projectlocal.h"

ProjectLocal::ProjectLocal( KSharedConfig::Ptr config )
  : KConfigSkeleton( std::move( config ) )
{
  setCurrentGroup( QStringLiteral( "General" ) );

  KConfigSkeleton::ItemString  *itemSourceDir;
  itemSourceDir = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "SourceDir" ), mSourceDir );
  addItem( itemSourceDir, QStringLiteral( "SourceDir" ) );

  setCurrentGroup( QStringLiteral( "Personal" ) );

  QList<KConfigSkeleton::ItemEnum::Choice> valuesRole;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Translator");
    valuesRole.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Reviewer");
    valuesRole.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Approver");
    valuesRole.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Undefined");
    valuesRole.append( choice );
  }
  KConfigSkeleton::ItemEnum  *itemRole;
  itemRole = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "Role" ), mRole, valuesRole, int(Approver) );
  addItem( itemRole, QStringLiteral( "Role" ) );
  KConfigSkeleton::ItemBool  *itemFirstRun;
  itemFirstRun = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "FirstRun" ), mFirstRun, true );
  addItem( itemFirstRun, QStringLiteral( "FirstRun" ) );
}

ProjectLocal::~ProjectLocal()
{
}

