/********************************************************************************
** Form generated from reading UI file 'prefs_identity.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFS_IDENTITY_H
#define UI_PREFS_IDENTITY_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "prefs.h"

QT_BEGIN_NAMESPACE

class Ui_prefs_identity
{
public:
    QGridLayout *gridLayout;
    QLabel *textLabel1;
    QLabel *textLabel2;
    QLabel *textLabel2_2;
    QLineEdit *kcfg_authorName;
    QLabel *label;
    QLineEdit *kcfg_DefaultMailingList;
    KComboBox *DefaultLangCode;
    QSpacerItem *spacerItem;
    QLineEdit *kcfg_authorEmail;
    LangCodeSaver *kcfg_DefaultLangCode;
    QLineEdit *kcfg_authorLocalizedName;
    QLabel *label_2;
    QCheckBox *kcfg_overrideLangTeam;
    QLineEdit *kcfg_userLangTeam;

    void setupUi(QWidget *prefs_identity)
    {
        if (prefs_identity->objectName().isEmpty())
            prefs_identity->setObjectName("prefs_identity");
        prefs_identity->resize(612, 375);
        gridLayout = new QGridLayout(prefs_identity);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(11, 11, 11, 11);
        textLabel1 = new QLabel(prefs_identity);
        textLabel1->setObjectName("textLabel1");
        textLabel1->setWordWrap(false);

        gridLayout->addWidget(textLabel1, 2, 0, 1, 1);

        textLabel2 = new QLabel(prefs_identity);
        textLabel2->setObjectName("textLabel2");
        textLabel2->setWordWrap(false);

        gridLayout->addWidget(textLabel2, 1, 0, 1, 1);

        textLabel2_2 = new QLabel(prefs_identity);
        textLabel2_2->setObjectName("textLabel2_2");
        textLabel2_2->setWordWrap(false);

        gridLayout->addWidget(textLabel2_2, 0, 0, 1, 1);

        kcfg_authorName = new QLineEdit(prefs_identity);
        kcfg_authorName->setObjectName("kcfg_authorName");

        gridLayout->addWidget(kcfg_authorName, 0, 2, 1, 1);

        label = new QLabel(prefs_identity);
        label->setObjectName("label");

        gridLayout->addWidget(label, 3, 0, 1, 1);

        kcfg_DefaultMailingList = new QLineEdit(prefs_identity);
        kcfg_DefaultMailingList->setObjectName("kcfg_DefaultMailingList");

        gridLayout->addWidget(kcfg_DefaultMailingList, 3, 2, 1, 1);

        DefaultLangCode = new KComboBox(prefs_identity);
        DefaultLangCode->setObjectName("DefaultLangCode");

        gridLayout->addWidget(DefaultLangCode, 2, 2, 1, 1);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacerItem, 8, 0, 1, 3);

        kcfg_authorEmail = new QLineEdit(prefs_identity);
        kcfg_authorEmail->setObjectName("kcfg_authorEmail");

        gridLayout->addWidget(kcfg_authorEmail, 1, 2, 1, 1);

        kcfg_DefaultLangCode = new LangCodeSaver(prefs_identity);
        kcfg_DefaultLangCode->setObjectName("kcfg_DefaultLangCode");
        kcfg_DefaultLangCode->setEnabled(true);

        gridLayout->addWidget(kcfg_DefaultLangCode, 6, 2, 1, 1);

        kcfg_authorLocalizedName = new QLineEdit(prefs_identity);
        kcfg_authorLocalizedName->setObjectName("kcfg_authorLocalizedName");

        gridLayout->addWidget(kcfg_authorLocalizedName, 5, 2, 1, 1);

        label_2 = new QLabel(prefs_identity);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 5, 0, 1, 1);

        kcfg_overrideLangTeam = new QCheckBox(prefs_identity);
        kcfg_overrideLangTeam->setObjectName("kcfg_overrideLangTeam");

        gridLayout->addWidget(kcfg_overrideLangTeam, 4, 0, 1, 1);

        kcfg_userLangTeam = new QLineEdit(prefs_identity);
        kcfg_userLangTeam->setObjectName("kcfg_userLangTeam");
        kcfg_userLangTeam->setEnabled(false);

        gridLayout->addWidget(kcfg_userLangTeam, 4, 2, 1, 1);

#if QT_CONFIG(shortcut)
        textLabel1->setBuddy(DefaultLangCode);
        textLabel2->setBuddy(kcfg_authorEmail);
        textLabel2_2->setBuddy(kcfg_authorName);
        label->setBuddy(kcfg_DefaultMailingList);
        label_2->setBuddy(kcfg_authorLocalizedName);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kcfg_authorName, kcfg_authorEmail);
        QWidget::setTabOrder(kcfg_authorEmail, DefaultLangCode);
        QWidget::setTabOrder(DefaultLangCode, kcfg_DefaultMailingList);
        QWidget::setTabOrder(kcfg_DefaultMailingList, kcfg_authorLocalizedName);
        QWidget::setTabOrder(kcfg_authorLocalizedName, kcfg_DefaultLangCode);

        retranslateUi(prefs_identity);

        QMetaObject::connectSlotsByName(prefs_identity);
    } // setupUi

    void retranslateUi(QWidget *prefs_identity)
    {
#if QT_CONFIG(whatsthis)
        prefs_identity->setWhatsThis(tr2i18n("Fill in your identity and information about your translation team. This information is used when updating the header of a file.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel1->setText(tr2i18n("Default language:", "@label:chooser"));
        textLabel2->setText(tr2i18n("&Email:", "@label:textbox"));
        textLabel2_2->setText(tr2i18n("&Name:", "@label:textbox"));
#if QT_CONFIG(tooltip)
        kcfg_authorName->setToolTip(tr2i18n("Your name, in English", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_authorName->setWhatsThis(tr2i18n("Please enter here your name and surname written in English", nullptr));
#endif // QT_CONFIG(whatsthis)
        label->setText(tr2i18n("&Default mailing list:", "@label:textbox"));
#if QT_CONFIG(tooltip)
        kcfg_DefaultMailingList->setToolTip(tr2i18n("The email of your team mailing list", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_DefaultMailingList->setWhatsThis(tr2i18n("Write the email of your translating team mailing list", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        DefaultLangCode->setToolTip(tr2i18n("Language you translate to", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        DefaultLangCode->setWhatsThis(tr2i18n("Set the default language you are going to translate to", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        kcfg_authorEmail->setToolTip(tr2i18n("Write your email", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_authorEmail->setWhatsThis(tr2i18n("Write your email here so it will appear in the po file header with your name", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        kcfg_authorLocalizedName->setToolTip(tr2i18n("Your name in your own language", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_authorLocalizedName->setWhatsThis(tr2i18n("Write your name and surname in your language with your language alphabet.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_2->setText(tr2i18n("Localized name:", "@label:textbox"));
        kcfg_overrideLangTeam->setText(tr2i18n("Default Language-Team:", nullptr));
        kcfg_userLangTeam->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class prefs_identity: public Ui_prefs_identity {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PREFS_IDENTITY_H

