// This file is generated by kconfig_compiler_kf6 from projectbase.kcfg.
// All changes you do to this file will be lost.

#include "projectbase.h"

ProjectBase::ProjectBase( KSharedConfig::Ptr config )
  : KConfigSkeleton( std::move( config ) )
{
  setCurrentGroup( QStringLiteral( "General" ) );

  KConfigSkeleton::ItemString  *itemProjectID;
  itemProjectID = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "ProjectID" ), mProjectID, i18n("default") );
  addItem( itemProjectID, QStringLiteral( "ProjectID" ) );
  KConfigSkeleton::ItemString  *itemKind;
  itemKind = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Kind" ), mKind, QStringLiteral( "kde" ) );
  addItem( itemKind, QStringLiteral( "Kind" ) );
  KConfigSkeleton::ItemString  *itemLangCode;
  itemLangCode = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "LangCode" ), mLangCode );
  addItem( itemLangCode, QStringLiteral( "LangCode" ) );
  KConfigSkeleton::ItemString  *itemTargetLangCode;
  itemTargetLangCode = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "TargetLangCode" ), mTargetLangCode );
  addItem( itemTargetLangCode, QStringLiteral( "TargetLangCode" ) );
  KConfigSkeleton::ItemString  *itemSourceLangCode;
  itemSourceLangCode = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "SourceLangCode" ), mSourceLangCode, QStringLiteral( "en_US" ) );
  addItem( itemSourceLangCode, QStringLiteral( "SourceLangCode" ) );
  KConfigSkeleton::ItemString  *itemMailingList;
  itemMailingList = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "MailingList" ), mMailingList, getMailingList() );
  addItem( itemMailingList, QStringLiteral( "MailingList" ) );
  KConfigSkeleton::ItemString  *itemUserLangTeam;
  itemUserLangTeam = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "UserLangTeam" ), mUserLangTeam );
  addItem( itemUserLangTeam, QStringLiteral( "UserLangTeam" ) );
  KConfigSkeleton::ItemBool  *itemOverrideLangTeam;
  itemOverrideLangTeam = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "OverrideLangTeam" ), mOverrideLangTeam, false );
  addItem( itemOverrideLangTeam, QStringLiteral( "OverrideLangTeam" ) );
  KConfigSkeleton::ItemString  *itemProjLangTeam;
  itemProjLangTeam = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "ProjLangTeam" ), mProjLangTeam );
  addItem( itemProjLangTeam, QStringLiteral( "ProjLangTeam" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valuesLanguageSource;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Automatic");
    valuesLanguageSource.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Application");
    valuesLanguageSource.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Project");
    valuesLanguageSource.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Undefined");
    valuesLanguageSource.append( choice );
  }
  KConfigSkeleton::ItemEnum  *itemLanguageSource;
  itemLanguageSource = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "LanguageSource" ), mLanguageSource, valuesLanguageSource, int(Application) );
  addItem( itemLanguageSource, QStringLiteral( "LanguageSource" ) );
  KConfigSkeleton::ItemString  *itemPoBaseDir;
  itemPoBaseDir = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "PoBaseDir" ), mPoBaseDir, QStringLiteral( "./" ) );
  addItem( itemPoBaseDir, QStringLiteral( "PoBaseDir" ) );
  KConfigSkeleton::ItemString  *itemPotBaseDir;
  itemPotBaseDir = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "PotBaseDir" ), mPotBaseDir, QStringLiteral( "../templates" ) );
  addItem( itemPotBaseDir, QStringLiteral( "PotBaseDir" ) );
  KConfigSkeleton::ItemString  *itemBranchDir;
  itemBranchDir = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "BranchDir" ), mBranchDir );
  addItem( itemBranchDir, QStringLiteral( "BranchDir" ) );
  KConfigSkeleton::ItemString  *itemPotBranchDir;
  itemPotBranchDir = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "PotBranchDir" ), mPotBranchDir );
  addItem( itemPotBranchDir, QStringLiteral( "PotBranchDir" ) );
  KConfigSkeleton::ItemString  *itemAltDir;
  itemAltDir = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "AltDir" ), mAltDir );
  addItem( itemAltDir, QStringLiteral( "AltDir" ) );
  KConfigSkeleton::ItemString  *itemGlossaryTbx;
  itemGlossaryTbx = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "GlossaryTbx" ), mGlossaryTbx, QStringLiteral( "./terms.tbx" ) );
  addItem( itemGlossaryTbx, QStringLiteral( "GlossaryTbx" ) );
  KConfigSkeleton::ItemString  *itemMainQA;
  itemMainQA = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "MainQA" ), mMainQA, QStringLiteral( "./main.lqa" ) );
  addItem( itemMainQA, QStringLiteral( "MainQA" ) );

  setCurrentGroup( QStringLiteral( "RegExps" ) );

  KConfigSkeleton::ItemString  *itemAccel;
  itemAccel = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Accel" ), mAccel, QStringLiteral( "&" ) );
  addItem( itemAccel, QStringLiteral( "Accel" ) );
  KConfigSkeleton::ItemString  *itemMarkup;
  itemMarkup = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Markup" ), mMarkup, QStringLiteral( "(<[^>]+>)+|(&[A-Za-z_:][A-Za-z0-9_\\.:-]*;|%[0-9])+" ) );
  addItem( itemMarkup, QStringLiteral( "Markup" ) );
  KConfigSkeleton::ItemInt  *itemWordWrap;
  itemWordWrap = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "WordWrap" ), mWordWrap, 80 );
  addItem( itemWordWrap, QStringLiteral( "WordWrap" ) );

  setCurrentGroup( QStringLiteral( "Comments" ) );

  KConfigSkeleton::ItemStringList  *itemCommentsFiles;
  itemCommentsFiles = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "CommentsFiles" ), mCommentsFiles );
  addItem( itemCommentsFiles, QStringLiteral( "CommentsFiles" ) );
  KConfigSkeleton::ItemStringList  *itemCommentsTexts;
  itemCommentsTexts = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "CommentsTexts" ), mCommentsTexts );
  addItem( itemCommentsTexts, QStringLiteral( "CommentsTexts" ) );
}

ProjectBase::~ProjectBase()
{
}

