/********************************************************************************
** Form generated from reading UI file 'prefs_editor.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFS_EDITOR_H
#define UI_PREFS_EDITOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_prefs_editor
{
public:
    QGridLayout *gridLayout;
    QCheckBox *kcfg_MouseWheelGo;
    QCheckBox *kcfg_AutoApprove;
    QSpacerItem *spacerItem;
    QCheckBox *kcfg_VisualizeSeparators;
    QHBoxLayout *hboxLayout;
    QLabel *l1;
    QSpinBox *kcfg_WordCompletionLength;
    QCheckBox *kcfg_ConvertXMLChars;

    void setupUi(QWidget *prefs_editor)
    {
        if (prefs_editor->objectName().isEmpty())
            prefs_editor->setObjectName("prefs_editor");
        prefs_editor->resize(612, 375);
        gridLayout = new QGridLayout(prefs_editor);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(11, 11, 11, 11);
        kcfg_MouseWheelGo = new QCheckBox(prefs_editor);
        kcfg_MouseWheelGo->setObjectName("kcfg_MouseWheelGo");

        gridLayout->addWidget(kcfg_MouseWheelGo, 1, 0, 1, 1);

        kcfg_AutoApprove = new QCheckBox(prefs_editor);
        kcfg_AutoApprove->setObjectName("kcfg_AutoApprove");

        gridLayout->addWidget(kcfg_AutoApprove, 0, 0, 1, 1);

        spacerItem = new QSpacerItem(20, 30, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacerItem, 7, 0, 1, 2);

        kcfg_VisualizeSeparators = new QCheckBox(prefs_editor);
        kcfg_VisualizeSeparators->setObjectName("kcfg_VisualizeSeparators");

        gridLayout->addWidget(kcfg_VisualizeSeparators, 4, 0, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        l1 = new QLabel(prefs_editor);
        l1->setObjectName("l1");

        hboxLayout->addWidget(l1);

        kcfg_WordCompletionLength = new QSpinBox(prefs_editor);
        kcfg_WordCompletionLength->setObjectName("kcfg_WordCompletionLength");
        kcfg_WordCompletionLength->setMinimum(2);
        kcfg_WordCompletionLength->setMaximum(20);

        hboxLayout->addWidget(kcfg_WordCompletionLength);


        gridLayout->addLayout(hboxLayout, 2, 0, 1, 1);

        kcfg_ConvertXMLChars = new QCheckBox(prefs_editor);
        kcfg_ConvertXMLChars->setObjectName("kcfg_ConvertXMLChars");

        gridLayout->addWidget(kcfg_ConvertXMLChars, 5, 0, 1, 1);

#if QT_CONFIG(shortcut)
        l1->setBuddy(kcfg_WordCompletionLength);
#endif // QT_CONFIG(shortcut)

        retranslateUi(prefs_editor);

        QMetaObject::connectSlotsByName(prefs_editor);
    } // setupUi

    void retranslateUi(QWidget *prefs_editor)
    {
#if QT_CONFIG(tooltip)
        kcfg_MouseWheelGo->setToolTip(tr2i18n("If set, mouse wheel goes to previous or next unit, otherwise it scrolls text", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_MouseWheelGo->setWhatsThis(tr2i18n("<html>When this option is enabled, the mouse wheel is used to go to the previous or next translation unit (without modifier keys). Modifier keys can be used to change this behavior. Use:<ul><li><b>Shift</b> to scroll within the text of the current unit,</li><li><b>Ctrl+Shift</b> to go to previous or next non-ready unit,</li><li><b>Ctrl</b> to go to previous or next non-ready not empty unit,</li><li><b>Alt</b> to go to previous or next untranslated unit.</li></ul>When the option is disabled, the mouse wheel scrolls within the text of the current translation unit.</html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_MouseWheelGo->setText(tr2i18n("Mouse wheel goes to previous or next translation unit", nullptr));
        kcfg_AutoApprove->setText(tr2i18n("Set 'approved' status automatically when editing started", nullptr));
        kcfg_VisualizeSeparators->setText(tr2i18n("Visualize separators such as spaces, tabs and new lines in the editor", nullptr));
#if QT_CONFIG(tooltip)
        l1->setToolTip(tr2i18n("Set to 2 to disable word completion", nullptr));
#endif // QT_CONFIG(tooltip)
        l1->setText(tr2i18n("Minimum word length for word completion", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_WordCompletionLength->setToolTip(tr2i18n("Set to 2 to disable word completion", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_WordCompletionLength->setSpecialValueText(tr2i18n("Disable word completion", nullptr));
        kcfg_ConvertXMLChars->setText(tr2i18n("Automatically convert XML special characters in TS files", nullptr));
        (void)prefs_editor;
    } // retranslateUi

};

namespace Ui {
    class prefs_editor: public Ui_prefs_editor {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PREFS_EDITOR_H

