/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.lokalize.Editor.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef EDITORADAPTOR_H
#define EDITORADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "editortab.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.Lokalize.Editor
 */
class EditorAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.Lokalize.Editor")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.Lokalize.Editor\">\n"
"    <signal name=\"srcFileOpenRequested\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"srcPath\"/>\n"
"      <arg direction=\"out\" type=\"i\" name=\"line\"/>\n"
"    </signal>\n"
"    <signal name=\"fileClosed\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"path\"/>\n"
"    </signal>\n"
"    <signal name=\"fileSaved\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"path\"/>\n"
"    </signal>\n"
"    <signal name=\"fileAboutToBeClosed\"/>\n"
"    <signal name=\"fileOpened\"/>\n"
"    <signal name=\"entryDisplayed\"/>\n"
"    <method name=\"gotoEntry\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"entry\"/>\n"
"    </method>\n"
"    <method name=\"gotoEntryForm\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"entry\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"form\"/>\n"
"    </method>\n"
"    <method name=\"gotoEntryFormOffset\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"entry\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"form\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"offset\"/>\n"
"    </method>\n"
"    <method name=\"gotoEntryFormOffsetSelection\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"entry\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"form\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"offset\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"selection\"/>\n"
"    </method>\n"
"    <method name=\"currentEntryId\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"currentEntry\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"currentForm\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"selectionInTarget\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"selectionInSource\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setEntryFilteredOut\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"entry\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"filteredOut\"/>\n"
"    </method>\n"
"    <method name=\"setEntriesFilteredOut\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"filteredOut\"/>\n"
"    </method>\n"
"    <method name=\"entryCount\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"entrySource\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"entry\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"form\"/>\n"
"    </method>\n"
"    <method name=\"entryTarget\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"entry\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"form\"/>\n"
"    </method>\n"
"    <method name=\"setEntryTarget\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"entry\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"form\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"content\"/>\n"
"    </method>\n"
"    <method name=\"entryPluralFormCount\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"entry\"/>\n"
"    </method>\n"
"    <method name=\"entryReady\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"entry\"/>\n"
"    </method>\n"
"    <method name=\"addEntryNote\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"entry\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"note\"/>\n"
"    </method>\n"
"    <method name=\"addTemporaryEntryNote\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"entry\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"note\"/>\n"
"    </method>\n"
"    <method name=\"addAlternateTranslation\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"entry\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"translation\"/>\n"
"    </method>\n"
"    <method name=\"addTemporaryAlternateTranslation\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"entry\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"translation\"/>\n"
"    </method>\n"
"    <method name=\"currentFile\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"currentFileContents\">\n"
"      <arg direction=\"out\" type=\"ay\"/>\n"
"    </method>\n"
"    <method name=\"sourceLangCode\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"targetLangCode\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"attachAlternateTranslationFile\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"path\"/>\n"
"    </method>\n"
"    <method name=\"openSyncSource\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"path\"/>\n"
"    </method>\n"
"    <method name=\"reloadFile\"/>\n"
"    <method name=\"saveFile\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"saveFileAs\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"close\"/>\n"
"    <method name=\"gotoNextUnfiltered\"/>\n"
"    <method name=\"gotoPrevUnfiltered\"/>\n"
"    <method name=\"gotoFirstUnfiltered\"/>\n"
"    <method name=\"gotoLastUnfiltered\"/>\n"
"    <method name=\"gotoNext\"/>\n"
"    <method name=\"gotoPrev\"/>\n"
"    <method name=\"gotoFirst\"/>\n"
"    <method name=\"gotoLast\"/>\n"
"    <method name=\"findEntryBySourceContext\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"source\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"ctxt\"/>\n"
"    </method>\n"
"    <method name=\"isValid\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"setSrcFileOpenRequestAccepted\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"a\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    EditorAdaptor(EditorTab *parent);
    ~EditorAdaptor() override;

    inline EditorTab *parent() const
    { return static_cast<EditorTab *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void addAlternateTranslation(int entry, const QString &translation);
    void addEntryNote(int entry, const QString &note);
    void addTemporaryAlternateTranslation(int entry, const QString &translation);
    void addTemporaryEntryNote(int entry, const QString &note);
    void attachAlternateTranslationFile(const QString &path);
    void close();
    int currentEntry();
    QString currentEntryId();
    QString currentFile();
    QByteArray currentFileContents();
    int currentForm();
    int entryCount();
    int entryPluralFormCount(int entry);
    bool entryReady(int entry);
    QString entrySource(int entry, int form);
    QString entryTarget(int entry, int form);
    bool findEntryBySourceContext(const QString &source, const QString &ctxt);
    void gotoEntry(int entry);
    void gotoEntryForm(int entry, int form);
    void gotoEntryFormOffset(int entry, int form, int offset);
    void gotoEntryFormOffsetSelection(int entry, int form, int offset, int selection);
    void gotoFirst();
    void gotoFirstUnfiltered();
    void gotoLast();
    void gotoLastUnfiltered();
    void gotoNext();
    void gotoNextUnfiltered();
    void gotoPrev();
    void gotoPrevUnfiltered();
    bool isValid();
    void openSyncSource(const QString &path);
    void reloadFile();
    bool saveFile();
    bool saveFileAs();
    QString selectionInSource();
    QString selectionInTarget();
    void setEntriesFilteredOut(bool filteredOut);
    void setEntryFilteredOut(int entry, bool filteredOut);
    void setEntryTarget(int entry, int form, const QString &content);
    void setSrcFileOpenRequestAccepted(bool a);
    QString sourceLangCode();
    QString targetLangCode();
Q_SIGNALS: // SIGNALS
    void entryDisplayed();
    void fileAboutToBeClosed();
    void fileClosed(const QString &path);
    void fileOpened();
    void fileSaved(const QString &path);
    void srcFileOpenRequested(const QString &srcPath, int line);
};

#endif
