/********************************************************************************
** Form generated from reading UI file 'termedit.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TERMEDIT_H
#define UI_TERMEDIT_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "glossarytab.h"
#include "kcombobox.h"
#include "ktextedit.h"

QT_BEGIN_NAMESPACE

class Ui_TermEdit
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *engTermHL;
    QLabel *label;
    QPushButton *addEngTerm;
    QPushButton *remEngTerm;
    TermListView *sourceTermsView;
    QHBoxLayout *targetTermHL;
    QLabel *l2;
    QPushButton *addTargetTerm;
    QPushButton *remTargetTerm;
    TermListView *targetTermsView;
    QLabel *label_4;
    KComboBox *subjectField;
    QHBoxLayout *horizontalLayout;
    QLabel *label_3;
    KComboBox *definitionLang;
    AuxTextEdit *definition;

    void setupUi(QWidget *TermEdit)
    {
        if (TermEdit->objectName().isEmpty())
            TermEdit->setObjectName("TermEdit");
        TermEdit->resize(534, 536);
        vboxLayout = new QVBoxLayout(TermEdit);
        vboxLayout->setObjectName("vboxLayout");
        engTermHL = new QHBoxLayout();
        engTermHL->setObjectName("engTermHL");
        label = new QLabel(TermEdit);
        label->setObjectName("label");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);

        engTermHL->addWidget(label);

        addEngTerm = new QPushButton(TermEdit);
        addEngTerm->setObjectName("addEngTerm");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("list-add")));
        addEngTerm->setIcon(icon);

        engTermHL->addWidget(addEngTerm);

        remEngTerm = new QPushButton(TermEdit);
        remEngTerm->setObjectName("remEngTerm");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("list-remove")));
        remEngTerm->setIcon(icon1);

        engTermHL->addWidget(remEngTerm);


        vboxLayout->addLayout(engTermHL);

        sourceTermsView = new TermListView(TermEdit);
        sourceTermsView->setObjectName("sourceTermsView");

        vboxLayout->addWidget(sourceTermsView);

        targetTermHL = new QHBoxLayout();
        targetTermHL->setObjectName("targetTermHL");
        l2 = new QLabel(TermEdit);
        l2->setObjectName("l2");
        sizePolicy.setHeightForWidth(l2->sizePolicy().hasHeightForWidth());
        l2->setSizePolicy(sizePolicy);

        targetTermHL->addWidget(l2);

        addTargetTerm = new QPushButton(TermEdit);
        addTargetTerm->setObjectName("addTargetTerm");
        addTargetTerm->setIcon(icon);

        targetTermHL->addWidget(addTargetTerm);

        remTargetTerm = new QPushButton(TermEdit);
        remTargetTerm->setObjectName("remTargetTerm");
        remTargetTerm->setIcon(icon1);

        targetTermHL->addWidget(remTargetTerm);


        vboxLayout->addLayout(targetTermHL);

        targetTermsView = new TermListView(TermEdit);
        targetTermsView->setObjectName("targetTermsView");

        vboxLayout->addWidget(targetTermsView);

        label_4 = new QLabel(TermEdit);
        label_4->setObjectName("label_4");

        vboxLayout->addWidget(label_4);

        subjectField = new KComboBox(TermEdit);
        subjectField->setObjectName("subjectField");
        subjectField->setEditable(true);

        vboxLayout->addWidget(subjectField);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label_3 = new QLabel(TermEdit);
        label_3->setObjectName("label_3");

        horizontalLayout->addWidget(label_3);

        definitionLang = new KComboBox(TermEdit);
        definitionLang->setObjectName("definitionLang");

        horizontalLayout->addWidget(definitionLang);


        vboxLayout->addLayout(horizontalLayout);

        definition = new AuxTextEdit(TermEdit);
        definition->setObjectName("definition");
        definition->setTabChangesFocus(true);
        definition->setAcceptRichText(false);

        vboxLayout->addWidget(definition);

#if QT_CONFIG(shortcut)
        label_4->setBuddy(subjectField);
        label_3->setBuddy(definitionLang);
#endif // QT_CONFIG(shortcut)

        retranslateUi(TermEdit);

        QMetaObject::connectSlotsByName(TermEdit);
    } // setupUi

    void retranslateUi(QWidget *TermEdit)
    {
        label->setText(tr2i18n("English synonyms (double-click to edit):", nullptr));
        addEngTerm->setText(tr2i18n("Add", nullptr));
#if QT_CONFIG(tooltip)
        addEngTerm->setToolTip(tr2i18n("Add new source synonym", nullptr));
#endif // QT_CONFIG(tooltip)
        remEngTerm->setText(tr2i18n("Remove", nullptr));
#if QT_CONFIG(tooltip)
        remEngTerm->setToolTip(tr2i18n("Remove selected source synonym", nullptr));
#endif // QT_CONFIG(tooltip)
        l2->setText(tr2i18n("Corresponding target language synonyms:", nullptr));
        addTargetTerm->setText(tr2i18n("Add", nullptr));
#if QT_CONFIG(tooltip)
        addTargetTerm->setToolTip(tr2i18n("Add new target synonym", nullptr));
#endif // QT_CONFIG(tooltip)
        remTargetTerm->setText(tr2i18n("Remove", nullptr));
#if QT_CONFIG(tooltip)
        remTargetTerm->setToolTip(tr2i18n("Remove selected target synonym", nullptr));
#endif // QT_CONFIG(tooltip)
        label_4->setText(tr2i18n("Subject field:", nullptr));
#if QT_CONFIG(tooltip)
        subjectField->setToolTip(tr2i18n("When adding a new item, press enter after you have typed its name for changes to take effect", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        label_3->setText(tr2i18n("Definition:", nullptr));
        (void)TermEdit;
    } // retranslateUi

};

namespace Ui {
    class TermEdit: public Ui_TermEdit {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TERMEDIT_H

