/********************************************************************************
** Form generated from reading UI file 'prefs_appearance.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFS_APPEARANCE_H
#define UI_PREFS_APPEARANCE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"
#include "kfontrequester.h"

QT_BEGIN_NAMESPACE

class Ui_prefs_appearance
{
public:
    QGridLayout *gridLayout;
    QGridLayout *gridLayout1;
    QLabel *label;
    KFontRequester *kcfg_MsgFont;
    QCheckBox *kcfg_Leds;
    QSpacerItem *spacerItem;
    QCheckBox *kcfg_HighlightSpaces;

    void setupUi(QWidget *prefs_appearance)
    {
        if (prefs_appearance->objectName().isEmpty())
            prefs_appearance->setObjectName("prefs_appearance");
        prefs_appearance->resize(576, 515);
        gridLayout = new QGridLayout(prefs_appearance);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(9, 9, 9, 9);
        gridLayout1 = new QGridLayout();
        gridLayout1->setObjectName("gridLayout1");
        label = new QLabel(prefs_appearance);
        label->setObjectName("label");

        gridLayout1->addWidget(label, 0, 0, 1, 1);

        kcfg_MsgFont = new KFontRequester(prefs_appearance);
        kcfg_MsgFont->setObjectName("kcfg_MsgFont");

        gridLayout1->addWidget(kcfg_MsgFont, 0, 1, 1, 1);

        kcfg_Leds = new QCheckBox(prefs_appearance);
        kcfg_Leds->setObjectName("kcfg_Leds");

        gridLayout1->addWidget(kcfg_Leds, 1, 0, 1, 2);


        gridLayout->addLayout(gridLayout1, 0, 0, 1, 1);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacerItem, 4, 0, 1, 1);

        kcfg_HighlightSpaces = new QCheckBox(prefs_appearance);
        kcfg_HighlightSpaces->setObjectName("kcfg_HighlightSpaces");

        gridLayout->addWidget(kcfg_HighlightSpaces, 1, 0, 1, 1);

#if QT_CONFIG(shortcut)
        label->setBuddy(kcfg_MsgFont);
#endif // QT_CONFIG(shortcut)

        retranslateUi(prefs_appearance);

        QMetaObject::connectSlotsByName(prefs_appearance);
    } // setupUi

    void retranslateUi(QWidget *prefs_appearance)
    {
        label->setText(tr2i18n("Editor font:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_MsgFont->setToolTip(tr2i18n("Change the font for the editor", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_MsgFont->setWhatsThis(tr2i18n("Choose a new font for the area where you write the translated message.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        kcfg_Leds->setToolTip(tr2i18n("Display LEDS for message status", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_Leds->setWhatsThis(tr2i18n("If checked, LEDS will be shown to display the message status: Fuzzy, Untranslated or Error. If unchecked, no LEDs will be displayed.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_Leds->setText(tr2i18n("LEDs to indicate Fuzzy and Untranslated status as well as cursor column number", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_HighlightSpaces->setToolTip(tr2i18n("Check to see if a string ends in a space (which is often important when displaying it in the user interface, or when it gets concatenated with others).", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_HighlightSpaces->setText(tr2i18n("Highlight spaces at the end", nullptr));
        (void)prefs_appearance;
    } // retranslateUi

};

namespace Ui {
    class prefs_appearance: public Ui_prefs_appearance {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PREFS_APPEARANCE_H

