/********************************************************************************
** Form generated from reading UI file 'prefs_projectmain.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFS_PROJECTMAIN_H
#define UI_PREFS_PROJECTMAIN_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "kurlrequester.h"
#include "prefs.h"

QT_BEGIN_NAMESPACE

class Ui_prefs_projectmain
{
public:
    QGridLayout *gridLayout;
    QLabel *l2;
    LangCodeSaver *kcfg_LangCode;
    QLabel *l0;
    QLineEdit *kcfg_MailingList;
    QLineEdit *kcfg_ProjectID;
    KComboBox *LangCode;
    KUrlRequester *glossaryTbx;
    QLabel *l4;
    QLabel *l3;
    RelPathSaver *kcfg_GlossaryTbx;
    KUrlRequester *poBaseDir;
    RelPathSaver *kcfg_PoBaseDir;
    QSpacerItem *verticalSpacer;
    QLabel *l1;
    KComboBox *kcfg_LanguageSource;
    QLineEdit *kcfg_ProjLangTeam;
    QLabel *l5;

    void setupUi(QWidget *prefs_projectmain)
    {
        if (prefs_projectmain->objectName().isEmpty())
            prefs_projectmain->setObjectName("prefs_projectmain");
        prefs_projectmain->resize(611, 340);
        gridLayout = new QGridLayout(prefs_projectmain);
        gridLayout->setObjectName("gridLayout");
        l2 = new QLabel(prefs_projectmain);
        l2->setObjectName("l2");

        gridLayout->addWidget(l2, 5, 0, 1, 1);

        kcfg_LangCode = new LangCodeSaver(prefs_projectmain);
        kcfg_LangCode->setObjectName("kcfg_LangCode");

        gridLayout->addWidget(kcfg_LangCode, 6, 1, 1, 2);

        l0 = new QLabel(prefs_projectmain);
        l0->setObjectName("l0");

        gridLayout->addWidget(l0, 1, 0, 1, 1);

        kcfg_MailingList = new QLineEdit(prefs_projectmain);
        kcfg_MailingList->setObjectName("kcfg_MailingList");

        gridLayout->addWidget(kcfg_MailingList, 2, 1, 1, 2);

        kcfg_ProjectID = new QLineEdit(prefs_projectmain);
        kcfg_ProjectID->setObjectName("kcfg_ProjectID");

        gridLayout->addWidget(kcfg_ProjectID, 0, 1, 1, 2);

        LangCode = new KComboBox(prefs_projectmain);
        LangCode->setObjectName("LangCode");
        LangCode->setMinimumSize(QSize(400, 0));

        gridLayout->addWidget(LangCode, 1, 1, 1, 2);

        glossaryTbx = new KUrlRequester(prefs_projectmain);
        glossaryTbx->setObjectName("glossaryTbx");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(glossaryTbx->sizePolicy().hasHeightForWidth());
        glossaryTbx->setSizePolicy(sizePolicy);
        glossaryTbx->setMinimumSize(QSize(400, 16));

        gridLayout->addWidget(glossaryTbx, 5, 1, 1, 2);

        l4 = new QLabel(prefs_projectmain);
        l4->setObjectName("l4");

        gridLayout->addWidget(l4, 2, 0, 1, 1);

        l3 = new QLabel(prefs_projectmain);
        l3->setObjectName("l3");

        gridLayout->addWidget(l3, 0, 0, 1, 1);

        kcfg_GlossaryTbx = new RelPathSaver(prefs_projectmain);
        kcfg_GlossaryTbx->setObjectName("kcfg_GlossaryTbx");

        gridLayout->addWidget(kcfg_GlossaryTbx, 8, 1, 1, 2);

        poBaseDir = new KUrlRequester(prefs_projectmain);
        poBaseDir->setObjectName("poBaseDir");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(poBaseDir->sizePolicy().hasHeightForWidth());
        poBaseDir->setSizePolicy(sizePolicy1);
        poBaseDir->setMinimumSize(QSize(400, 16));

        gridLayout->addWidget(poBaseDir, 4, 1, 1, 2);

        kcfg_PoBaseDir = new RelPathSaver(prefs_projectmain);
        kcfg_PoBaseDir->setObjectName("kcfg_PoBaseDir");

        gridLayout->addWidget(kcfg_PoBaseDir, 7, 1, 1, 2);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 9, 0, 1, 1);

        l1 = new QLabel(prefs_projectmain);
        l1->setObjectName("l1");
        l1->setWordWrap(false);

        gridLayout->addWidget(l1, 4, 0, 1, 1);

        kcfg_LanguageSource = new KComboBox(prefs_projectmain);
        kcfg_LanguageSource->addItem(QString());
        kcfg_LanguageSource->addItem(QString());
        kcfg_LanguageSource->addItem(QString());
        kcfg_LanguageSource->setObjectName("kcfg_LanguageSource");

        gridLayout->addWidget(kcfg_LanguageSource, 3, 1, 1, 1);

        kcfg_ProjLangTeam = new QLineEdit(prefs_projectmain);
        kcfg_ProjLangTeam->setObjectName("kcfg_ProjLangTeam");
        kcfg_ProjLangTeam->setEnabled(false);

        gridLayout->addWidget(kcfg_ProjLangTeam, 3, 2, 1, 1);

        l5 = new QLabel(prefs_projectmain);
        l5->setObjectName("l5");

        gridLayout->addWidget(l5, 3, 0, 1, 1);

#if QT_CONFIG(shortcut)
        l2->setBuddy(glossaryTbx);
        l0->setBuddy(LangCode);
        l4->setBuddy(kcfg_MailingList);
        l3->setBuddy(kcfg_ProjectID);
        l1->setBuddy(poBaseDir);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kcfg_ProjectID, LangCode);
        QWidget::setTabOrder(LangCode, kcfg_MailingList);
        QWidget::setTabOrder(kcfg_MailingList, poBaseDir);
        QWidget::setTabOrder(poBaseDir, glossaryTbx);

        retranslateUi(prefs_projectmain);
        QObject::connect(LangCode, SIGNAL(currentTextChanged(QString)), kcfg_LangCode, SLOT(setText(QString)));

        QMetaObject::connectSlotsByName(prefs_projectmain);
    } // setupUi

    void retranslateUi(QWidget *prefs_projectmain)
    {
        l2->setText(tr2i18n("Glossary:", "@label:textbox"));
        l0->setText(tr2i18n("Target language:", "@label:textbox"));
#if QT_CONFIG(tooltip)
        kcfg_ProjectID->setToolTip(tr2i18n("Project ID is used to differentiate translation memories of absolutely different projects and languages.\n"
"\n"
"For example, if you have several projects for translating KDE applications\n"
"(e.g. they are in different repositories), use same ID for all of them.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        LangCode->setToolTip(tr2i18n("Target language of the project.", nullptr));
#endif // QT_CONFIG(tooltip)
        l4->setText(tr2i18n("Mailing list:", "@label:textbox"));
        l3->setText(tr2i18n("ID:", "@label:textbox"));
#if QT_CONFIG(tooltip)
        poBaseDir->setToolTip(tr2i18n("This is main setting. Set this to path of a folder with translation files\n"
"for your project (or a subproject for your target language).", nullptr));
#endif // QT_CONFIG(tooltip)
        l1->setText(tr2i18n("Root folder:", "@label:textbox"));
        kcfg_LanguageSource->setItemText(0, tr2i18n("Automatic", nullptr));
        kcfg_LanguageSource->setItemText(1, tr2i18n("Application", nullptr));
        kcfg_LanguageSource->setItemText(2, tr2i18n("Project", nullptr));

        l5->setText(tr2i18n("Language-Team:", nullptr));
        (void)prefs_projectmain;
    } // retranslateUi

};

namespace Ui {
    class prefs_projectmain: public Ui_prefs_projectmain {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PREFS_PROJECTMAIN_H

