/****************************************************************************
** Meta object code from reading C++ file 'catalog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../lokalize-26.08.0/src/catalog/catalog.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'catalog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7CatalogE_t {};
} // unnamed namespace

template <> constexpr inline auto Catalog::qt_create_metaobjectdata<qt_meta_tag_ZN7CatalogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Catalog",
        "D-Bus Interface",
        "org.Lokalize.FileContainer",
        "signalEntryModified",
        "",
        "DocPosition",
        "activePhaseChanged",
        "signalNumberOfFuzziesChanged",
        "signalNumberOfEmptyChanged",
        "signalFileLoaded",
        "signalFileSaved",
        "signalFileAutoSaveFailed",
        "source",
        "pos",
        "target",
        "sourceWithTags",
        "CatalogString",
        "targetWithTags",
        "catalogString",
        "setNote",
        "Note",
        "note",
        "notes",
        "QList<Note>",
        "developerNotes",
        "noteAuthors",
        "altTrans",
        "QList<AltTrans>",
        "sourceFiles",
        "context",
        "id",
        "setPhase",
        "phase",
        "activePhase",
        "activePhaseRole",
        "ProjectLocal::PersonRole",
        "setActivePhase",
        "role",
        "Phase",
        "name",
        "allPhases",
        "QList<Phase>",
        "allTools",
        "QMap<QString,Tool>",
        "phaseNotes",
        "setPhaseNotes",
        "isPlural",
        "index",
        "isApproved",
        "state",
        "TargetState",
        "isEquivTrans",
        "isEmpty",
        "isModified",
        "DocPos",
        "entry",
        "isObsolete",
        "binUnitsCount",
        "unitById",
        "isBookmarked",
        "setBookmark",
        "numberOfPluralForms",
        "numberOfEntries",
        "numberOfNonApproved",
        "numberOfUntranslated",
        "url",
        "loadFromUrl",
        "saidUrl",
        "int*",
        "fileSize",
        "fast",
        "saveToUrl",
        "save",
        "contents",
        "mimetype",
        "fileType",
        "type",
        "CatalogType",
        "sourceLangCode",
        "targetLangCode",
        "setTargetLangCode",
        "flushUpdateDBBuffer",
        "doAutoSave",
        "setAutoSaveDirty",
        "projectConfigChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'signalEntryModified'
        QtMocHelpers::SignalData<void(const DocPosition &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 4 },
        }}),
        // Signal 'activePhaseChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalNumberOfFuzziesChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalNumberOfEmptyChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalFileLoaded'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Signal 'signalFileLoaded'
        QtMocHelpers::SignalData<void(const QString &)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'signalFileSaved'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Signal 'signalFileSaved'
        QtMocHelpers::SignalData<void(const QString &)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'signalFileAutoSaveFailed'
        QtMocHelpers::SignalData<void(const QString &)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'source'
        QtMocHelpers::SlotData<QString(const DocPosition &) const>(12, 4, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 5, 13 },
        }}),
        // Slot 'target'
        QtMocHelpers::SlotData<QString(const DocPosition &) const>(14, 4, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 5, 13 },
        }}),
        // Slot 'sourceWithTags'
        QtMocHelpers::SlotData<CatalogString(const DocPosition &) const>(15, 4, QMC::AccessPublic, 0x80000000 | 16, {{
            { 0x80000000 | 5, 13 },
        }}),
        // Slot 'targetWithTags'
        QtMocHelpers::SlotData<CatalogString(const DocPosition &) const>(17, 4, QMC::AccessPublic, 0x80000000 | 16, {{
            { 0x80000000 | 5, 13 },
        }}),
        // Slot 'catalogString'
        QtMocHelpers::SlotData<CatalogString(const DocPosition &) const>(18, 4, QMC::AccessPublic, 0x80000000 | 16, {{
            { 0x80000000 | 5, 13 },
        }}),
        // Slot 'setNote'
        QtMocHelpers::SlotData<Note(const DocPosition &, const Note &)>(19, 4, QMC::AccessPublic, 0x80000000 | 20, {{
            { 0x80000000 | 5, 13 }, { 0x80000000 | 20, 21 },
        }}),
        // Slot 'notes'
        QtMocHelpers::SlotData<QVector<Note>(const DocPosition &) const>(22, 4, QMC::AccessPublic, 0x80000000 | 23, {{
            { 0x80000000 | 5, 13 },
        }}),
        // Slot 'developerNotes'
        QtMocHelpers::SlotData<QVector<Note>(const DocPosition &) const>(24, 4, QMC::AccessPublic, 0x80000000 | 23, {{
            { 0x80000000 | 5, 13 },
        }}),
        // Slot 'noteAuthors'
        QtMocHelpers::SlotData<QStringList() const>(25, 4, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'altTrans'
        QtMocHelpers::SlotData<QVector<AltTrans>(const DocPosition &) const>(26, 4, QMC::AccessPublic, 0x80000000 | 27, {{
            { 0x80000000 | 5, 13 },
        }}),
        // Slot 'sourceFiles'
        QtMocHelpers::SlotData<QStringList(const DocPosition &) const>(28, 4, QMC::AccessPublic, QMetaType::QStringList, {{
            { 0x80000000 | 5, 13 },
        }}),
        // Slot 'context'
        QtMocHelpers::SlotData<QStringList(const DocPosition &) const>(29, 4, QMC::AccessPublic, QMetaType::QStringList, {{
            { 0x80000000 | 5, 13 },
        }}),
        // Slot 'id'
        QtMocHelpers::SlotData<QString(const DocPosition &) const>(30, 4, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 5, 13 },
        }}),
        // Slot 'setPhase'
        QtMocHelpers::SlotData<QString(const DocPosition &, const QString &)>(31, 4, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 5, 13 }, { QMetaType::QString, 32 },
        }}),
        // Slot 'phase'
        QtMocHelpers::SlotData<QString(const DocPosition &) const>(32, 4, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 5, 13 },
        }}),
        // Slot 'activePhase'
        QtMocHelpers::SlotData<QString() const>(33, 4, QMC::AccessPublic, QMetaType::QString),
        // Slot 'activePhaseRole'
        QtMocHelpers::SlotData<ProjectLocal::PersonRole() const>(34, 4, QMC::AccessPublic, 0x80000000 | 35),
        // Slot 'setActivePhase'
        QtMocHelpers::SlotData<void(const QString &, ProjectLocal::PersonRole)>(36, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 32 }, { 0x80000000 | 35, 37 },
        }}),
        // Slot 'setActivePhase'
        QtMocHelpers::SlotData<void(const QString &)>(36, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 32 },
        }}),
        // Slot 'phase'
        QtMocHelpers::SlotData<Phase(const QString &) const>(32, 4, QMC::AccessPublic, 0x80000000 | 38, {{
            { QMetaType::QString, 39 },
        }}),
        // Slot 'allPhases'
        QtMocHelpers::SlotData<QList<Phase>() const>(40, 4, QMC::AccessPublic, 0x80000000 | 41),
        // Slot 'allTools'
        QtMocHelpers::SlotData<QMap<QString,Tool>() const>(42, 4, QMC::AccessPublic, 0x80000000 | 43),
        // Slot 'phaseNotes'
        QtMocHelpers::SlotData<QVector<Note>(const QString &) const>(44, 4, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::QString, 32 },
        }}),
        // Slot 'setPhaseNotes'
        QtMocHelpers::SlotData<QVector<Note>(const QString &, QVector<Note>)>(45, 4, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::QString, 32 }, { 0x80000000 | 23, 4 },
        }}),
        // Slot 'isPlural'
        QtMocHelpers::SlotData<bool(uint) const>(46, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::UInt, 47 },
        }}),
        // Slot 'isPlural'
        QtMocHelpers::SlotData<bool(const DocPosition &) const>(46, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 5, 13 },
        }}),
        // Slot 'isApproved'
        QtMocHelpers::SlotData<bool(uint) const>(48, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::UInt, 47 },
        }}),
        // Slot 'isApproved'
        QtMocHelpers::SlotData<bool(const DocPosition &) const>(48, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 5, 13 },
        }}),
        // Slot 'state'
        QtMocHelpers::SlotData<TargetState(const DocPosition &) const>(49, 4, QMC::AccessPublic, 0x80000000 | 50, {{
            { 0x80000000 | 5, 13 },
        }}),
        // Slot 'isEquivTrans'
        QtMocHelpers::SlotData<bool(const DocPosition &) const>(51, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 5, 4 },
        }}),
        // Slot 'isEmpty'
        QtMocHelpers::SlotData<bool(uint) const>(52, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::UInt, 47 },
        }}),
        // Slot 'isEmpty'
        QtMocHelpers::SlotData<bool(const DocPosition &) const>(52, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 5, 4 },
        }}),
        // Slot 'isModified'
        QtMocHelpers::SlotData<bool(DocPos) const>(53, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 54, 55 },
        }}),
        // Slot 'isModified'
        QtMocHelpers::SlotData<bool(int) const>(53, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 55 },
        }}),
        // Slot 'isObsolete'
        QtMocHelpers::SlotData<bool(int) const>(56, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 55 },
        }}),
        // Slot 'binUnitsCount'
        QtMocHelpers::SlotData<int() const>(57, 4, QMC::AccessPublic, QMetaType::Int),
        // Slot 'unitById'
        QtMocHelpers::SlotData<int(const QString &) const>(58, 4, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 30 },
        }}),
        // Slot 'isBookmarked'
        QtMocHelpers::SlotData<bool(uint) const>(59, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::UInt, 47 },
        }}),
        // Slot 'setBookmark'
        QtMocHelpers::SlotData<void(uint, bool)>(60, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 4 }, { QMetaType::Bool, 4 },
        }}),
        // Slot 'numberOfPluralForms'
        QtMocHelpers::SlotData<int() const>(61, 4, QMC::AccessPublic, QMetaType::Int),
        // Slot 'numberOfEntries'
        QtMocHelpers::SlotData<int() const>(62, 4, QMC::AccessPublic, QMetaType::Int),
        // Slot 'numberOfNonApproved'
        QtMocHelpers::SlotData<int() const>(63, 4, QMC::AccessPublic, QMetaType::Int),
        // Slot 'numberOfUntranslated'
        QtMocHelpers::SlotData<int() const>(64, 4, QMC::AccessPublic, QMetaType::Int),
        // Slot 'url'
        QtMocHelpers::SlotData<void() const>(65, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'loadFromUrl'
        QtMocHelpers::SlotData<int(const QString &, const QString &, int *, bool)>(66, 4, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 65 }, { QMetaType::QString, 67 }, { 0x80000000 | 68, 69 }, { QMetaType::Bool, 70 },
        }}),
        // Slot 'loadFromUrl'
        QtMocHelpers::SlotData<int(const QString &, const QString &, int *)>(66, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int, {{
            { QMetaType::QString, 65 }, { QMetaType::QString, 67 }, { 0x80000000 | 68, 69 },
        }}),
        // Slot 'loadFromUrl'
        QtMocHelpers::SlotData<int(const QString &, const QString &)>(66, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int, {{
            { QMetaType::QString, 65 }, { QMetaType::QString, 67 },
        }}),
        // Slot 'loadFromUrl'
        QtMocHelpers::SlotData<int(const QString &)>(66, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int, {{
            { QMetaType::QString, 65 },
        }}),
        // Slot 'saveToUrl'
        QtMocHelpers::SlotData<bool(QString)>(71, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 65 },
        }}),
        // Slot 'save'
        QtMocHelpers::SlotData<bool()>(72, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'contents'
        QtMocHelpers::SlotData<QByteArray()>(73, 4, QMC::AccessPublic, QMetaType::QByteArray),
        // Slot 'mimetype'
        QtMocHelpers::SlotData<QString()>(74, 4, QMC::AccessPublic, QMetaType::QString),
        // Slot 'fileType'
        QtMocHelpers::SlotData<QString()>(75, 4, QMC::AccessPublic, QMetaType::QString),
        // Slot 'type'
        QtMocHelpers::SlotData<CatalogType()>(76, 4, QMC::AccessPublic, 0x80000000 | 77),
        // Slot 'sourceLangCode'
        QtMocHelpers::SlotData<QString() const>(78, 4, QMC::AccessPublic, QMetaType::QString),
        // Slot 'targetLangCode'
        QtMocHelpers::SlotData<QString() const>(79, 4, QMC::AccessPublic, QMetaType::QString),
        // Slot 'setTargetLangCode'
        QtMocHelpers::SlotData<void(const QString &)>(80, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 79 },
        }}),
        // Slot 'flushUpdateDBBuffer'
        QtMocHelpers::SlotData<void()>(81, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'doAutoSave'
        QtMocHelpers::SlotData<void()>(82, 4, QMC::AccessProtected, QMetaType::Void),
        // Slot 'setAutoSaveDirty'
        QtMocHelpers::SlotData<void()>(83, 4, QMC::AccessProtected, QMetaType::Void),
        // Slot 'projectConfigChanged'
        QtMocHelpers::SlotData<void()>(84, 4, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Catalog, qt_meta_tag_ZN7CatalogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Catalog::staticMetaObject = { {
    QMetaObject::SuperData::link<QUndoStack::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7CatalogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7CatalogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7CatalogE_t>.metaTypes,
    nullptr
} };

void Catalog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Catalog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->signalEntryModified((*reinterpret_cast<std::add_pointer_t<DocPosition>>(_a[1]))); break;
        case 1: _t->activePhaseChanged(); break;
        case 2: _t->signalNumberOfFuzziesChanged(); break;
        case 3: _t->signalNumberOfEmptyChanged(); break;
        case 4: _t->signalFileLoaded(); break;
        case 5: _t->signalFileLoaded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->signalFileSaved(); break;
        case 7: _t->signalFileSaved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->signalFileAutoSaveFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: { QString _r = _t->source((*reinterpret_cast<std::add_pointer_t<DocPosition>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 10: { QString _r = _t->target((*reinterpret_cast<std::add_pointer_t<DocPosition>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 11: { CatalogString _r = _t->sourceWithTags((*reinterpret_cast<std::add_pointer_t<DocPosition>>(_a[1])));
            if (_a[0]) *reinterpret_cast<CatalogString*>(_a[0]) = std::move(_r); }  break;
        case 12: { CatalogString _r = _t->targetWithTags((*reinterpret_cast<std::add_pointer_t<DocPosition>>(_a[1])));
            if (_a[0]) *reinterpret_cast<CatalogString*>(_a[0]) = std::move(_r); }  break;
        case 13: { CatalogString _r = _t->catalogString((*reinterpret_cast<std::add_pointer_t<DocPosition>>(_a[1])));
            if (_a[0]) *reinterpret_cast<CatalogString*>(_a[0]) = std::move(_r); }  break;
        case 14: { Note _r = _t->setNote((*reinterpret_cast<std::add_pointer_t<DocPosition>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Note>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Note*>(_a[0]) = std::move(_r); }  break;
        case 15: { QList<Note> _r = _t->notes((*reinterpret_cast<std::add_pointer_t<DocPosition>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QList<Note>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QList<Note> _r = _t->developerNotes((*reinterpret_cast<std::add_pointer_t<DocPosition>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QList<Note>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QStringList _r = _t->noteAuthors();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 18: { QList<AltTrans> _r = _t->altTrans((*reinterpret_cast<std::add_pointer_t<DocPosition>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QList<AltTrans>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QStringList _r = _t->sourceFiles((*reinterpret_cast<std::add_pointer_t<DocPosition>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 20: { QStringList _r = _t->context((*reinterpret_cast<std::add_pointer_t<DocPosition>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 21: { QString _r = _t->id((*reinterpret_cast<std::add_pointer_t<DocPosition>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 22: { QString _r = _t->setPhase((*reinterpret_cast<std::add_pointer_t<DocPosition>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 23: { QString _r = _t->phase((*reinterpret_cast<std::add_pointer_t<DocPosition>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 24: { QString _r = _t->activePhase();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 25: { ProjectLocal::PersonRole _r = _t->activePhaseRole();
            if (_a[0]) *reinterpret_cast<ProjectLocal::PersonRole*>(_a[0]) = std::move(_r); }  break;
        case 26: _t->setActivePhase((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ProjectLocal::PersonRole>>(_a[2]))); break;
        case 27: _t->setActivePhase((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 28: { Phase _r = _t->phase((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Phase*>(_a[0]) = std::move(_r); }  break;
        case 29: { QList<Phase> _r = _t->allPhases();
            if (_a[0]) *reinterpret_cast<QList<Phase>*>(_a[0]) = std::move(_r); }  break;
        case 30: { QMap<QString,Tool> _r = _t->allTools();
            if (_a[0]) *reinterpret_cast<QMap<QString,Tool>*>(_a[0]) = std::move(_r); }  break;
        case 31: { QList<Note> _r = _t->phaseNotes((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QList<Note>*>(_a[0]) = std::move(_r); }  break;
        case 32: { QList<Note> _r = _t->setPhaseNotes((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<Note>>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QList<Note>*>(_a[0]) = std::move(_r); }  break;
        case 33: { bool _r = _t->isPlural((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 34: { bool _r = _t->isPlural((*reinterpret_cast<std::add_pointer_t<DocPosition>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 35: { bool _r = _t->isApproved((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 36: { bool _r = _t->isApproved((*reinterpret_cast<std::add_pointer_t<DocPosition>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 37: { TargetState _r = _t->state((*reinterpret_cast<std::add_pointer_t<DocPosition>>(_a[1])));
            if (_a[0]) *reinterpret_cast<TargetState*>(_a[0]) = std::move(_r); }  break;
        case 38: { bool _r = _t->isEquivTrans((*reinterpret_cast<std::add_pointer_t<DocPosition>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 39: { bool _r = _t->isEmpty((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 40: { bool _r = _t->isEmpty((*reinterpret_cast<std::add_pointer_t<DocPosition>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 41: { bool _r = _t->isModified((*reinterpret_cast<std::add_pointer_t<DocPos>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 42: { bool _r = _t->isModified((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 43: { bool _r = _t->isObsolete((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 44: { int _r = _t->binUnitsCount();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 45: { int _r = _t->unitById((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 46: { bool _r = _t->isBookmarked((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 47: _t->setBookmark((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 48: { int _r = _t->numberOfPluralForms();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 49: { int _r = _t->numberOfEntries();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 50: { int _r = _t->numberOfNonApproved();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 51: { int _r = _t->numberOfUntranslated();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 52: _t->url(); break;
        case 53: { int _r = _t->loadFromUrl((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int*>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 54: { int _r = _t->loadFromUrl((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int*>>(_a[3])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 55: { int _r = _t->loadFromUrl((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 56: { int _r = _t->loadFromUrl((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 57: { bool _r = _t->saveToUrl((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 58: { bool _r = _t->save();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 59: { QByteArray _r = _t->contents();
            if (_a[0]) *reinterpret_cast<QByteArray*>(_a[0]) = std::move(_r); }  break;
        case 60: { QString _r = _t->mimetype();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 61: { QString _r = _t->fileType();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 62: { CatalogType _r = _t->type();
            if (_a[0]) *reinterpret_cast<CatalogType*>(_a[0]) = std::move(_r); }  break;
        case 63: { QString _r = _t->sourceLangCode();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 64: { QString _r = _t->targetLangCode();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 65: _t->setTargetLangCode((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 66: _t->flushUpdateDBBuffer(); break;
        case 67: _t->doAutoSave(); break;
        case 68: _t->setAutoSaveDirty(); break;
        case 69: _t->projectConfigChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DocPosition >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DocPosition >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DocPosition >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DocPosition >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DocPosition >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DocPosition >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DocPosition >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DocPosition >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DocPosition >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DocPosition >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DocPosition >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DocPosition >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DocPosition >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DocPosition >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DocPosition >(); break;
            }
            break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DocPosition >(); break;
            }
            break;
        case 36:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DocPosition >(); break;
            }
            break;
        case 37:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DocPosition >(); break;
            }
            break;
        case 38:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DocPosition >(); break;
            }
            break;
        case 40:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DocPosition >(); break;
            }
            break;
        case 41:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DocPos >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Catalog::*)(const DocPosition & )>(_a, &Catalog::signalEntryModified, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Catalog::*)()>(_a, &Catalog::activePhaseChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Catalog::*)()>(_a, &Catalog::signalNumberOfFuzziesChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Catalog::*)()>(_a, &Catalog::signalNumberOfEmptyChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Catalog::*)()>(_a, &Catalog::signalFileLoaded, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Catalog::*)(const QString & )>(_a, &Catalog::signalFileLoaded, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Catalog::*)()>(_a, &Catalog::signalFileSaved, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Catalog::*)(const QString & )>(_a, &Catalog::signalFileSaved, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Catalog::*)(const QString & )>(_a, &Catalog::signalFileAutoSaveFailed, 8))
            return;
    }
}

const QMetaObject *Catalog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Catalog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7CatalogE_t>.strings))
        return static_cast<void*>(this);
    return QUndoStack::qt_metacast(_clname);
}

int Catalog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QUndoStack::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 70)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 70;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 70)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 70;
    }
    return _id;
}

// SIGNAL 0
void Catalog::signalEntryModified(const DocPosition & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Catalog::activePhaseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Catalog::signalNumberOfFuzziesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Catalog::signalNumberOfEmptyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Catalog::signalFileLoaded()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Catalog::signalFileLoaded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Catalog::signalFileSaved()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Catalog::signalFileSaved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Catalog::signalFileAutoSaveFailed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}
QT_WARNING_POP
