/********************************************************************************
** Form generated from reading UI file 'prefs_languagetool.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFS_LANGUAGETOOL_H
#define UI_PREFS_LANGUAGETOOL_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_prefs_languagetool
{
public:
    QVBoxLayout *vboxLayout;
    QFormLayout *formLayout;
    QCheckBox *kcfg_LanguageToolCustom;
    QHBoxLayout *hboxLayout;
    QLabel *textLabel2_2;
    QLineEdit *kcfg_LanguageToolInstancePath;
    QHBoxLayout *hboxLayout1;
    QLabel *l1;
    QSpinBox *kcfg_LanguageToolDelay;

    void setupUi(QWidget *prefs_languagetool)
    {
        if (prefs_languagetool->objectName().isEmpty())
            prefs_languagetool->setObjectName("prefs_languagetool");
        prefs_languagetool->resize(611, 439);
        vboxLayout = new QVBoxLayout(prefs_languagetool);
        vboxLayout->setObjectName("vboxLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        kcfg_LanguageToolCustom = new QCheckBox(prefs_languagetool);
        kcfg_LanguageToolCustom->setObjectName("kcfg_LanguageToolCustom");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, kcfg_LanguageToolCustom);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        textLabel2_2 = new QLabel(prefs_languagetool);
        textLabel2_2->setObjectName("textLabel2_2");
        textLabel2_2->setWordWrap(false);

        hboxLayout->addWidget(textLabel2_2);

        kcfg_LanguageToolInstancePath = new QLineEdit(prefs_languagetool);
        kcfg_LanguageToolInstancePath->setObjectName("kcfg_LanguageToolInstancePath");

        hboxLayout->addWidget(kcfg_LanguageToolInstancePath);


        formLayout->setLayout(2, QFormLayout::ItemRole::LabelRole, hboxLayout);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        l1 = new QLabel(prefs_languagetool);
        l1->setObjectName("l1");

        hboxLayout1->addWidget(l1);

        kcfg_LanguageToolDelay = new QSpinBox(prefs_languagetool);
        kcfg_LanguageToolDelay->setObjectName("kcfg_LanguageToolDelay");
        kcfg_LanguageToolDelay->setMinimum(0);
        kcfg_LanguageToolDelay->setMaximum(20);

        hboxLayout1->addWidget(kcfg_LanguageToolDelay);


        formLayout->setLayout(3, QFormLayout::ItemRole::LabelRole, hboxLayout1);


        vboxLayout->addLayout(formLayout);

#if QT_CONFIG(shortcut)
        textLabel2_2->setBuddy(kcfg_LanguageToolInstancePath);
        l1->setBuddy(kcfg_LanguageToolDelay);
#endif // QT_CONFIG(shortcut)

        retranslateUi(prefs_languagetool);

        QMetaObject::connectSlotsByName(prefs_languagetool);
    } // setupUi

    void retranslateUi(QWidget *prefs_languagetool)
    {
        kcfg_LanguageToolCustom->setText(tr2i18n("Use custom LanguageTool server", nullptr));
        textLabel2_2->setText(tr2i18n("Server Path:", "@label:textbox"));
#if QT_CONFIG(tooltip)
        kcfg_LanguageToolInstancePath->setToolTip(tr2i18n("The path of your custom Language Tool server", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_LanguageToolInstancePath->setWhatsThis(tr2i18n("Please enter the path of your custom Language Tool server, if any", nullptr));
#endif // QT_CONFIG(whatsthis)
        l1->setText(tr2i18n("Delay before automatic checking after you stop typing (in seconds, 0 to disable)", nullptr));
#if QT_CONFIG(tooltip)
        l1->setToolTip(tr2i18n("Set to 0 to disable auto checking", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_LanguageToolDelay->setToolTip(tr2i18n("Set to 0 to disable auto checking", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)prefs_languagetool;
    } // retranslateUi

};

namespace Ui {
    class prefs_languagetool: public Ui_prefs_languagetool {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PREFS_LANGUAGETOOL_H

