/****************************************************************************
** Meta object code from reading C++ file 'xlifftextedit.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../lokalize-26.08.0/src/xlifftextedit.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'xlifftextedit.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23TranslationUnitTextEditE_t {};
} // unnamed namespace

template <> constexpr inline auto TranslationUnitTextEdit::qt_create_metaobjectdata<qt_meta_tag_ZN23TranslationUnitTextEditE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TranslationUnitTextEdit",
        "toggleApprovementRequested",
        "",
        "undoRequested",
        "redoRequested",
        "findRequested",
        "findNextRequested",
        "replaceRequested",
        "gotoFirstRequested",
        "gotoLastRequested",
        "gotoPrevRequested",
        "gotoNextRequested",
        "gotoPrevFuzzyRequested",
        "gotoNextFuzzyRequested",
        "gotoPrevUntranslatedRequested",
        "gotoNextUntranslatedRequested",
        "gotoPrevFuzzyUntrRequested",
        "gotoNextFuzzyUntrRequested",
        "gotoEntryRequested",
        "DocPosition",
        "zoomRequested",
        "tagInsertRequested",
        "InlineTag",
        "tag",
        "binaryUnitSelectRequested",
        "languageToolChanged",
        "tmLookupRequested",
        "DocPosition::Part",
        "contentsModified",
        "approvedEntryDisplayed",
        "nonApprovedEntryDisplayed",
        "translatedEntryDisplayed",
        "untranslatedEntryDisplayed",
        "cursorPositionChanged",
        "column",
        "reflectApprovementState",
        "reflectUntranslatedState",
        "removeTargetSubstring",
        "start",
        "end",
        "refresh",
        "insertCatalogString",
        "CatalogString",
        "catStr",
        "source2target",
        "tagMenu",
        "tagImmediate",
        "insertTag",
        "skipTags",
        "spellReplace",
        "launchLanguageTool",
        "emitCursorPositionChanged",
        "doExplicitCompletion",
        "zoomRequestedSlot",
        "fontSize",
        "contentsChanged",
        "position",
        "charsRemoved",
        "charsAdded",
        "completionActivated",
        "fileLoaded",
        "slotLanguageToolFinished",
        "result",
        "slotLanguageToolError",
        "str"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'toggleApprovementRequested'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'undoRequested'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'redoRequested'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'findRequested'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'findNextRequested'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'replaceRequested'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'gotoFirstRequested'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'gotoLastRequested'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'gotoPrevRequested'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'gotoNextRequested'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'gotoPrevFuzzyRequested'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'gotoNextFuzzyRequested'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'gotoPrevUntranslatedRequested'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'gotoNextUntranslatedRequested'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'gotoPrevFuzzyUntrRequested'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'gotoNextFuzzyUntrRequested'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'gotoEntryRequested'
        QtMocHelpers::SignalData<void(const DocPosition &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 2 },
        }}),
        // Signal 'zoomRequested'
        QtMocHelpers::SignalData<void(qreal)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'tagInsertRequested'
        QtMocHelpers::SignalData<void(const InlineTag &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Signal 'binaryUnitSelectRequested'
        QtMocHelpers::SignalData<void(const QString &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'languageToolChanged'
        QtMocHelpers::SignalData<void(const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'tmLookupRequested'
        QtMocHelpers::SignalData<void(DocPosition::Part, const QString &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 2 }, { QMetaType::QString, 2 },
        }}),
        // Signal 'contentsModified'
        QtMocHelpers::SignalData<void(const DocPosition &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 2 },
        }}),
        // Signal 'approvedEntryDisplayed'
        QtMocHelpers::SignalData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nonApprovedEntryDisplayed'
        QtMocHelpers::SignalData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'translatedEntryDisplayed'
        QtMocHelpers::SignalData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'untranslatedEntryDisplayed'
        QtMocHelpers::SignalData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cursorPositionChanged'
        QtMocHelpers::SignalData<void(int)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 },
        }}),
        // Slot 'reflectApprovementState'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reflectUntranslatedState'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'removeTargetSubstring'
        QtMocHelpers::SlotData<bool(int, int, bool)>(37, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 38 }, { QMetaType::Int, 39 }, { QMetaType::Bool, 40 },
        }}),
        // Slot 'removeTargetSubstring'
        QtMocHelpers::SlotData<bool(int, int)>(37, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Int, 38 }, { QMetaType::Int, 39 },
        }}),
        // Slot 'removeTargetSubstring'
        QtMocHelpers::SlotData<bool(int)>(37, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Int, 38 },
        }}),
        // Slot 'removeTargetSubstring'
        QtMocHelpers::SlotData<bool()>(37, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool),
        // Slot 'insertCatalogString'
        QtMocHelpers::SlotData<void(CatalogString, int, bool)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 42, 43 }, { QMetaType::Int, 38 }, { QMetaType::Bool, 40 },
        }}),
        // Slot 'insertCatalogString'
        QtMocHelpers::SlotData<void(CatalogString, int)>(41, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 42, 43 }, { QMetaType::Int, 38 },
        }}),
        // Slot 'insertCatalogString'
        QtMocHelpers::SlotData<void(CatalogString)>(41, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 42, 43 },
        }}),
        // Slot 'source2target'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'tagMenu'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'tagImmediate'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insertTag'
        QtMocHelpers::SlotData<void(InlineTag)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'skipTags'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'spellReplace'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'launchLanguageTool'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'emitCursorPositionChanged'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'doExplicitCompletion'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomRequestedSlot'
        QtMocHelpers::SlotData<void(qreal)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 54 },
        }}),
        // Slot 'contentsChanged'
        QtMocHelpers::SlotData<void(int, int, int)>(55, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 56 }, { QMetaType::Int, 57 }, { QMetaType::Int, 58 },
        }}),
        // Slot 'completionActivated'
        QtMocHelpers::SlotData<void(const QString &)>(59, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'fileLoaded'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotLanguageToolFinished'
        QtMocHelpers::SlotData<void(const QString &)>(61, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 62 },
        }}),
        // Slot 'slotLanguageToolError'
        QtMocHelpers::SlotData<void(const QString &)>(63, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 64 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TranslationUnitTextEdit, qt_meta_tag_ZN23TranslationUnitTextEditE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TranslationUnitTextEdit::staticMetaObject = { {
    QMetaObject::SuperData::link<KTextEdit::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23TranslationUnitTextEditE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23TranslationUnitTextEditE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23TranslationUnitTextEditE_t>.metaTypes,
    nullptr
} };

void TranslationUnitTextEdit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TranslationUnitTextEdit *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->toggleApprovementRequested(); break;
        case 1: _t->undoRequested(); break;
        case 2: _t->redoRequested(); break;
        case 3: _t->findRequested(); break;
        case 4: _t->findNextRequested(); break;
        case 5: _t->replaceRequested(); break;
        case 6: _t->gotoFirstRequested(); break;
        case 7: _t->gotoLastRequested(); break;
        case 8: _t->gotoPrevRequested(); break;
        case 9: _t->gotoNextRequested(); break;
        case 10: _t->gotoPrevFuzzyRequested(); break;
        case 11: _t->gotoNextFuzzyRequested(); break;
        case 12: _t->gotoPrevUntranslatedRequested(); break;
        case 13: _t->gotoNextUntranslatedRequested(); break;
        case 14: _t->gotoPrevFuzzyUntrRequested(); break;
        case 15: _t->gotoNextFuzzyUntrRequested(); break;
        case 16: _t->gotoEntryRequested((*reinterpret_cast<std::add_pointer_t<DocPosition>>(_a[1]))); break;
        case 17: _t->zoomRequested((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 18: _t->tagInsertRequested((*reinterpret_cast<std::add_pointer_t<InlineTag>>(_a[1]))); break;
        case 19: _t->binaryUnitSelectRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: _t->languageToolChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 21: _t->tmLookupRequested((*reinterpret_cast<std::add_pointer_t<DocPosition::Part>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 22: _t->contentsModified((*reinterpret_cast<std::add_pointer_t<DocPosition>>(_a[1]))); break;
        case 23: _t->approvedEntryDisplayed(); break;
        case 24: _t->nonApprovedEntryDisplayed(); break;
        case 25: _t->translatedEntryDisplayed(); break;
        case 26: _t->untranslatedEntryDisplayed(); break;
        case 27: _t->cursorPositionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 28: _t->reflectApprovementState(); break;
        case 29: _t->reflectUntranslatedState(); break;
        case 30: { bool _r = _t->removeTargetSubstring((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 31: { bool _r = _t->removeTargetSubstring((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 32: { bool _r = _t->removeTargetSubstring((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 33: { bool _r = _t->removeTargetSubstring();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 34: _t->insertCatalogString((*reinterpret_cast<std::add_pointer_t<CatalogString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 35: _t->insertCatalogString((*reinterpret_cast<std::add_pointer_t<CatalogString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 36: _t->insertCatalogString((*reinterpret_cast<std::add_pointer_t<CatalogString>>(_a[1]))); break;
        case 37: _t->source2target(); break;
        case 38: _t->tagMenu(); break;
        case 39: _t->tagImmediate(); break;
        case 40: _t->insertTag((*reinterpret_cast<std::add_pointer_t<InlineTag>>(_a[1]))); break;
        case 41: _t->skipTags(); break;
        case 42: _t->spellReplace(); break;
        case 43: _t->launchLanguageTool(); break;
        case 44: _t->emitCursorPositionChanged(); break;
        case 45: _t->doExplicitCompletion(); break;
        case 46: _t->zoomRequestedSlot((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 47: _t->contentsChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 48: _t->completionActivated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 49: _t->fileLoaded(); break;
        case 50: _t->slotLanguageToolFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 51: _t->slotLanguageToolError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DocPosition >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< InlineTag >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DocPosition >(); break;
            }
            break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< CatalogString >(); break;
            }
            break;
        case 35:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< CatalogString >(); break;
            }
            break;
        case 36:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< CatalogString >(); break;
            }
            break;
        case 40:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< InlineTag >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TranslationUnitTextEdit::*)()>(_a, &TranslationUnitTextEdit::toggleApprovementRequested, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TranslationUnitTextEdit::*)()>(_a, &TranslationUnitTextEdit::undoRequested, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TranslationUnitTextEdit::*)()>(_a, &TranslationUnitTextEdit::redoRequested, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TranslationUnitTextEdit::*)()>(_a, &TranslationUnitTextEdit::findRequested, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TranslationUnitTextEdit::*)()>(_a, &TranslationUnitTextEdit::findNextRequested, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TranslationUnitTextEdit::*)()>(_a, &TranslationUnitTextEdit::replaceRequested, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TranslationUnitTextEdit::*)()>(_a, &TranslationUnitTextEdit::gotoFirstRequested, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (TranslationUnitTextEdit::*)()>(_a, &TranslationUnitTextEdit::gotoLastRequested, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (TranslationUnitTextEdit::*)()>(_a, &TranslationUnitTextEdit::gotoPrevRequested, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (TranslationUnitTextEdit::*)()>(_a, &TranslationUnitTextEdit::gotoNextRequested, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (TranslationUnitTextEdit::*)()>(_a, &TranslationUnitTextEdit::gotoPrevFuzzyRequested, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (TranslationUnitTextEdit::*)()>(_a, &TranslationUnitTextEdit::gotoNextFuzzyRequested, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (TranslationUnitTextEdit::*)()>(_a, &TranslationUnitTextEdit::gotoPrevUntranslatedRequested, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (TranslationUnitTextEdit::*)()>(_a, &TranslationUnitTextEdit::gotoNextUntranslatedRequested, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (TranslationUnitTextEdit::*)()>(_a, &TranslationUnitTextEdit::gotoPrevFuzzyUntrRequested, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (TranslationUnitTextEdit::*)()>(_a, &TranslationUnitTextEdit::gotoNextFuzzyUntrRequested, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (TranslationUnitTextEdit::*)(const DocPosition & )>(_a, &TranslationUnitTextEdit::gotoEntryRequested, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (TranslationUnitTextEdit::*)(qreal )>(_a, &TranslationUnitTextEdit::zoomRequested, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (TranslationUnitTextEdit::*)(const InlineTag & )>(_a, &TranslationUnitTextEdit::tagInsertRequested, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (TranslationUnitTextEdit::*)(const QString & )>(_a, &TranslationUnitTextEdit::binaryUnitSelectRequested, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (TranslationUnitTextEdit::*)(const QString & )>(_a, &TranslationUnitTextEdit::languageToolChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (TranslationUnitTextEdit::*)(DocPosition::Part , const QString & )>(_a, &TranslationUnitTextEdit::tmLookupRequested, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (TranslationUnitTextEdit::*)(const DocPosition & )>(_a, &TranslationUnitTextEdit::contentsModified, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (TranslationUnitTextEdit::*)()>(_a, &TranslationUnitTextEdit::approvedEntryDisplayed, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (TranslationUnitTextEdit::*)()>(_a, &TranslationUnitTextEdit::nonApprovedEntryDisplayed, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (TranslationUnitTextEdit::*)()>(_a, &TranslationUnitTextEdit::translatedEntryDisplayed, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (TranslationUnitTextEdit::*)()>(_a, &TranslationUnitTextEdit::untranslatedEntryDisplayed, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (TranslationUnitTextEdit::*)(int )>(_a, &TranslationUnitTextEdit::cursorPositionChanged, 27))
            return;
    }
}

const QMetaObject *TranslationUnitTextEdit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TranslationUnitTextEdit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23TranslationUnitTextEditE_t>.strings))
        return static_cast<void*>(this);
    return KTextEdit::qt_metacast(_clname);
}

int TranslationUnitTextEdit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEdit::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 52)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 52;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 52)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 52;
    }
    return _id;
}

// SIGNAL 0
void TranslationUnitTextEdit::toggleApprovementRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TranslationUnitTextEdit::undoRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void TranslationUnitTextEdit::redoRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void TranslationUnitTextEdit::findRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void TranslationUnitTextEdit::findNextRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void TranslationUnitTextEdit::replaceRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void TranslationUnitTextEdit::gotoFirstRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void TranslationUnitTextEdit::gotoLastRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void TranslationUnitTextEdit::gotoPrevRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void TranslationUnitTextEdit::gotoNextRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void TranslationUnitTextEdit::gotoPrevFuzzyRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void TranslationUnitTextEdit::gotoNextFuzzyRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void TranslationUnitTextEdit::gotoPrevUntranslatedRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void TranslationUnitTextEdit::gotoNextUntranslatedRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void TranslationUnitTextEdit::gotoPrevFuzzyUntrRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void TranslationUnitTextEdit::gotoNextFuzzyUntrRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void TranslationUnitTextEdit::gotoEntryRequested(const DocPosition & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void TranslationUnitTextEdit::zoomRequested(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void TranslationUnitTextEdit::tagInsertRequested(const InlineTag & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void TranslationUnitTextEdit::binaryUnitSelectRequested(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void TranslationUnitTextEdit::languageToolChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void TranslationUnitTextEdit::tmLookupRequested(DocPosition::Part _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1, _t2);
}

// SIGNAL 22
void TranslationUnitTextEdit::contentsModified(const DocPosition & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void TranslationUnitTextEdit::approvedEntryDisplayed()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void TranslationUnitTextEdit::nonApprovedEntryDisplayed()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void TranslationUnitTextEdit::translatedEntryDisplayed()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void TranslationUnitTextEdit::untranslatedEntryDisplayed()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void TranslationUnitTextEdit::cursorPositionChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 27, nullptr, _t1);
}
QT_WARNING_POP
