/********************************************************************************
** Form generated from reading UI file 'queryoptions.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QUERYOPTIONS_H
#define UI_QUERYOPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_QueryOptions
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer_2;
    QLabel *label;
    QComboBox *dbName;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *queryLayout;
    QGridLayout *mainQueryLayout;
    QLineEdit *querySource;
    QLineEdit *queryTarget;
    QLabel *querySourceLabel;
    QLabel *queryTargetLabel;
    QCheckBox *invertTarget;
    QCheckBox *invertSource;
    QFrame *line;
    QGridLayout *optionsLayout;
    QLabel *label_2;
    QLineEdit *filemask;
    QLabel *label_s;
    KComboBox *queryStyle;
    QFrame *line_2;
    QVBoxLayout *buttonsLayout;
    QPushButton *doFind;
    QPushButton *doUpdateTM;
    QTreeView *treeView;

    void setupUi(QWidget *QueryOptions)
    {
        if (QueryOptions->objectName().isEmpty())
            QueryOptions->setObjectName("QueryOptions");
        QueryOptions->resize(600, 278);
        vboxLayout = new QVBoxLayout(QueryOptions);
        vboxLayout->setObjectName("vboxLayout");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        label = new QLabel(QueryOptions);
        label->setObjectName("label");

        horizontalLayout_2->addWidget(label);

        dbName = new QComboBox(QueryOptions);
        dbName->setObjectName("dbName");
        dbName->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        horizontalLayout_2->addWidget(dbName);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        vboxLayout->addLayout(horizontalLayout_2);

        queryLayout = new QHBoxLayout();
        queryLayout->setObjectName("queryLayout");
        queryLayout->setSizeConstraint(QLayout::SetMinimumSize);
        mainQueryLayout = new QGridLayout();
        mainQueryLayout->setObjectName("mainQueryLayout");
        querySource = new QLineEdit(QueryOptions);
        querySource->setObjectName("querySource");

        mainQueryLayout->addWidget(querySource, 1, 1, 1, 1);

        queryTarget = new QLineEdit(QueryOptions);
        queryTarget->setObjectName("queryTarget");

        mainQueryLayout->addWidget(queryTarget, 2, 1, 1, 1);

        querySourceLabel = new QLabel(QueryOptions);
        querySourceLabel->setObjectName("querySourceLabel");

        mainQueryLayout->addWidget(querySourceLabel, 1, 0, 1, 1);

        queryTargetLabel = new QLabel(QueryOptions);
        queryTargetLabel->setObjectName("queryTargetLabel");

        mainQueryLayout->addWidget(queryTargetLabel, 2, 0, 1, 1);

        invertTarget = new QCheckBox(QueryOptions);
        invertTarget->setObjectName("invertTarget");

        mainQueryLayout->addWidget(invertTarget, 2, 2, 1, 1);

        invertSource = new QCheckBox(QueryOptions);
        invertSource->setObjectName("invertSource");

        mainQueryLayout->addWidget(invertSource, 1, 2, 1, 1);


        queryLayout->addLayout(mainQueryLayout);

        line = new QFrame(QueryOptions);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::VLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        queryLayout->addWidget(line);

        optionsLayout = new QGridLayout();
        optionsLayout->setObjectName("optionsLayout");
        label_2 = new QLabel(QueryOptions);
        label_2->setObjectName("label_2");

        optionsLayout->addWidget(label_2, 1, 1, 1, 1);

        filemask = new QLineEdit(QueryOptions);
        filemask->setObjectName("filemask");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(filemask->sizePolicy().hasHeightForWidth());
        filemask->setSizePolicy(sizePolicy);

        optionsLayout->addWidget(filemask, 1, 2, 1, 1);

        label_s = new QLabel(QueryOptions);
        label_s->setObjectName("label_s");

        optionsLayout->addWidget(label_s, 2, 1, 1, 1);

        queryStyle = new KComboBox(QueryOptions);
        queryStyle->setObjectName("queryStyle");

        optionsLayout->addWidget(queryStyle, 2, 2, 1, 1);


        queryLayout->addLayout(optionsLayout);

        line_2 = new QFrame(QueryOptions);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::VLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        queryLayout->addWidget(line_2);

        buttonsLayout = new QVBoxLayout();
        buttonsLayout->setObjectName("buttonsLayout");
        doFind = new QPushButton(QueryOptions);
        doFind->setObjectName("doFind");

        buttonsLayout->addWidget(doFind);

        doUpdateTM = new QPushButton(QueryOptions);
        doUpdateTM->setObjectName("doUpdateTM");

        buttonsLayout->addWidget(doUpdateTM);


        queryLayout->addLayout(buttonsLayout);


        vboxLayout->addLayout(queryLayout);

        treeView = new QTreeView(QueryOptions);
        treeView->setObjectName("treeView");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(treeView->sizePolicy().hasHeightForWidth());
        treeView->setSizePolicy(sizePolicy1);
        treeView->setAlternatingRowColors(true);
        treeView->setRootIsDecorated(false);
        treeView->setWordWrap(true);

        vboxLayout->addWidget(treeView);

#if QT_CONFIG(shortcut)
        querySourceLabel->setBuddy(querySource);
        queryTargetLabel->setBuddy(queryTarget);
        label_2->setBuddy(filemask);
        label_s->setBuddy(queryStyle);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(querySource, queryTarget);
        QWidget::setTabOrder(queryTarget, doFind);
        QWidget::setTabOrder(doFind, invertSource);
        QWidget::setTabOrder(invertSource, invertTarget);
        QWidget::setTabOrder(invertTarget, filemask);
        QWidget::setTabOrder(filemask, queryStyle);
        QWidget::setTabOrder(queryStyle, doUpdateTM);
        QWidget::setTabOrder(doUpdateTM, treeView);
        QWidget::setTabOrder(treeView, dbName);

        retranslateUi(QueryOptions);

        queryStyle->setCurrentIndex(-1);


        QMetaObject::connectSlotsByName(QueryOptions);
    } // setupUi

    void retranslateUi(QWidget *QueryOptions)
    {
        label->setText(tr2i18n("Translation Memory:", nullptr));
#if QT_CONFIG(tooltip)
        querySource->setToolTip(tr2i18n("Search expression for source language part.\n"
"Press Enter to start the search.\n"
"Press Ctrl+L to go to this control.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        queryTarget->setToolTip(tr2i18n("Search expression for target language part.\n"
"Press Enter to start the search.", nullptr));
#endif // QT_CONFIG(tooltip)
        querySourceLabel->setText(tr2i18n("Source:", nullptr));
        queryTargetLabel->setText(tr2i18n("Target:", nullptr));
#if QT_CONFIG(tooltip)
        invertTarget->setToolTip(tr2i18n("Show results that do not match search expression", nullptr));
#endif // QT_CONFIG(tooltip)
        invertTarget->setText(tr2i18n("Invert", nullptr));
#if QT_CONFIG(tooltip)
        invertSource->setToolTip(tr2i18n("Show results that do not match search expression", nullptr));
#endif // QT_CONFIG(tooltip)
        invertSource->setText(tr2i18n("Invert", nullptr));
#if QT_CONFIG(tooltip)
        label_2->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        label_2->setText(tr2i18n("File Mask:", nullptr));
#if QT_CONFIG(tooltip)
        filemask->setToolTip(tr2i18n("Show only results from files with path matching specified mask", nullptr));
#endif // QT_CONFIG(tooltip)
        label_s->setText(tr2i18n("Query Syntax:", nullptr));
        doFind->setText(tr2i18n("&Search", nullptr));
#if QT_CONFIG(tooltip)
        doUpdateTM->setToolTip(tr2i18n("Reads all project files into translation memory, updating old entries. The scanning will work in background.", nullptr));
#endif // QT_CONFIG(tooltip)
        doUpdateTM->setText(tr2i18n("&Rescan Project", nullptr));
        (void)QueryOptions;
    } // retranslateUi

};

namespace Ui {
    class QueryOptions: public Ui_QueryOptions {};
} // namespace Ui

QT_END_NAMESPACE

#endif // QUERYOPTIONS_H

