/********************************************************************************
** Form generated from reading UI file 'managedatabases.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MANAGEDATABASES_H
#define UI_MANAGEDATABASES_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_TMManager
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *hboxLayout;
    QPushButton *create;
    QPushButton *addData;
    QPushButton *importTMX;
    QPushButton *exportTMX;
    QPushButton *remove;
    QTreeView *list;

    void setupUi(QWidget *TMManager)
    {
        if (TMManager->objectName().isEmpty())
            TMManager->setObjectName("TMManager");
        TMManager->resize(557, 401);
        gridLayout = new QGridLayout(TMManager);
        gridLayout->setObjectName("gridLayout");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        create = new QPushButton(TMManager);
        create->setObjectName("create");

        hboxLayout->addWidget(create);

        addData = new QPushButton(TMManager);
        addData->setObjectName("addData");

        hboxLayout->addWidget(addData);

        importTMX = new QPushButton(TMManager);
        importTMX->setObjectName("importTMX");

        hboxLayout->addWidget(importTMX);

        exportTMX = new QPushButton(TMManager);
        exportTMX->setObjectName("exportTMX");

        hboxLayout->addWidget(exportTMX);

        remove = new QPushButton(TMManager);
        remove->setObjectName("remove");

        hboxLayout->addWidget(remove);


        gridLayout->addLayout(hboxLayout, 3, 0, 1, 1);

        list = new QTreeView(TMManager);
        list->setObjectName("list");
        list->setRootIsDecorated(false);
        list->setUniformRowHeights(true);
        list->setItemsExpandable(false);
        list->setAllColumnsShowFocus(true);
        list->setExpandsOnDoubleClick(false);

        gridLayout->addWidget(list, 0, 0, 1, 1);


        retranslateUi(TMManager);

        QMetaObject::connectSlotsByName(TMManager);
    } // setupUi

    void retranslateUi(QWidget *TMManager)
    {
        create->setText(tr2i18n("Create", nullptr));
        addData->setText(tr2i18n("Add Data", nullptr));
        importTMX->setText(tr2i18n("Add Data from TMX\342\200\246", nullptr));
        exportTMX->setText(tr2i18n("Export to TMX\342\200\246", nullptr));
        remove->setText(tr2i18n("Remove", nullptr));
        (void)TMManager;
    } // retranslateUi

};

namespace Ui {
    class TMManager: public Ui_TMManager {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MANAGEDATABASES_H

