/********************************************************************************
** Form generated from reading UI file 'prefs_general.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFS_GENERAL_H
#define UI_PREFS_GENERAL_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_prefs_general
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *spacerItem;
    QCheckBox *kcfg_RestoreRecentFilesOnStartup;
    QHBoxLayout *hboxLayout;
    QLabel *l2;
    QComboBox *kcfg_TabSwitch;
    QCheckBox *kcfg_CustomEditorEnabled;
    QLineEdit *kcfg_CustomEditorCommand;

    void setupUi(QWidget *prefs_general)
    {
        if (prefs_general->objectName().isEmpty())
            prefs_general->setObjectName("prefs_general");
        prefs_general->resize(612, 375);
        gridLayout = new QGridLayout(prefs_general);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(11, 11, 11, 11);
        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacerItem, 4, 0, 1, 2);

        kcfg_RestoreRecentFilesOnStartup = new QCheckBox(prefs_general);
        kcfg_RestoreRecentFilesOnStartup->setObjectName("kcfg_RestoreRecentFilesOnStartup");

        gridLayout->addWidget(kcfg_RestoreRecentFilesOnStartup, 0, 0, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        l2 = new QLabel(prefs_general);
        l2->setObjectName("l2");

        hboxLayout->addWidget(l2);

        kcfg_TabSwitch = new QComboBox(prefs_general);
        kcfg_TabSwitch->addItem(QString());
        kcfg_TabSwitch->addItem(QString());
        kcfg_TabSwitch->setObjectName("kcfg_TabSwitch");

        hboxLayout->addWidget(kcfg_TabSwitch);


        gridLayout->addLayout(hboxLayout, 1, 0, 1, 1);

        kcfg_CustomEditorEnabled = new QCheckBox(prefs_general);
        kcfg_CustomEditorEnabled->setObjectName("kcfg_CustomEditorEnabled");

        gridLayout->addWidget(kcfg_CustomEditorEnabled, 2, 0, 1, 1);

        kcfg_CustomEditorCommand = new QLineEdit(prefs_general);
        kcfg_CustomEditorCommand->setObjectName("kcfg_CustomEditorCommand");

        gridLayout->addWidget(kcfg_CustomEditorCommand, 3, 0, 1, 1);

#if QT_CONFIG(shortcut)
        l2->setBuddy(kcfg_TabSwitch);
#endif // QT_CONFIG(shortcut)

        retranslateUi(prefs_general);

        QMetaObject::connectSlotsByName(prefs_general);
    } // setupUi

    void retranslateUi(QWidget *prefs_general)
    {
        kcfg_RestoreRecentFilesOnStartup->setText(tr2i18n("Restore the previously opened files when launching Lokalize", nullptr));
#if QT_CONFIG(tooltip)
        l2->setToolTip(tr2i18n("Defines the behavior of the next/previous tab shortcuts", nullptr));
#endif // QT_CONFIG(tooltip)
        l2->setText(tr2i18n("Next/previous tab shortcut behavior", nullptr));
        kcfg_TabSwitch->setItemText(0, tr2i18n("According to tab position", nullptr));
        kcfg_TabSwitch->setItemText(1, tr2i18n("According to tab activation order", nullptr));

        kcfg_CustomEditorEnabled->setText(tr2i18n("Use a custom editor to open source files", nullptr));
        (void)prefs_general;
    } // retranslateUi

};

namespace Ui {
    class prefs_general: public Ui_prefs_general {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PREFS_GENERAL_H

