/****************************************************************************
** Meta object code from reading C++ file 'tmtab.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../lokalize-26.08.0/src/tm/tmtab.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tmtab.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2TM5TMTabE_t {};
} // unnamed namespace

template <> constexpr inline auto TM::TMTab::qt_create_metaobjectdata<qt_meta_tag_ZN2TM5TMTabE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TM::TMTab",
        "D-Bus Interface",
        "org.kde.Lokalize.TranslationMemory",
        "fileOpenRequested",
        "",
        "url",
        "source",
        "ctxt",
        "setAsActive",
        "findGuiText",
        "text",
        "findGuiTextPackage",
        "package",
        "lookup",
        "target",
        "performQuery",
        "updateTM",
        "copySource",
        "copyTarget",
        "openFile",
        "handleResults",
        "displayTotalResultCount",
        "setQAMode",
        "enabled"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'fileOpenRequested'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &, const bool)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 6 }, { QMetaType::QString, 7 }, { QMetaType::Bool, 8 },
        }}),
        // Slot 'findGuiText'
        QtMocHelpers::SlotData<bool(QString)>(9, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'findGuiTextPackage'
        QtMocHelpers::SlotData<bool(QString, QString)>(11, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 12 },
        }}),
        // Slot 'lookup'
        QtMocHelpers::SlotData<void(QString, QString)>(13, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { QMetaType::QString, 14 },
        }}),
        // Slot 'performQuery'
        QtMocHelpers::SlotData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateTM'
        QtMocHelpers::SlotData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copySource'
        QtMocHelpers::SlotData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copyTarget'
        QtMocHelpers::SlotData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'openFile'
        QtMocHelpers::SlotData<void()>(19, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleResults'
        QtMocHelpers::SlotData<void()>(20, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'displayTotalResultCount'
        QtMocHelpers::SlotData<void()>(21, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setQAMode'
        QtMocHelpers::SlotData<void()>(22, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setQAMode'
        QtMocHelpers::SlotData<void(bool)>(22, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<TMTab, qt_meta_tag_ZN2TM5TMTabE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject TM::TMTab::staticMetaObject = { {
    QMetaObject::SuperData::link<LokalizeTabPageBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2TM5TMTabE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2TM5TMTabE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2TM5TMTabE_t>.metaTypes,
    nullptr
} };

void TM::TMTab::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TMTab *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->fileOpenRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 1: { bool _r = _t->findGuiText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->findGuiTextPackage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->lookup((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->performQuery(); break;
        case 5: _t->updateTM(); break;
        case 6: _t->copySource(); break;
        case 7: _t->copyTarget(); break;
        case 8: _t->openFile(); break;
        case 9: _t->handleResults(); break;
        case 10: _t->displayTotalResultCount(); break;
        case 11: _t->setQAMode(); break;
        case 12: _t->setQAMode((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TMTab::*)(const QString & , const QString & , const QString & , const bool )>(_a, &TMTab::fileOpenRequested, 0))
            return;
    }
}

const QMetaObject *TM::TMTab::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TM::TMTab::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2TM5TMTabE_t>.strings))
        return static_cast<void*>(this);
    return LokalizeTabPageBase::qt_metacast(_clname);
}

int TM::TMTab::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = LokalizeTabPageBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void TM::TMTab::fileOpenRequested(const QString & _t1, const QString & _t2, const QString & _t3, const bool _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4);
}
namespace {
struct qt_meta_tag_ZN2TM9TMDBModelE_t {};
} // unnamed namespace

template <> constexpr inline auto TM::TMDBModel::qt_create_metaobjectdata<qt_meta_tag_ZN2TM9TMDBModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TM::TMDBModel",
        "resultsFetched",
        "",
        "finalResultCountFetched",
        "setFilter",
        "source",
        "target",
        "invertSource",
        "invertTarget",
        "filemask",
        "setQueryType",
        "setDB",
        "slotQueryExecuted",
        "ExecQueryJob*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'resultsFetched'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'finalResultCountFetched'
        QtMocHelpers::SignalData<void(int)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'setFilter'
        QtMocHelpers::SlotData<void(const QString &, const QString &, bool, bool, const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 6 }, { QMetaType::Bool, 7 }, { QMetaType::Bool, 8 },
            { QMetaType::QString, 9 },
        }}),
        // Slot 'setQueryType'
        QtMocHelpers::SlotData<void(int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'setDB'
        QtMocHelpers::SlotData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'slotQueryExecuted'
        QtMocHelpers::SlotData<void(ExecQueryJob *)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TMDBModel, qt_meta_tag_ZN2TM9TMDBModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TM::TMDBModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QSqlQueryModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2TM9TMDBModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2TM9TMDBModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2TM9TMDBModelE_t>.metaTypes,
    nullptr
} };

void TM::TMDBModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TMDBModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->resultsFetched(); break;
        case 1: _t->finalResultCountFetched((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->setFilter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5]))); break;
        case 3: _t->setQueryType((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->setDB((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->slotQueryExecuted((*reinterpret_cast<std::add_pointer_t<ExecQueryJob*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TMDBModel::*)()>(_a, &TMDBModel::resultsFetched, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TMDBModel::*)(int )>(_a, &TMDBModel::finalResultCountFetched, 1))
            return;
    }
}

const QMetaObject *TM::TMDBModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TM::TMDBModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2TM9TMDBModelE_t>.strings))
        return static_cast<void*>(this);
    return QSqlQueryModel::qt_metacast(_clname);
}

int TM::TMDBModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSqlQueryModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void TM::TMDBModel::resultsFetched()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TM::TMDBModel::finalResultCountFetched(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
