/****************************************************************************
** Meta object code from reading C++ file 'filesearchadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "filesearchadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'filesearchadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17FileSearchAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto FileSearchAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN17FileSearchAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FileSearchAdaptor",
        "D-Bus Interface",
        "org.kde.Lokalize.FileSearch",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.Lokalize.FileSearch\">\n    <method na"
        "me=\"performSearch\"/>\n    <method name=\"addFilesToSearch\">\n  "
        "    <arg direction=\"in\" type=\"as\"/>\n    </method>\n    <metho"
        "d name=\"setSourceQuery\">\n      <arg direction=\"in\" type=\"s\""
        "/>\n    </method>\n    <method name=\"setTargetQuery\">\n      <ar"
        "g direction=\"in\" type=\"s\"/>\n    </method>\n    <method name=\""
        "findGuiText\">\n      <arg direction=\"out\" type=\"b\"/>\n      <"
        "arg direction=\"in\" type=\"s\" name=\"text\"/>\n    </method>\n  "
        "  <method name=\"findGuiTextPackage\">\n      <arg direction=\"out"
        "\" type=\"b\"/>\n      <arg direction=\"in\" type=\"s\" name=\"tex"
        "t\"/>\n      <arg direction=\"in\" type=\"s\" name=\"package\"/>\n"
        "    </method>\n  </interface>\n",
        "addFilesToSearch",
        "",
        "in0",
        "findGuiText",
        "text",
        "findGuiTextPackage",
        "package",
        "performSearch",
        "setSourceQuery",
        "setTargetQuery"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'addFilesToSearch'
        QtMocHelpers::SlotData<void(const QStringList &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 7 },
        }}),
        // Slot 'findGuiText'
        QtMocHelpers::SlotData<bool(const QString &)>(8, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'findGuiTextPackage'
        QtMocHelpers::SlotData<bool(const QString &, const QString &)>(10, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 11 },
        }}),
        // Slot 'performSearch'
        QtMocHelpers::SlotData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setSourceQuery'
        QtMocHelpers::SlotData<void(const QString &)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'setTargetQuery'
        QtMocHelpers::SlotData<void(const QString &)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<FileSearchAdaptor, qt_meta_tag_ZN17FileSearchAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject FileSearchAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17FileSearchAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17FileSearchAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17FileSearchAdaptorE_t>.metaTypes,
    nullptr
} };

void FileSearchAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FileSearchAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->addFilesToSearch((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 1: { bool _r = _t->findGuiText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->findGuiTextPackage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->performSearch(); break;
        case 4: _t->setSourceQuery((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->setTargetQuery((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *FileSearchAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FileSearchAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17FileSearchAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int FileSearchAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}
QT_WARNING_POP
