/****************************************************************************
** Meta object code from reading C++ file 'project.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../lokalize-26.08.0/src/project/project.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'project.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7ProjectE_t {};
} // unnamed namespace

template <> constexpr inline auto Project::qt_create_metaobjectdata<qt_meta_tag_ZN7ProjectE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Project",
        "D-Bus Interface",
        "org.kde.Lokalize.Project",
        "loaded",
        "",
        "fileOpenRequested",
        "setAsActive",
        "closed",
        "sourceFilePathsAreReady",
        "load",
        "newProjectPath",
        "defaultTargetLangCode",
        "defaultProjectId",
        "reinit",
        "save",
        "translationsRoot",
        "templatesRoot",
        "targetLangCode",
        "sourceLangCode",
        "init",
        "path",
        "kind",
        "id",
        "sourceLang",
        "targetLang",
        "absolutePath",
        "relativePath",
        "setDesirablePath",
        "desirablePath",
        "isTmSupported",
        "populateDirModel",
        "populateGlossary",
        "showTMManager",
        "projectOdfCreate"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'loaded'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Signal 'fileOpenRequested'
        QtMocHelpers::SignalData<void(const QString &, const bool)>(5, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 }, { QMetaType::Bool, 6 },
        }}),
        // Signal 'closed'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sourceFilePathsAreReady'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'load'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(9, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 11 }, { QMetaType::QString, 12 },
        }}),
        // Slot 'load'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(9, 4, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 11 },
        }}),
        // Slot 'load'
        QtMocHelpers::SlotData<void(const QString &)>(9, 4, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'reinit'
        QtMocHelpers::SlotData<void()>(13, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(14, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'translationsRoot'
        QtMocHelpers::SlotData<QString() const>(15, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'templatesRoot'
        QtMocHelpers::SlotData<QString() const>(16, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'targetLangCode'
        QtMocHelpers::SlotData<QString() const>(17, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'sourceLangCode'
        QtMocHelpers::SlotData<QString() const>(18, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'init'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, const QString &, const QString &)>(19, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { QMetaType::QString, 22 }, { QMetaType::QString, 23 },
            { QMetaType::QString, 24 },
        }}),
        // Slot 'kind'
        QtMocHelpers::SlotData<QString() const>(21, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'absolutePath'
        QtMocHelpers::SlotData<QString(const QString &) const>(25, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'relativePath'
        QtMocHelpers::SlotData<QString(const QString &) const>(26, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'setDesirablePath'
        QtMocHelpers::SlotData<void(const QString &)>(27, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'desirablePath'
        QtMocHelpers::SlotData<QString() const>(28, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'isTmSupported'
        QtMocHelpers::SlotData<bool() const>(29, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'populateDirModel'
        QtMocHelpers::SlotData<void()>(30, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'populateGlossary'
        QtMocHelpers::SlotData<void()>(31, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showTMManager'
        QtMocHelpers::SlotData<void()>(32, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'projectOdfCreate'
        QtMocHelpers::SlotData<void()>(33, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Project, qt_meta_tag_ZN7ProjectE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Project::staticMetaObject = { {
    QMetaObject::SuperData::link<ProjectBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7ProjectE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7ProjectE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7ProjectE_t>.metaTypes,
    nullptr
} };

void Project::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Project *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->loaded(); break;
        case 1: _t->fileOpenRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 2: _t->closed(); break;
        case 3: _t->sourceFilePathsAreReady(); break;
        case 4: _t->load((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 5: _t->load((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->load((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->reinit(); break;
        case 8: _t->save(); break;
        case 9: { QString _r = _t->translationsRoot();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 10: { QString _r = _t->templatesRoot();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 11: { QString _r = _t->targetLangCode();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 12: { QString _r = _t->sourceLangCode();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->init((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5]))); break;
        case 14: { QString _r = _t->kind();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 15: { QString _r = _t->absolutePath((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 16: { QString _r = _t->relativePath((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 17: _t->setDesirablePath((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: { QString _r = _t->desirablePath();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 19: { bool _r = _t->isTmSupported();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 20: _t->populateDirModel(); break;
        case 21: _t->populateGlossary(); break;
        case 22: _t->showTMManager(); break;
        case 23: _t->projectOdfCreate(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Project::*)()>(_a, &Project::loaded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Project::*)(const QString & , const bool )>(_a, &Project::fileOpenRequested, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Project::*)()>(_a, &Project::closed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Project::*)()>(_a, &Project::sourceFilePathsAreReady, 3))
            return;
    }
}

const QMetaObject *Project::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Project::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7ProjectE_t>.strings))
        return static_cast<void*>(this);
    return ProjectBase::qt_metacast(_clname);
}

int Project::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ProjectBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 24;
    }
    return _id;
}

// SIGNAL 0
void Project::loaded()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Project::fileOpenRequested(const QString & _t1, const bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void Project::closed()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Project::sourceFilePathsAreReady()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
