/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.lokalize.FileSearch.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef FILESEARCHADAPTOR_H
#define FILESEARCHADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "filesearch/filesearchtab.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.Lokalize.FileSearch
 */
class FileSearchAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.Lokalize.FileSearch")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.Lokalize.FileSearch\">\n"
"    <method name=\"performSearch\"/>\n"
"    <method name=\"addFilesToSearch\">\n"
"      <arg direction=\"in\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"setSourceQuery\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setTargetQuery\">\n"
"      <arg direction=\"in\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"findGuiText\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"text\"/>\n"
"    </method>\n"
"    <method name=\"findGuiTextPackage\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"text\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"package\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    FileSearchAdaptor(FileSearchTab *parent);
    ~FileSearchAdaptor() override;

    inline FileSearchTab *parent() const
    { return static_cast<FileSearchTab *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void addFilesToSearch(const QStringList &in0);
    bool findGuiText(const QString &text);
    bool findGuiTextPackage(const QString &text, const QString &package);
    void performSearch();
    void setSourceQuery(const QString &in0);
    void setTargetQuery(const QString &in0);
Q_SIGNALS: // SIGNALS
};

#endif
