/********************************************************************************
** Form generated from reading UI file 'filesearchoptions.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FILESEARCHOPTIONS_H
#define UI_FILESEARCHOPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_FileSearchOptions
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QGridLayout *gridLayout;
    QLineEdit *querySource;
    QCheckBox *invertTarget;
    QLabel *querySourceLabel;
    QLineEdit *queryTarget;
    QCheckBox *regEx;
    QLabel *queryTargetLabel;
    QCheckBox *matchCase;
    QCheckBox *invertSource;
    QFrame *line;
    QPushButton *doFind;
    QTreeView *treeView;

    void setupUi(QWidget *FileSearchOptions)
    {
        if (FileSearchOptions->objectName().isEmpty())
            FileSearchOptions->setObjectName("FileSearchOptions");
        FileSearchOptions->resize(600, 359);
        vboxLayout = new QVBoxLayout(FileSearchOptions);
        vboxLayout->setObjectName("vboxLayout");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        querySource = new QLineEdit(FileSearchOptions);
        querySource->setObjectName("querySource");

        gridLayout->addWidget(querySource, 0, 1, 1, 1);

        invertTarget = new QCheckBox(FileSearchOptions);
        invertTarget->setObjectName("invertTarget");

        gridLayout->addWidget(invertTarget, 1, 2, 1, 1);

        querySourceLabel = new QLabel(FileSearchOptions);
        querySourceLabel->setObjectName("querySourceLabel");

        gridLayout->addWidget(querySourceLabel, 0, 0, 1, 1);

        queryTarget = new QLineEdit(FileSearchOptions);
        queryTarget->setObjectName("queryTarget");

        gridLayout->addWidget(queryTarget, 1, 1, 1, 1);

        regEx = new QCheckBox(FileSearchOptions);
        regEx->setObjectName("regEx");

        gridLayout->addWidget(regEx, 0, 4, 1, 1);

        queryTargetLabel = new QLabel(FileSearchOptions);
        queryTargetLabel->setObjectName("queryTargetLabel");

        gridLayout->addWidget(queryTargetLabel, 1, 0, 1, 1);

        matchCase = new QCheckBox(FileSearchOptions);
        matchCase->setObjectName("matchCase");

        gridLayout->addWidget(matchCase, 1, 4, 1, 1);

        invertSource = new QCheckBox(FileSearchOptions);
        invertSource->setObjectName("invertSource");

        gridLayout->addWidget(invertSource, 0, 2, 1, 1);

        line = new QFrame(FileSearchOptions);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::VLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line, 0, 3, 2, 1);


        hboxLayout->addLayout(gridLayout);

        doFind = new QPushButton(FileSearchOptions);
        doFind->setObjectName("doFind");

        hboxLayout->addWidget(doFind);


        vboxLayout->addLayout(hboxLayout);

        treeView = new QTreeView(FileSearchOptions);
        treeView->setObjectName("treeView");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(treeView->sizePolicy().hasHeightForWidth());
        treeView->setSizePolicy(sizePolicy);
        treeView->setAlternatingRowColors(true);
        treeView->setRootIsDecorated(false);
        treeView->setWordWrap(true);

        vboxLayout->addWidget(treeView);

#if QT_CONFIG(shortcut)
        querySourceLabel->setBuddy(querySource);
        queryTargetLabel->setBuddy(queryTarget);
#endif // QT_CONFIG(shortcut)

        retranslateUi(FileSearchOptions);

        QMetaObject::connectSlotsByName(FileSearchOptions);
    } // setupUi

    void retranslateUi(QWidget *FileSearchOptions)
    {
#if QT_CONFIG(tooltip)
        querySource->setToolTip(tr2i18n("Search expression for source language part.\n"
"Press Ctrl+L to go to this control.\n"
"Press Enter to start the search.\n"
"Press Esc to stop the search.", nullptr));
#endif // QT_CONFIG(tooltip)
        invertTarget->setText(tr2i18n("Invert", nullptr));
        querySourceLabel->setText(tr2i18n("Source:", nullptr));
#if QT_CONFIG(tooltip)
        queryTarget->setToolTip(tr2i18n("Search expression for target language part.\n"
"Press Enter to start the search.", nullptr));
#endif // QT_CONFIG(tooltip)
        regEx->setText(tr2i18n("Regular expressions", nullptr));
        queryTargetLabel->setText(tr2i18n("Target:", nullptr));
        matchCase->setText(tr2i18n("Match case", nullptr));
        invertSource->setText(tr2i18n("Invert", nullptr));
        doFind->setText(tr2i18n("&Search", nullptr));
        (void)FileSearchOptions;
    } // retranslateUi

};

namespace Ui {
    class FileSearchOptions: public Ui_FileSearchOptions {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FILESEARCHOPTIONS_H

