/********************************************************************************
** Form generated from reading UI file 'prefs_tm.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFS_TM_H
#define UI_PREFS_TM_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_prefs_tm
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *spacerItem;
    QCheckBox *kcfg_PrefetchTM;
    QHBoxLayout *hboxLayout;
    QLabel *label1;
    QSpinBox *kcfg_SuggCount;
    QSpacerItem *horizontalSpacer1;
    QHBoxLayout *hboxLayout1;
    QLabel *label;
    QSpinBox *kcfg_SuggScore;
    QSpacerItem *horizontalSpacer;
    QCheckBox *kcfg_AutoaddTM;
    QCheckBox *kcfg_ScanToTMOnOpen;
    QCheckBox *kcfg_DeleteFromTMOnMissing;

    void setupUi(QWidget *prefs_tm)
    {
        if (prefs_tm->objectName().isEmpty())
            prefs_tm->setObjectName("prefs_tm");
        prefs_tm->resize(637, 375);
        gridLayout = new QGridLayout(prefs_tm);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(11, 11, 11, 11);
        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacerItem, 7, 0, 1, 2);

        kcfg_PrefetchTM = new QCheckBox(prefs_tm);
        kcfg_PrefetchTM->setObjectName("kcfg_PrefetchTM");

        gridLayout->addWidget(kcfg_PrefetchTM, 0, 0, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        label1 = new QLabel(prefs_tm);
        label1->setObjectName("label1");

        hboxLayout->addWidget(label1);

        kcfg_SuggCount = new QSpinBox(prefs_tm);
        kcfg_SuggCount->setObjectName("kcfg_SuggCount");

        hboxLayout->addWidget(kcfg_SuggCount);

        horizontalSpacer1 = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(horizontalSpacer1);


        gridLayout->addLayout(hboxLayout, 1, 0, 1, 1);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        label = new QLabel(prefs_tm);
        label->setObjectName("label");

        hboxLayout1->addWidget(label);

        kcfg_SuggScore = new QSpinBox(prefs_tm);
        kcfg_SuggScore->setObjectName("kcfg_SuggScore");
        kcfg_SuggScore->setMinimum(0);
        kcfg_SuggScore->setMaximum(100);

        hboxLayout1->addWidget(kcfg_SuggScore);

        horizontalSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(horizontalSpacer);


        gridLayout->addLayout(hboxLayout1, 2, 0, 1, 1);

        kcfg_AutoaddTM = new QCheckBox(prefs_tm);
        kcfg_AutoaddTM->setObjectName("kcfg_AutoaddTM");

        gridLayout->addWidget(kcfg_AutoaddTM, 3, 0, 1, 1);

        kcfg_ScanToTMOnOpen = new QCheckBox(prefs_tm);
        kcfg_ScanToTMOnOpen->setObjectName("kcfg_ScanToTMOnOpen");

        gridLayout->addWidget(kcfg_ScanToTMOnOpen, 4, 0, 1, 1);

        kcfg_DeleteFromTMOnMissing = new QCheckBox(prefs_tm);
        kcfg_DeleteFromTMOnMissing->setObjectName("kcfg_DeleteFromTMOnMissing");

        gridLayout->addWidget(kcfg_DeleteFromTMOnMissing, 5, 0, 1, 1);

#if QT_CONFIG(shortcut)
        label1->setBuddy(kcfg_SuggCount);
        label->setBuddy(kcfg_SuggScore);
#endif // QT_CONFIG(shortcut)

        retranslateUi(prefs_tm);

        QMetaObject::connectSlotsByName(prefs_tm);
    } // setupUi

    void retranslateUi(QWidget *prefs_tm)
    {
#if QT_CONFIG(tooltip)
        kcfg_PrefetchTM->setToolTip(tr2i18n("If checked, get translation memory suggestions ", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_PrefetchTM->setWhatsThis(tr2i18n("If this is checked, the program will fetch translation memories as soon as you open a file.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_PrefetchTM->setText(tr2i18n("Prefetch translation memory suggestions on file open", nullptr));
        label1->setText(tr2i18n("Maximum number of suggestions:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_SuggCount->setToolTip(tr2i18n("Set the maximum number of suggestions", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_SuggCount->setWhatsThis(tr2i18n("You can change the maximum number of suggestions, default is 7.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label->setText(tr2i18n("Minimum score (0-100) of suggestions:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_SuggScore->setToolTip(tr2i18n("Set the minimum score (0-100) of suggestions", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_SuggScore->setWhatsThis(tr2i18n("You can change the minimum score (0-100) required for suggestions, default is 0.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_AutoaddTM->setText(tr2i18n("Update/Add edited entries to translation memory", nullptr));
        kcfg_ScanToTMOnOpen->setText(tr2i18n("Add opened files to translation memory automatically", nullptr));
        kcfg_DeleteFromTMOnMissing->setText(tr2i18n("Delete missing files from translation memory on rescan or when right-clicking on a missing entry", nullptr));
        (void)prefs_tm;
    } // retranslateUi

};

namespace Ui {
    class prefs_tm: public Ui_prefs_tm {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PREFS_TM_H

