/****************************************************************************
** Meta object code from reading C++ file 'editorview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../lokalize-26.08.0/src/editorview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'editorview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10EditorViewE_t {};
} // unnamed namespace

template <> constexpr inline auto EditorView::qt_create_metaobjectdata<qt_meta_tag_ZN10EditorViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EditorView",
        "signalEquivTranslatedEntryDisplayed",
        "",
        "signalApprovedEntryDisplayed",
        "signalChangeStatusbar",
        "signalChanged",
        "index",
        "binaryUnitSelectRequested",
        "id",
        "gotoEntryRequested",
        "DocPosition",
        "tmLookupRequested",
        "DocPosition::Part",
        "findRequested",
        "findNextRequested",
        "replaceRequested",
        "doExplicitCompletion",
        "gotoEntry",
        "pos",
        "selection",
        "toggleApprovement",
        "setState",
        "TargetState",
        "setEquivTrans",
        "settingsChanged",
        "insertTerm",
        "unwrap",
        "TranslationUnitTextEdit*",
        "editor",
        "resetFindForCurrent",
        "toggleBookmark"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'signalEquivTranslatedEntryDisplayed'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'signalApprovedEntryDisplayed'
        QtMocHelpers::SignalData<void(bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'signalChangeStatusbar'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'signalChanged'
        QtMocHelpers::SignalData<void(uint)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 6 },
        }}),
        // Signal 'binaryUnitSelectRequested'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'gotoEntryRequested'
        QtMocHelpers::SignalData<void(const DocPosition &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 2 },
        }}),
        // Signal 'tmLookupRequested'
        QtMocHelpers::SignalData<void(DocPosition::Part, const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 2 }, { QMetaType::QString, 2 },
        }}),
        // Signal 'findRequested'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'findNextRequested'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'replaceRequested'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'doExplicitCompletion'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'gotoEntry'
        QtMocHelpers::SlotData<void(DocPosition, int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 18 }, { QMetaType::Int, 19 },
        }}),
        // Slot 'gotoEntry'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleApprovement'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setState'
        QtMocHelpers::SlotData<void(TargetState)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 2 },
        }}),
        // Slot 'setEquivTrans'
        QtMocHelpers::SlotData<void(bool)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'settingsChanged'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insertTerm'
        QtMocHelpers::SlotData<void(const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'unwrap'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'unwrap'
        QtMocHelpers::SlotData<void(TranslationUnitTextEdit *)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
        // Slot 'resetFindForCurrent'
        QtMocHelpers::SlotData<void(const DocPosition &)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 18 },
        }}),
        // Slot 'toggleBookmark'
        QtMocHelpers::SlotData<void(bool)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EditorView, qt_meta_tag_ZN10EditorViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EditorView::staticMetaObject = { {
    QMetaObject::SuperData::link<QSplitter::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EditorViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EditorViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10EditorViewE_t>.metaTypes,
    nullptr
} };

void EditorView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EditorView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->signalEquivTranslatedEntryDisplayed((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->signalApprovedEntryDisplayed((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->signalChangeStatusbar((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->signalChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 4: _t->binaryUnitSelectRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->gotoEntryRequested((*reinterpret_cast<std::add_pointer_t<DocPosition>>(_a[1]))); break;
        case 6: _t->tmLookupRequested((*reinterpret_cast<std::add_pointer_t<DocPosition::Part>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 7: _t->findRequested(); break;
        case 8: _t->findNextRequested(); break;
        case 9: _t->replaceRequested(); break;
        case 10: _t->doExplicitCompletion(); break;
        case 11: _t->gotoEntry((*reinterpret_cast<std::add_pointer_t<DocPosition>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 12: _t->gotoEntry(); break;
        case 13: _t->toggleApprovement(); break;
        case 14: _t->setState((*reinterpret_cast<std::add_pointer_t<TargetState>>(_a[1]))); break;
        case 15: _t->setEquivTrans((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->settingsChanged(); break;
        case 17: _t->insertTerm((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: _t->unwrap(); break;
        case 19: _t->unwrap((*reinterpret_cast<std::add_pointer_t<TranslationUnitTextEdit*>>(_a[1]))); break;
        case 20: _t->resetFindForCurrent((*reinterpret_cast<std::add_pointer_t<DocPosition>>(_a[1]))); break;
        case 21: _t->toggleBookmark((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DocPosition >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DocPosition >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DocPosition >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (EditorView::*)(bool )>(_a, &EditorView::signalEquivTranslatedEntryDisplayed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditorView::*)(bool )>(_a, &EditorView::signalApprovedEntryDisplayed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditorView::*)(const QString & )>(_a, &EditorView::signalChangeStatusbar, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditorView::*)(uint )>(_a, &EditorView::signalChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditorView::*)(const QString & )>(_a, &EditorView::binaryUnitSelectRequested, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditorView::*)(const DocPosition & )>(_a, &EditorView::gotoEntryRequested, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditorView::*)(DocPosition::Part , const QString & )>(_a, &EditorView::tmLookupRequested, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditorView::*)()>(_a, &EditorView::findRequested, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditorView::*)()>(_a, &EditorView::findNextRequested, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditorView::*)()>(_a, &EditorView::replaceRequested, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditorView::*)()>(_a, &EditorView::doExplicitCompletion, 10))
            return;
    }
}

const QMetaObject *EditorView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EditorView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EditorViewE_t>.strings))
        return static_cast<void*>(this);
    return QSplitter::qt_metacast(_clname);
}

int EditorView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSplitter::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    return _id;
}

// SIGNAL 0
void EditorView::signalEquivTranslatedEntryDisplayed(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void EditorView::signalApprovedEntryDisplayed(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void EditorView::signalChangeStatusbar(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void EditorView::signalChanged(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void EditorView::binaryUnitSelectRequested(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void EditorView::gotoEntryRequested(const DocPosition & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void EditorView::tmLookupRequested(DocPosition::Part _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void EditorView::findRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void EditorView::findNextRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void EditorView::replaceRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void EditorView::doExplicitCompletion()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
namespace {
struct qt_meta_tag_ZN10LedsWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto LedsWidget::qt_create_metaobjectdata<qt_meta_tag_ZN10LedsWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LedsWidget",
        "cursorPositionChanged",
        "",
        "column"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'cursorPositionChanged'
        QtMocHelpers::SlotData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LedsWidget, qt_meta_tag_ZN10LedsWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LedsWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10LedsWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10LedsWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10LedsWidgetE_t>.metaTypes,
    nullptr
} };

void LedsWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LedsWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->cursorPositionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *LedsWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LedsWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10LedsWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int LedsWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
