/****************************************************************************
** Meta object code from reading C++ file 'mergeview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../lokalize-26.08.0/src/mergemode/mergeview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mergeview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9MergeViewE_t {};
} // unnamed namespace

template <> constexpr inline auto MergeView::qt_create_metaobjectdata<qt_meta_tag_ZN9MergeViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MergeView",
        "signalPriorChangedAvailable",
        "",
        "signalNextChangedAvailable",
        "signalEntryWithMergeDisplayed",
        "gotoEntry",
        "DocPosition",
        "mergeCatalogAvailable",
        "mergeCatalogPointerChanged",
        "MergeCatalog*",
        "mergeCatalog",
        "mergeOpen",
        "mergeFilePath",
        "cleanup",
        "slotNewEntryDisplayed",
        "slotUpdate",
        "gotoNextChanged",
        "approvedOnly",
        "gotoNextChangedApproved",
        "gotoPrevChanged",
        "mergeAccept",
        "mergeAcceptAllForEmpty",
        "mergeBack"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'signalPriorChangedAvailable'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'signalNextChangedAvailable'
        QtMocHelpers::SignalData<void(bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'signalEntryWithMergeDisplayed'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'gotoEntry'
        QtMocHelpers::SignalData<void(const DocPosition &, int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'mergeCatalogAvailable'
        QtMocHelpers::SignalData<void(bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'mergeCatalogPointerChanged'
        QtMocHelpers::SignalData<void(MergeCatalog *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'mergeOpen'
        QtMocHelpers::SlotData<void(QString)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'mergeOpen'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'cleanup'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNewEntryDisplayed'
        QtMocHelpers::SlotData<void(const DocPosition &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Slot 'slotUpdate'
        QtMocHelpers::SlotData<void(const DocPosition &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Slot 'gotoNextChanged'
        QtMocHelpers::SlotData<void(bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'gotoNextChanged'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'gotoNextChangedApproved'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'gotoPrevChanged'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'mergeAccept'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'mergeAcceptAllForEmpty'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'mergeBack'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MergeView, qt_meta_tag_ZN9MergeViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MergeView::staticMetaObject = { {
    QMetaObject::SuperData::link<QDockWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9MergeViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9MergeViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9MergeViewE_t>.metaTypes,
    nullptr
} };

void MergeView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MergeView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->signalPriorChangedAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->signalNextChangedAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->signalEntryWithMergeDisplayed((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->gotoEntry((*reinterpret_cast<std::add_pointer_t<DocPosition>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 4: _t->mergeCatalogAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->mergeCatalogPointerChanged((*reinterpret_cast<std::add_pointer_t<MergeCatalog*>>(_a[1]))); break;
        case 6: _t->mergeOpen((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->mergeOpen(); break;
        case 8: _t->cleanup(); break;
        case 9: _t->slotNewEntryDisplayed((*reinterpret_cast<std::add_pointer_t<DocPosition>>(_a[1]))); break;
        case 10: _t->slotUpdate((*reinterpret_cast<std::add_pointer_t<DocPosition>>(_a[1]))); break;
        case 11: _t->gotoNextChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->gotoNextChanged(); break;
        case 13: _t->gotoNextChangedApproved(); break;
        case 14: _t->gotoPrevChanged(); break;
        case 15: _t->mergeAccept(); break;
        case 16: _t->mergeAcceptAllForEmpty(); break;
        case 17: _t->mergeBack(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DocPosition >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< MergeCatalog* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DocPosition >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DocPosition >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MergeView::*)(bool )>(_a, &MergeView::signalPriorChangedAvailable, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MergeView::*)(bool )>(_a, &MergeView::signalNextChangedAvailable, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MergeView::*)(bool )>(_a, &MergeView::signalEntryWithMergeDisplayed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MergeView::*)(const DocPosition & , int )>(_a, &MergeView::gotoEntry, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MergeView::*)(bool )>(_a, &MergeView::mergeCatalogAvailable, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MergeView::*)(MergeCatalog * )>(_a, &MergeView::mergeCatalogPointerChanged, 5))
            return;
    }
}

const QMetaObject *MergeView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MergeView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9MergeViewE_t>.strings))
        return static_cast<void*>(this);
    return QDockWidget::qt_metacast(_clname);
}

int MergeView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDockWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void MergeView::signalPriorChangedAvailable(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void MergeView::signalNextChangedAvailable(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void MergeView::signalEntryWithMergeDisplayed(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void MergeView::gotoEntry(const DocPosition & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void MergeView::mergeCatalogAvailable(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void MergeView::mergeCatalogPointerChanged(MergeCatalog * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
